/*******************************************************************************
* File Name: CLK12.h
* Version 2.20
*
*  Description:
*   Provides the function and constant definitions for the clock component.
*
*  Note:
*
********************************************************************************
* Copyright 2008-2012, Cypress Semiconductor Corporation.  All rights reserved.
* You may use this file only in accordance with the license, terms, conditions, 
* disclaimers, and limitations in the end user license agreement accompanying 
* the software package with which this file was provided.
*******************************************************************************/

#if !defined(CY_CLOCK_CLK12_H)
#define CY_CLOCK_CLK12_H

#include <cytypes.h>
#include <cyfitter.h>


/***************************************
* Conditional Compilation Parameters
***************************************/

/* Check to see if required defines such as CY_PSOC5LP are available */
/* They are defined starting with cy_boot v3.0 */
#if !defined (CY_PSOC5LP)
    #error Component cy_clock_v2_20 requires cy_boot v3.0 or later
#endif /* (CY_PSOC5LP) */


/***************************************
*        Function Prototypes
***************************************/

void CLK12_Start(void) ;
void CLK12_Stop(void) ;

#if(CY_PSOC3 || CY_PSOC5LP)
void CLK12_StopBlock(void) ;
#endif /* (CY_PSOC3 || CY_PSOC5LP) */

void CLK12_StandbyPower(uint8 state) ;
void CLK12_SetDividerRegister(uint16 clkDivider, uint8 restart) 
                                ;
uint16 CLK12_GetDividerRegister(void) ;
void CLK12_SetModeRegister(uint8 modeBitMask) ;
void CLK12_ClearModeRegister(uint8 modeBitMask) ;
uint8 CLK12_GetModeRegister(void) ;
void CLK12_SetSourceRegister(uint8 clkSource) ;
uint8 CLK12_GetSourceRegister(void) ;
#if defined(CLK12__CFG3)
void CLK12_SetPhaseRegister(uint8 clkPhase) ;
uint8 CLK12_GetPhaseRegister(void) ;
#endif /* defined(CLK12__CFG3) */

#define CLK12_Enable()                       CLK12_Start()
#define CLK12_Disable()                      CLK12_Stop()
#define CLK12_SetDivider(clkDivider)         CLK12_SetDividerRegister(clkDivider, 1u)
#define CLK12_SetDividerValue(clkDivider)    CLK12_SetDividerRegister((clkDivider) - 1u, 1u)
#define CLK12_SetMode(clkMode)               CLK12_SetModeRegister(clkMode)
#define CLK12_SetSource(clkSource)           CLK12_SetSourceRegister(clkSource)
#if defined(CLK12__CFG3)
#define CLK12_SetPhase(clkPhase)             CLK12_SetPhaseRegister(clkPhase)
#define CLK12_SetPhaseValue(clkPhase)        CLK12_SetPhaseRegister((clkPhase) + 1u)
#endif /* defined(CLK12__CFG3) */


/***************************************
*             Registers
***************************************/

/* Register to enable or disable the clock */
#define CLK12_CLKEN              (* (reg8 *) CLK12__PM_ACT_CFG)
#define CLK12_CLKEN_PTR          ((reg8 *) CLK12__PM_ACT_CFG)

/* Register to enable or disable the clock */
#define CLK12_CLKSTBY            (* (reg8 *) CLK12__PM_STBY_CFG)
#define CLK12_CLKSTBY_PTR        ((reg8 *) CLK12__PM_STBY_CFG)

/* Clock LSB divider configuration register. */
#define CLK12_DIV_LSB            (* (reg8 *) CLK12__CFG0)
#define CLK12_DIV_LSB_PTR        ((reg8 *) CLK12__CFG0)
#define CLK12_DIV_PTR            ((reg16 *) CLK12__CFG0)

/* Clock MSB divider configuration register. */
#define CLK12_DIV_MSB            (* (reg8 *) CLK12__CFG1)
#define CLK12_DIV_MSB_PTR        ((reg8 *) CLK12__CFG1)

/* Mode and source configuration register */
#define CLK12_MOD_SRC            (* (reg8 *) CLK12__CFG2)
#define CLK12_MOD_SRC_PTR        ((reg8 *) CLK12__CFG2)

#if defined(CLK12__CFG3)
/* Analog clock phase configuration register */
#define CLK12_PHASE              (* (reg8 *) CLK12__CFG3)
#define CLK12_PHASE_PTR          ((reg8 *) CLK12__CFG3)
#endif /* defined(CLK12__CFG3) */


/**************************************
*       Register Constants
**************************************/

/* Power manager register masks */
#define CLK12_CLKEN_MASK         CLK12__PM_ACT_MSK
#define CLK12_CLKSTBY_MASK       CLK12__PM_STBY_MSK

/* CFG2 field masks */
#define CLK12_SRC_SEL_MSK        CLK12__CFG2_SRC_SEL_MASK
#define CLK12_MODE_MASK          (~(CLK12_SRC_SEL_MSK))

#if defined(CLK12__CFG3)
/* CFG3 phase mask */
#define CLK12_PHASE_MASK         CLK12__CFG3_PHASE_DLY_MASK
#endif /* defined(CLK12__CFG3) */

#endif /* CY_CLOCK_CLK12_H */


/* [] END OF FILE */
