/*******************************************************************************
* File Name: ETH_A.c
* Version 2.30
*
* Description:
*  This file provides all API functionality of the UART component
*
* Note:
*
********************************************************************************
* Copyright 2008-2012, Cypress Semiconductor Corporation.  All rights reserved.
* You may use this file only in accordance with the license, terms, conditions,
* disclaimers, and limitations in the end user license agreement accompanying
* the software package with which this file was provided.
*******************************************************************************/

#include "ETH_A.h"
#include "CyLib.h"
#if(ETH_A_INTERNAL_CLOCK_USED)
    #include "ETH_A_IntClock.h"
#endif /* End ETH_A_INTERNAL_CLOCK_USED */


/***************************************
* Global data allocation
***************************************/

uint8 ETH_A_initVar = 0u;
#if( ETH_A_TX_ENABLED && (ETH_A_TXBUFFERSIZE > ETH_A_FIFO_LENGTH))
    volatile uint8 ETH_A_txBuffer[ETH_A_TXBUFFERSIZE];
    volatile uint8 ETH_A_txBufferRead = 0u;
    uint8 ETH_A_txBufferWrite = 0u;
#endif /* End ETH_A_TX_ENABLED */
#if( ( ETH_A_RX_ENABLED || ETH_A_HD_ENABLED ) && \
     (ETH_A_RXBUFFERSIZE > ETH_A_FIFO_LENGTH) )
    volatile uint8 ETH_A_rxBuffer[ETH_A_RXBUFFERSIZE];
    volatile uint8 ETH_A_rxBufferRead = 0u;
    volatile uint8 ETH_A_rxBufferWrite = 0u;
    volatile uint8 ETH_A_rxBufferLoopDetect = 0u;
    volatile uint8 ETH_A_rxBufferOverflow = 0u;
    #if (ETH_A_RXHW_ADDRESS_ENABLED)
        volatile uint8 ETH_A_rxAddressMode = ETH_A_RXADDRESSMODE;
        volatile uint8 ETH_A_rxAddressDetected = 0u;
    #endif /* End EnableHWAddress */
#endif /* End ETH_A_RX_ENABLED */


/*******************************************************************************
* Function Name: ETH_A_Start
********************************************************************************
*
* Summary:
*  Initialize and Enable the UART component.
*  Enable the clock input to enable operation.
*
* Parameters:
*  None.
*
* Return:
*  None.
*
* Global variables:
*  The ETH_A_intiVar variable is used to indicate initial
*  configuration of this component. The variable is initialized to zero (0u)
*  and set to one (1u) the first time UART_Start() is called. This allows for
*  component initialization without re-initialization in all subsequent calls
*  to the ETH_A_Start() routine.
*
* Reentrant:
*  No.
*
*******************************************************************************/
void ETH_A_Start(void) 
{
    /* If not Initialized then initialize all required hardware and software */
    if(ETH_A_initVar == 0u)
    {
        ETH_A_Init();
        ETH_A_initVar = 1u;
    }
    ETH_A_Enable();
}


/*******************************************************************************
* Function Name: ETH_A_Init
********************************************************************************
*
* Summary:
*  Initialize component's parameters to the parameters set by user in the
*  customizer of the component placed onto schematic. Usually called in
*  ETH_A_Start().
*
* Parameters:
*  None.
*
* Return:
*  None.
*
*******************************************************************************/
void ETH_A_Init(void) 
{
    #if(ETH_A_RX_ENABLED || ETH_A_HD_ENABLED)

        #if(ETH_A_RX_INTERRUPT_ENABLED && (ETH_A_RXBUFFERSIZE > ETH_A_FIFO_LENGTH))
            /* Set the RX Interrupt. */
            (void)CyIntSetVector(ETH_A_RX_VECT_NUM, &ETH_A_RXISR);
            CyIntSetPriority(ETH_A_RX_VECT_NUM, ETH_A_RX_PRIOR_NUM);
        #endif /* End ETH_A_RX_INTERRUPT_ENABLED */

        #if (ETH_A_RXHW_ADDRESS_ENABLED)
            ETH_A_SetRxAddressMode(ETH_A_RXAddressMode);
            ETH_A_SetRxAddress1(ETH_A_RXHWADDRESS1);
            ETH_A_SetRxAddress2(ETH_A_RXHWADDRESS2);
        #endif /* End ETH_A_RXHW_ADDRESS_ENABLED */

        /* Init Count7 period */
        ETH_A_RXBITCTR_PERIOD_REG = ETH_A_RXBITCTR_INIT;
        /* Configure the Initial RX interrupt mask */
        ETH_A_RXSTATUS_MASK_REG  = ETH_A_INIT_RX_INTERRUPTS_MASK;
    #endif /* End ETH_A_RX_ENABLED || ETH_A_HD_ENABLED*/

    #if(ETH_A_TX_ENABLED)
        #if(ETH_A_TX_INTERRUPT_ENABLED && (ETH_A_TXBUFFERSIZE > ETH_A_FIFO_LENGTH))
            /* Set the TX Interrupt. */
            (void)CyIntSetVector(ETH_A_TX_VECT_NUM, &ETH_A_TXISR);
            CyIntSetPriority(ETH_A_TX_VECT_NUM, ETH_A_TX_PRIOR_NUM);
        #endif /* End ETH_A_TX_INTERRUPT_ENABLED */

        /* Write Counter Value for TX Bit Clk Generator*/
        #if(ETH_A_TXCLKGEN_DP)
            ETH_A_TXBITCLKGEN_CTR_REG = ETH_A_BIT_CENTER;
            ETH_A_TXBITCLKTX_COMPLETE_REG = (ETH_A_NUMBER_OF_DATA_BITS +
                        ETH_A_NUMBER_OF_START_BIT) * ETH_A_OVER_SAMPLE_COUNT;
        #else
            ETH_A_TXBITCTR_PERIOD_REG = ((ETH_A_NUMBER_OF_DATA_BITS +
                        ETH_A_NUMBER_OF_START_BIT) * ETH_A_OVER_SAMPLE_8) - 1u;
        #endif /* End ETH_A_TXCLKGEN_DP */

        /* Configure the Initial TX interrupt mask */
        #if(ETH_A_TX_INTERRUPT_ENABLED && (ETH_A_TXBUFFERSIZE > ETH_A_FIFO_LENGTH))
            ETH_A_TXSTATUS_MASK_REG = ETH_A_TX_STS_FIFO_EMPTY;
        #else
            ETH_A_TXSTATUS_MASK_REG = ETH_A_INIT_TX_INTERRUPTS_MASK;
        #endif /*End ETH_A_TX_INTERRUPT_ENABLED*/

    #endif /* End ETH_A_TX_ENABLED */

    #if(ETH_A_PARITY_TYPE_SW)  /* Write Parity to Control Register */
        ETH_A_WriteControlRegister( \
            (ETH_A_ReadControlRegister() & (uint8)~ETH_A_CTRL_PARITY_TYPE_MASK) | \
            (uint8)(ETH_A_PARITY_TYPE << ETH_A_CTRL_PARITY_TYPE0_SHIFT) );
    #endif /* End ETH_A_PARITY_TYPE_SW */
}


/*******************************************************************************
* Function Name: ETH_A_Enable
********************************************************************************
*
* Summary:
*  Enables the UART block operation
*
* Parameters:
*  None.
*
* Return:
*  None.
*
* Global Variables:
*  ETH_A_rxAddressDetected - set to initial state (0).
*
*******************************************************************************/
void ETH_A_Enable(void) 
{
    uint8 enableInterrupts;
    enableInterrupts = CyEnterCriticalSection();

    #if(ETH_A_RX_ENABLED || ETH_A_HD_ENABLED)
        /*RX Counter (Count7) Enable */
        ETH_A_RXBITCTR_CONTROL_REG |= ETH_A_CNTR_ENABLE;
        /* Enable the RX Interrupt. */
        ETH_A_RXSTATUS_ACTL_REG  |= ETH_A_INT_ENABLE;
        #if(ETH_A_RX_INTERRUPT_ENABLED && (ETH_A_RXBUFFERSIZE > ETH_A_FIFO_LENGTH))
            CyIntEnable(ETH_A_RX_VECT_NUM);
            #if (ETH_A_RXHW_ADDRESS_ENABLED)
                ETH_A_rxAddressDetected = 0u;
            #endif /* End ETH_A_RXHW_ADDRESS_ENABLED */
        #endif /* End ETH_A_RX_INTERRUPT_ENABLED */
    #endif /* End ETH_A_RX_ENABLED || ETH_A_HD_ENABLED*/

    #if(ETH_A_TX_ENABLED)
        /*TX Counter (DP/Count7) Enable */
        #if(!ETH_A_TXCLKGEN_DP)
            ETH_A_TXBITCTR_CONTROL_REG |= ETH_A_CNTR_ENABLE;
        #endif /* End ETH_A_TXCLKGEN_DP */
        /* Enable the TX Interrupt. */
        ETH_A_TXSTATUS_ACTL_REG |= ETH_A_INT_ENABLE;
        #if(ETH_A_TX_INTERRUPT_ENABLED && (ETH_A_TXBUFFERSIZE > ETH_A_FIFO_LENGTH))
            CyIntEnable(ETH_A_TX_VECT_NUM);
        #endif /* End ETH_A_TX_INTERRUPT_ENABLED*/
     #endif /* End ETH_A_TX_ENABLED */

    #if(ETH_A_INTERNAL_CLOCK_USED)
        /* Enable the clock. */
        ETH_A_IntClock_Start();
    #endif /* End ETH_A_INTERNAL_CLOCK_USED */

    CyExitCriticalSection(enableInterrupts);
}


/*******************************************************************************
* Function Name: ETH_A_Stop
********************************************************************************
*
* Summary:
*  Disable the UART component
*
* Parameters:
*  None.
*
* Return:
*  None.
*
*******************************************************************************/
void ETH_A_Stop(void) 
{
    uint8 enableInterrupts;
    enableInterrupts = CyEnterCriticalSection();

    /* Write Bit Counter Disable */
    #if(ETH_A_RX_ENABLED || ETH_A_HD_ENABLED)
        ETH_A_RXBITCTR_CONTROL_REG &= (uint8)~ETH_A_CNTR_ENABLE;
    #endif /* End ETH_A_RX_ENABLED */

    #if(ETH_A_TX_ENABLED)
        #if(!ETH_A_TXCLKGEN_DP)
            ETH_A_TXBITCTR_CONTROL_REG &= (uint8)~ETH_A_CNTR_ENABLE;
        #endif /* End ETH_A_TXCLKGEN_DP */
    #endif /* ETH_A_TX_ENABLED */

    #if(ETH_A_INTERNAL_CLOCK_USED)
        /* Disable the clock. */
        ETH_A_IntClock_Stop();
    #endif /* End ETH_A_INTERNAL_CLOCK_USED */

    /* Disable internal interrupt component */
    #if(ETH_A_RX_ENABLED || ETH_A_HD_ENABLED)
        ETH_A_RXSTATUS_ACTL_REG  &= (uint8)~ETH_A_INT_ENABLE;
        #if(ETH_A_RX_INTERRUPT_ENABLED && (ETH_A_RXBUFFERSIZE > ETH_A_FIFO_LENGTH))
            ETH_A_DisableRxInt();
        #endif /* End ETH_A_RX_INTERRUPT_ENABLED */
    #endif /* End ETH_A_RX_ENABLED */

    #if(ETH_A_TX_ENABLED)
        ETH_A_TXSTATUS_ACTL_REG &= (uint8)~ETH_A_INT_ENABLE;
        #if(ETH_A_TX_INTERRUPT_ENABLED && (ETH_A_TXBUFFERSIZE > ETH_A_FIFO_LENGTH))
            ETH_A_DisableTxInt();
        #endif /* End ETH_A_TX_INTERRUPT_ENABLED */
    #endif /* End ETH_A_TX_ENABLED */

    CyExitCriticalSection(enableInterrupts);
}


/*******************************************************************************
* Function Name: ETH_A_ReadControlRegister
********************************************************************************
*
* Summary:
*  Read the current state of the control register
*
* Parameters:
*  None.
*
* Return:
*  Current state of the control register.
*
*******************************************************************************/
uint8 ETH_A_ReadControlRegister(void) 
{
    #if( ETH_A_CONTROL_REG_REMOVED )
        return(0u);
    #else
        return(ETH_A_CONTROL_REG);
    #endif /* End ETH_A_CONTROL_REG_REMOVED */
}


/*******************************************************************************
* Function Name: ETH_A_WriteControlRegister
********************************************************************************
*
* Summary:
*  Writes an 8-bit value into the control register
*
* Parameters:
*  control:  control register value
*
* Return:
*  None.
*
*******************************************************************************/
void  ETH_A_WriteControlRegister(uint8 control) 
{
    #if( ETH_A_CONTROL_REG_REMOVED )
        if(control != 0u) { }      /* release compiler warning */
    #else
       ETH_A_CONTROL_REG = control;
    #endif /* End ETH_A_CONTROL_REG_REMOVED */
}


#if(ETH_A_RX_ENABLED || ETH_A_HD_ENABLED)

    #if(ETH_A_RX_INTERRUPT_ENABLED)

        /*******************************************************************************
        * Function Name: ETH_A_EnableRxInt
        ********************************************************************************
        *
        * Summary:
        *  Enable RX interrupt generation
        *
        * Parameters:
        *  None.
        *
        * Return:
        *  None.
        *
        * Theory:
        *  Enable the interrupt output -or- the interrupt component itself
        *
        *******************************************************************************/
        void ETH_A_EnableRxInt(void) 
        {
            CyIntEnable(ETH_A_RX_VECT_NUM);
        }


        /*******************************************************************************
        * Function Name: ETH_A_DisableRxInt
        ********************************************************************************
        *
        * Summary:
        *  Disable RX interrupt generation
        *
        * Parameters:
        *  None.
        *
        * Return:
        *  None.
        *
        * Theory:
        *  Disable the interrupt output -or- the interrupt component itself
        *
        *******************************************************************************/
        void ETH_A_DisableRxInt(void) 
        {
            CyIntDisable(ETH_A_RX_VECT_NUM);
        }

    #endif /* ETH_A_RX_INTERRUPT_ENABLED */


    /*******************************************************************************
    * Function Name: ETH_A_SetRxInterruptMode
    ********************************************************************************
    *
    * Summary:
    *  Configure which status bits trigger an interrupt event
    *
    * Parameters:
    *  IntSrc:  An or'd combination of the desired status bit masks (defined in
    *           the header file)
    *
    * Return:
    *  None.
    *
    * Theory:
    *  Enables the output of specific status bits to the interrupt controller
    *
    *******************************************************************************/
    void ETH_A_SetRxInterruptMode(uint8 intSrc) 
    {
        ETH_A_RXSTATUS_MASK_REG  = intSrc;
    }


    /*******************************************************************************
    * Function Name: ETH_A_ReadRxData
    ********************************************************************************
    *
    * Summary:
    *  Returns data in RX Data register without checking status register to
    *  determine if data is valid
    *
    * Parameters:
    *  None.
    *
    * Return:
    *  Received data from RX register
    *
    * Global Variables:
    *  ETH_A_rxBuffer - RAM buffer pointer for save received data.
    *  ETH_A_rxBufferWrite - cyclic index for write to rxBuffer,
    *     checked to identify new data.
    *  ETH_A_rxBufferRead - cyclic index for read from rxBuffer,
    *     incremented after each byte has been read from buffer.
    *  ETH_A_rxBufferLoopDetect - creared if loop condition was detected
    *     in RX ISR.
    *
    * Reentrant:
    *  No.
    *
    *******************************************************************************/
    uint8 ETH_A_ReadRxData(void) 
    {
        uint8 rxData;

        #if(ETH_A_RXBUFFERSIZE > ETH_A_FIFO_LENGTH)
            uint8 loc_rxBufferRead;
            uint8 loc_rxBufferWrite;
            /* Protect variables that could change on interrupt. */
            /* Disable Rx interrupt. */
            #if(ETH_A_RX_INTERRUPT_ENABLED)
                ETH_A_DisableRxInt();
            #endif /* ETH_A_RX_INTERRUPT_ENABLED */
            loc_rxBufferRead = ETH_A_rxBufferRead;
            loc_rxBufferWrite = ETH_A_rxBufferWrite;

            if( (ETH_A_rxBufferLoopDetect != 0u) || (loc_rxBufferRead != loc_rxBufferWrite) )
            {
                rxData = ETH_A_rxBuffer[loc_rxBufferRead];
                loc_rxBufferRead++;

                if(loc_rxBufferRead >= ETH_A_RXBUFFERSIZE)
                {
                    loc_rxBufferRead = 0u;
                }
                /* Update the real pointer */
                ETH_A_rxBufferRead = loc_rxBufferRead;

                if(ETH_A_rxBufferLoopDetect != 0u )
                {
                    ETH_A_rxBufferLoopDetect = 0u;
                    #if( (ETH_A_RX_INTERRUPT_ENABLED) && (ETH_A_FLOW_CONTROL != 0u) && \
                         (ETH_A_RXBUFFERSIZE > ETH_A_FIFO_LENGTH) )
                        /* When Hardware Flow Control selected - return RX mask */
                        #if( ETH_A_HD_ENABLED )
                            if((ETH_A_CONTROL_REG & ETH_A_CTRL_HD_SEND) == 0u)
                            {   /* In Half duplex mode return RX mask only in RX
                                *  configuration set, otherwise
                                *  mask will be returned in LoadRxConfig() API.
                                */
                                ETH_A_RXSTATUS_MASK_REG  |= ETH_A_RX_STS_FIFO_NOTEMPTY;
                            }
                        #else
                            ETH_A_RXSTATUS_MASK_REG  |= ETH_A_RX_STS_FIFO_NOTEMPTY;
                        #endif /* end ETH_A_HD_ENABLED */
                    #endif /* ETH_A_RX_INTERRUPT_ENABLED and Hardware flow control*/
                }
            }
            else
            {   /* Needs to check status for RX_STS_FIFO_NOTEMPTY bit*/
                rxData = ETH_A_RXDATA_REG;
            }

            /* Enable Rx interrupt. */
            #if(ETH_A_RX_INTERRUPT_ENABLED)
                ETH_A_EnableRxInt();
            #endif /* End ETH_A_RX_INTERRUPT_ENABLED */

        #else /* ETH_A_RXBUFFERSIZE > ETH_A_FIFO_LENGTH */

            /* Needs to check status for RX_STS_FIFO_NOTEMPTY bit*/
            rxData = ETH_A_RXDATA_REG;

        #endif /* ETH_A_RXBUFFERSIZE > ETH_A_FIFO_LENGTH */

        return(rxData);
    }


    /*******************************************************************************
    * Function Name: ETH_A_ReadRxStatus
    ********************************************************************************
    *
    * Summary:
    *  Read the current state of the status register
    *  And detect software buffer overflow.
    *
    * Parameters:
    *  None.
    *
    * Return:
    *  Current state of the status register.
    *
    * Global Variables:
    *  ETH_A_rxBufferOverflow - used to indicate overload condition.
    *   It set to one in RX interrupt when there isn?t free space in
    *   ETH_A_rxBufferRead to write new data. This condition returned
    *   and cleared to zero by this API as an
    *   ETH_A_RX_STS_SOFT_BUFF_OVER bit along with RX Status register
    *   bits.
    *
    *******************************************************************************/
    uint8 ETH_A_ReadRxStatus(void) 
    {
        uint8 status;

        status = ETH_A_RXSTATUS_REG & ETH_A_RX_HW_MASK;

        #if(ETH_A_RXBUFFERSIZE > ETH_A_FIFO_LENGTH)
            if( ETH_A_rxBufferOverflow != 0u )
            {
                status |= ETH_A_RX_STS_SOFT_BUFF_OVER;
                ETH_A_rxBufferOverflow = 0u;
            }
        #endif /* ETH_A_RXBUFFERSIZE */

        return(status);
    }


    /*******************************************************************************
    * Function Name: ETH_A_GetChar
    ********************************************************************************
    *
    * Summary:
    *  Reads UART RX buffer immediately, if data is not available or an error
    *  condition exists, zero is returned; otherwise, character is read and
    *  returned.
    *
    * Parameters:
    *  None.
    *
    * Return:
    *  Character read from UART RX buffer. ASCII characters from 1 to 255 are valid.
    *  A returned zero signifies an error condition or no data available.
    *
    * Global Variables:
    *  ETH_A_rxBuffer - RAM buffer pointer for save received data.
    *  ETH_A_rxBufferWrite - cyclic index for write to rxBuffer,
    *     checked to identify new data.
    *  ETH_A_rxBufferRead - cyclic index for read from rxBuffer,
    *     incremented after each byte has been read from buffer.
    *  ETH_A_rxBufferLoopDetect - creared if loop condition was detected
    *     in RX ISR.
    *
    * Reentrant:
    *  No.
    *
    *******************************************************************************/
    uint8 ETH_A_GetChar(void) 
    {
        uint8 rxData = 0u;
        uint8 rxStatus;

        #if(ETH_A_RXBUFFERSIZE > ETH_A_FIFO_LENGTH)
            uint8 loc_rxBufferRead;
            uint8 loc_rxBufferWrite;
            /* Protect variables that could change on interrupt. */
            /* Disable Rx interrupt. */
            #if(ETH_A_RX_INTERRUPT_ENABLED)
                ETH_A_DisableRxInt();
            #endif /* ETH_A_RX_INTERRUPT_ENABLED */
            loc_rxBufferRead = ETH_A_rxBufferRead;
            loc_rxBufferWrite = ETH_A_rxBufferWrite;

            if( (ETH_A_rxBufferLoopDetect != 0u) || (loc_rxBufferRead != loc_rxBufferWrite) )
            {
                rxData = ETH_A_rxBuffer[loc_rxBufferRead];
                loc_rxBufferRead++;
                if(loc_rxBufferRead >= ETH_A_RXBUFFERSIZE)
                {
                    loc_rxBufferRead = 0u;
                }
                /* Update the real pointer */
                ETH_A_rxBufferRead = loc_rxBufferRead;

                if(ETH_A_rxBufferLoopDetect > 0u )
                {
                    ETH_A_rxBufferLoopDetect = 0u;
                    #if( (ETH_A_RX_INTERRUPT_ENABLED) && (ETH_A_FLOW_CONTROL != 0u) )
                        /* When Hardware Flow Control selected - return RX mask */
                        #if( ETH_A_HD_ENABLED )
                            if((ETH_A_CONTROL_REG & ETH_A_CTRL_HD_SEND) == 0u)
                            {   /* In Half duplex mode return RX mask only if
                                *  RX configuration set, otherwise
                                *  mask will be returned in LoadRxConfig() API.
                                */
                                ETH_A_RXSTATUS_MASK_REG  |= ETH_A_RX_STS_FIFO_NOTEMPTY;
                            }
                        #else
                            ETH_A_RXSTATUS_MASK_REG  |= ETH_A_RX_STS_FIFO_NOTEMPTY;
                        #endif /* end ETH_A_HD_ENABLED */
                    #endif /* ETH_A_RX_INTERRUPT_ENABLED and Hardware flow control*/
                }

            }
            else
            {   rxStatus = ETH_A_RXSTATUS_REG;
                if((rxStatus & ETH_A_RX_STS_FIFO_NOTEMPTY) != 0u)
                {   /* Read received data from FIFO*/
                    rxData = ETH_A_RXDATA_REG;
                    /*Check status on error*/
                    if((rxStatus & (ETH_A_RX_STS_BREAK | ETH_A_RX_STS_PAR_ERROR |
                                   ETH_A_RX_STS_STOP_ERROR | ETH_A_RX_STS_OVERRUN)) != 0u)
                    {
                        rxData = 0u;
                    }
                }
            }

            /* Enable Rx interrupt. */
            #if(ETH_A_RX_INTERRUPT_ENABLED)
                ETH_A_EnableRxInt();
            #endif /* ETH_A_RX_INTERRUPT_ENABLED */

        #else /* ETH_A_RXBUFFERSIZE > ETH_A_FIFO_LENGTH */

            rxStatus =ETH_A_RXSTATUS_REG;
            if((rxStatus & ETH_A_RX_STS_FIFO_NOTEMPTY) != 0u)
            {   /* Read received data from FIFO*/
                rxData = ETH_A_RXDATA_REG;
                /*Check status on error*/
                if((rxStatus & (ETH_A_RX_STS_BREAK | ETH_A_RX_STS_PAR_ERROR |
                               ETH_A_RX_STS_STOP_ERROR | ETH_A_RX_STS_OVERRUN)) != 0u)
                {
                    rxData = 0u;
                }
            }
        #endif /* ETH_A_RXBUFFERSIZE > ETH_A_FIFO_LENGTH */

        return(rxData);
    }


    /*******************************************************************************
    * Function Name: ETH_A_GetByte
    ********************************************************************************
    *
    * Summary:
    *  Grab the next available byte of data from the recieve FIFO
    *
    * Parameters:
    *  None.
    *
    * Return:
    *  MSB contains Status Register and LSB contains UART RX data
    *
    * Reentrant:
    *  No.
    *
    *******************************************************************************/
    uint16 ETH_A_GetByte(void) 
    {
        return ( ((uint16)ETH_A_ReadRxStatus() << 8u) | ETH_A_ReadRxData() );
    }


    /*******************************************************************************
    * Function Name: ETH_A_GetRxBufferSize
    ********************************************************************************
    *
    * Summary:
    *  Determine the amount of bytes left in the RX buffer and return the count in
    *  bytes
    *
    * Parameters:
    *  None.
    *
    * Return:
    *  uint8: Integer count of the number of bytes left
    *  in the RX buffer
    *
    * Global Variables:
    *  ETH_A_rxBufferWrite - used to calculate left bytes.
    *  ETH_A_rxBufferRead - used to calculate left bytes.
    *  ETH_A_rxBufferLoopDetect - checked to decide left bytes amount.
    *
    * Reentrant:
    *  No.
    *
    * Theory:
    *  Allows the user to find out how full the RX Buffer is.
    *
    *******************************************************************************/
    uint8 ETH_A_GetRxBufferSize(void)
                                                            
    {
        uint8 size;

        #if(ETH_A_RXBUFFERSIZE > ETH_A_FIFO_LENGTH)

            /* Disable Rx interrupt. */
            /* Protect variables that could change on interrupt. */
            #if(ETH_A_RX_INTERRUPT_ENABLED)
                ETH_A_DisableRxInt();
            #endif /* ETH_A_RX_INTERRUPT_ENABLED */

            if(ETH_A_rxBufferRead == ETH_A_rxBufferWrite)
            {
                if(ETH_A_rxBufferLoopDetect > 0u)
                {
                    size = ETH_A_RXBUFFERSIZE;
                }
                else
                {
                    size = 0u;
                }
            }
            else if(ETH_A_rxBufferRead < ETH_A_rxBufferWrite)
            {
                size = (ETH_A_rxBufferWrite - ETH_A_rxBufferRead);
            }
            else
            {
                size = (ETH_A_RXBUFFERSIZE - ETH_A_rxBufferRead) + ETH_A_rxBufferWrite;
            }

            /* Enable Rx interrupt. */
            #if(ETH_A_RX_INTERRUPT_ENABLED)
                ETH_A_EnableRxInt();
            #endif /* End ETH_A_RX_INTERRUPT_ENABLED */

        #else /* ETH_A_RXBUFFERSIZE > ETH_A_FIFO_LENGTH */

            /* We can only know if there is data in the fifo. */
            size = ((ETH_A_RXSTATUS_REG & ETH_A_RX_STS_FIFO_NOTEMPTY) != 0u) ? 1u : 0u;

        #endif /* End ETH_A_RXBUFFERSIZE > ETH_A_FIFO_LENGTH */

        return(size);
    }


    /*******************************************************************************
    * Function Name: ETH_A_ClearRxBuffer
    ********************************************************************************
    *
    * Summary:
    *  Clears the RX RAM buffer by setting the read and write pointers both to zero.
    *  Clears hardware RX FIFO.
    *
    * Parameters:
    *  None.
    *
    * Return:
    *  None.
    *
    * Global Variables:
    *  ETH_A_rxBufferWrite - cleared to zero.
    *  ETH_A_rxBufferRead - cleared to zero.
    *  ETH_A_rxBufferLoopDetect - cleared to zero.
    *  ETH_A_rxBufferOverflow - cleared to zero.
    *
    * Reentrant:
    *  No.
    *
    * Theory:
    *  Setting the pointers to zero makes the system believe there is no data to
    *  read and writing will resume at address 0 overwriting any data that may
    *  have remained in the RAM.
    *
    * Side Effects:
    *  Any received data not read from the RAM or FIFO buffer will be lost.
    *******************************************************************************/
    void ETH_A_ClearRxBuffer(void) 
    {
        uint8 enableInterrupts;

        /* clear the HW FIFO */
        /* Enter critical section */
        enableInterrupts = CyEnterCriticalSection();
        ETH_A_RXDATA_AUX_CTL_REG |=  ETH_A_RX_FIFO_CLR;
        ETH_A_RXDATA_AUX_CTL_REG &= (uint8)~ETH_A_RX_FIFO_CLR;
        /* Exit critical section */
        CyExitCriticalSection(enableInterrupts);

        #if(ETH_A_RXBUFFERSIZE > ETH_A_FIFO_LENGTH)
            /* Disable Rx interrupt. */
            /* Protect variables that could change on interrupt. */
            #if(ETH_A_RX_INTERRUPT_ENABLED)
                ETH_A_DisableRxInt();
            #endif /* End ETH_A_RX_INTERRUPT_ENABLED */

            ETH_A_rxBufferRead = 0u;
            ETH_A_rxBufferWrite = 0u;
            ETH_A_rxBufferLoopDetect = 0u;
            ETH_A_rxBufferOverflow = 0u;

            /* Enable Rx interrupt. */
            #if(ETH_A_RX_INTERRUPT_ENABLED)
                ETH_A_EnableRxInt();
            #endif /* End ETH_A_RX_INTERRUPT_ENABLED */
        #endif /* End ETH_A_RXBUFFERSIZE > ETH_A_FIFO_LENGTH */

    }


    /*******************************************************************************
    * Function Name: ETH_A_SetRxAddressMode
    ********************************************************************************
    *
    * Summary:
    *  Set the receive addressing mode
    *
    * Parameters:
    *  addressMode: Enumerated value indicating the mode of RX addressing
    *  ETH_A__B_UART__AM_SW_BYTE_BYTE -  Software Byte-by-Byte address
    *                                               detection
    *  ETH_A__B_UART__AM_SW_DETECT_TO_BUFFER - Software Detect to Buffer
    *                                               address detection
    *  ETH_A__B_UART__AM_HW_BYTE_BY_BYTE - Hardware Byte-by-Byte address
    *                                               detection
    *  ETH_A__B_UART__AM_HW_DETECT_TO_BUFFER - Hardware Detect to Buffer
    *                                               address detection
    *  ETH_A__B_UART__AM_NONE - No address detection
    *
    * Return:
    *  None.
    *
    * Global Variables:
    *  ETH_A_rxAddressMode - the parameter stored in this variable for
    *   the farther usage in RX ISR.
    *  ETH_A_rxAddressDetected - set to initial state (0).
    *
    *******************************************************************************/
    void ETH_A_SetRxAddressMode(uint8 addressMode)
                                                        
    {
        #if(ETH_A_RXHW_ADDRESS_ENABLED)
            #if(ETH_A_CONTROL_REG_REMOVED)
                if(addressMode != 0u) { }     /* release compiler warning */
            #else /* ETH_A_CONTROL_REG_REMOVED */
                uint8 tmpCtrl;
                tmpCtrl = ETH_A_CONTROL_REG & (uint8)~ETH_A_CTRL_RXADDR_MODE_MASK;
                tmpCtrl |= (uint8)(addressMode << ETH_A_CTRL_RXADDR_MODE0_SHIFT);
                ETH_A_CONTROL_REG = tmpCtrl;
                #if(ETH_A_RX_INTERRUPT_ENABLED && \
                   (ETH_A_RXBUFFERSIZE > ETH_A_FIFO_LENGTH) )
                    ETH_A_rxAddressMode = addressMode;
                    ETH_A_rxAddressDetected = 0u;
                #endif /* End ETH_A_RXBUFFERSIZE > ETH_A_FIFO_LENGTH*/
            #endif /* End ETH_A_CONTROL_REG_REMOVED */
        #else /* ETH_A_RXHW_ADDRESS_ENABLED */
            if(addressMode != 0u) { }     /* release compiler warning */
        #endif /* End ETH_A_RXHW_ADDRESS_ENABLED */
    }


    /*******************************************************************************
    * Function Name: ETH_A_SetRxAddress1
    ********************************************************************************
    *
    * Summary:
    *  Set the first hardware address compare value
    *
    * Parameters:
    *  address
    *
    * Return:
    *  None.
    *
    *******************************************************************************/
    void ETH_A_SetRxAddress1(uint8 address) 

    {
        ETH_A_RXADDRESS1_REG = address;
    }


    /*******************************************************************************
    * Function Name: ETH_A_SetRxAddress2
    ********************************************************************************
    *
    * Summary:
    *  Set the second hardware address compare value
    *
    * Parameters:
    *  address
    *
    * Return:
    *  None.
    *
    *******************************************************************************/
    void ETH_A_SetRxAddress2(uint8 address) 
    {
        ETH_A_RXADDRESS2_REG = address;
    }

#endif  /* ETH_A_RX_ENABLED || ETH_A_HD_ENABLED*/


#if( (ETH_A_TX_ENABLED) || (ETH_A_HD_ENABLED) )

    #if(ETH_A_TX_INTERRUPT_ENABLED)

        /*******************************************************************************
        * Function Name: ETH_A_EnableTxInt
        ********************************************************************************
        *
        * Summary:
        *  Enable TX interrupt generation
        *
        * Parameters:
        *  None.
        *
        * Return:
        *  None.
        *
        * Theory:
        *  Enable the interrupt output -or- the interrupt component itself
        *
        *******************************************************************************/
        void ETH_A_EnableTxInt(void) 
        {
            CyIntEnable(ETH_A_TX_VECT_NUM);
        }


        /*******************************************************************************
        * Function Name: ETH_A_DisableTxInt
        ********************************************************************************
        *
        * Summary:
        *  Disable TX interrupt generation
        *
        * Parameters:
        *  None.
        *
        * Return:
        *  None.
        *
        * Theory:
        *  Disable the interrupt output -or- the interrupt component itself
        *
        *******************************************************************************/
        void ETH_A_DisableTxInt(void) 
        {
            CyIntDisable(ETH_A_TX_VECT_NUM);
        }

    #endif /* ETH_A_TX_INTERRUPT_ENABLED */


    /*******************************************************************************
    * Function Name: ETH_A_SetTxInterruptMode
    ********************************************************************************
    *
    * Summary:
    *  Configure which status bits trigger an interrupt event
    *
    * Parameters:
    *  intSrc: An or'd combination of the desired status bit masks (defined in
    *          the header file)
    *
    * Return:
    *  None.
    *
    * Theory:
    *  Enables the output of specific status bits to the interrupt controller
    *
    *******************************************************************************/
    void ETH_A_SetTxInterruptMode(uint8 intSrc) 
    {
        ETH_A_TXSTATUS_MASK_REG = intSrc;
    }


    /*******************************************************************************
    * Function Name: ETH_A_WriteTxData
    ********************************************************************************
    *
    * Summary:
    *  Write a byte of data to the Transmit FIFO or TX buffer to be sent when the
    *  bus is available. WriteTxData sends a byte without checking for buffer room
    *  or status. It is up to the user to separately check status.
    *
    * Parameters:
    *  TXDataByte: byte of data to place in the transmit FIFO
    *
    * Return:
    * void
    *
    * Global Variables:
    *  ETH_A_txBuffer - RAM buffer pointer for save data for transmission
    *  ETH_A_txBufferWrite - cyclic index for write to txBuffer,
    *    incremented after each byte saved to buffer.
    *  ETH_A_txBufferRead - cyclic index for read from txBuffer,
    *    checked to identify the condition to write to FIFO directly or to TX buffer
    *  ETH_A_initVar - checked to identify that the component has been
    *    initialized.
    *
    * Reentrant:
    *  No.
    *
    *******************************************************************************/
    void ETH_A_WriteTxData(uint8 txDataByte) 
    {
        /* If not Initialized then skip this function*/
        if(ETH_A_initVar != 0u)
        {
            #if(ETH_A_TXBUFFERSIZE > ETH_A_FIFO_LENGTH)

                /* Disable Tx interrupt. */
                /* Protect variables that could change on interrupt. */
                #if(ETH_A_TX_INTERRUPT_ENABLED)
                    ETH_A_DisableTxInt();
                #endif /* End ETH_A_TX_INTERRUPT_ENABLED */

                if( (ETH_A_txBufferRead == ETH_A_txBufferWrite) &&
                    ((ETH_A_TXSTATUS_REG & ETH_A_TX_STS_FIFO_FULL) == 0u) )
                {
                    /* Add directly to the FIFO. */
                    ETH_A_TXDATA_REG = txDataByte;
                }
                else
                {
                    if(ETH_A_txBufferWrite >= ETH_A_TXBUFFERSIZE)
                    {
                        ETH_A_txBufferWrite = 0u;
                    }

                    ETH_A_txBuffer[ETH_A_txBufferWrite] = txDataByte;

                    /* Add to the software buffer. */
                    ETH_A_txBufferWrite++;

                }

                /* Enable Tx interrupt. */
                #if(ETH_A_TX_INTERRUPT_ENABLED)
                    ETH_A_EnableTxInt();
                #endif /* End ETH_A_TX_INTERRUPT_ENABLED */

            #else /* ETH_A_TXBUFFERSIZE > ETH_A_FIFO_LENGTH */

                /* Add directly to the FIFO. */
                ETH_A_TXDATA_REG = txDataByte;

            #endif /* End ETH_A_TXBUFFERSIZE > ETH_A_FIFO_LENGTH */
        }
    }


    /*******************************************************************************
    * Function Name: ETH_A_ReadTxStatus
    ********************************************************************************
    *
    * Summary:
    *  Read the status register for the component
    *
    * Parameters:
    *  None.
    *
    * Return:
    *  Contents of the status register
    *
    * Theory:
    *  This function reads the status register which is clear on read. It is up to
    *  the user to handle all bits in this return value accordingly, even if the bit
    *  was not enabled as an interrupt source the event happened and must be handled
    *  accordingly.
    *
    *******************************************************************************/
    uint8 ETH_A_ReadTxStatus(void) 
    {
        return(ETH_A_TXSTATUS_REG);
    }


    /*******************************************************************************
    * Function Name: ETH_A_PutChar
    ********************************************************************************
    *
    * Summary:
    *  Wait to send byte until TX register or buffer has room.
    *
    * Parameters:
    *  txDataByte: The 8-bit data value to send across the UART.
    *
    * Return:
    *  None.
    *
    * Global Variables:
    *  ETH_A_txBuffer - RAM buffer pointer for save data for transmission
    *  ETH_A_txBufferWrite - cyclic index for write to txBuffer,
    *     checked to identify free space in txBuffer and incremented after each byte
    *     saved to buffer.
    *  ETH_A_txBufferRead - cyclic index for read from txBuffer,
    *     checked to identify free space in txBuffer.
    *  ETH_A_initVar - checked to identify that the component has been
    *     initialized.
    *
    * Reentrant:
    *  No.
    *
    * Theory:
    *  Allows the user to transmit any byte of data in a single transfer
    *
    *******************************************************************************/
    void ETH_A_PutChar(uint8 txDataByte) 
    {
            #if(ETH_A_TXBUFFERSIZE > ETH_A_FIFO_LENGTH)
                /* The temporary output pointer is used since it takes two instructions
                *  to increment with a wrap, and we can't risk doing that with the real
                *  pointer and getting an interrupt in between instructions.
                */
                uint8 loc_txBufferWrite;
                uint8 loc_txBufferRead;

                do{
                    /* Block if software buffer is full, so we don't overwrite. */
                    #if ((ETH_A_TXBUFFERSIZE > ETH_A_MAX_BYTE_VALUE) && (CY_PSOC3))
                        /* Disable TX interrupt to protect variables that could change on interrupt */
                        CyIntDisable(ETH_A_TX_VECT_NUM);
                    #endif /* End TXBUFFERSIZE > 255 */
                    loc_txBufferWrite = ETH_A_txBufferWrite;
                    loc_txBufferRead = ETH_A_txBufferRead;
                    #if ((ETH_A_TXBUFFERSIZE > ETH_A_MAX_BYTE_VALUE) && (CY_PSOC3))
                        /* Enable interrupt to continue transmission */
                        CyIntEnable(ETH_A_TX_VECT_NUM);
                    #endif /* End TXBUFFERSIZE > 255 */
                }while( (loc_txBufferWrite < loc_txBufferRead) ? (loc_txBufferWrite == (loc_txBufferRead - 1u)) :
                                        ((loc_txBufferWrite - loc_txBufferRead) ==
                                        (uint8)(ETH_A_TXBUFFERSIZE - 1u)) );

                if( (loc_txBufferRead == loc_txBufferWrite) &&
                    ((ETH_A_TXSTATUS_REG & ETH_A_TX_STS_FIFO_FULL) == 0u) )
                {
                    /* Add directly to the FIFO. */
                    ETH_A_TXDATA_REG = txDataByte;
                }
                else
                {
                    if(loc_txBufferWrite >= ETH_A_TXBUFFERSIZE)
                    {
                        loc_txBufferWrite = 0u;
                    }
                    /* Add to the software buffer. */
                    ETH_A_txBuffer[loc_txBufferWrite] = txDataByte;
                    loc_txBufferWrite++;

                    /* Finally, update the real output pointer */
                    #if ((ETH_A_TXBUFFERSIZE > ETH_A_MAX_BYTE_VALUE) && (CY_PSOC3))
                        CyIntDisable(ETH_A_TX_VECT_NUM);
                    #endif /* End TXBUFFERSIZE > 255 */
                    ETH_A_txBufferWrite = loc_txBufferWrite;
                    #if ((ETH_A_TXBUFFERSIZE > ETH_A_MAX_BYTE_VALUE) && (CY_PSOC3))
                        CyIntEnable(ETH_A_TX_VECT_NUM);
                    #endif /* End TXBUFFERSIZE > 255 */
                }

            #else /* ETH_A_TXBUFFERSIZE > ETH_A_FIFO_LENGTH */

                while((ETH_A_TXSTATUS_REG & ETH_A_TX_STS_FIFO_FULL) != 0u)
                {
                    ; /* Wait for room in the FIFO. */
                }

                /* Add directly to the FIFO. */
                ETH_A_TXDATA_REG = txDataByte;

            #endif /* End ETH_A_TXBUFFERSIZE > ETH_A_FIFO_LENGTH */
    }


    /*******************************************************************************
    * Function Name: ETH_A_PutString
    ********************************************************************************
    *
    * Summary:
    *  Write a Sequence of bytes on the Transmit line. Data comes from RAM or ROM.
    *
    * Parameters:
    *  string: char pointer to character string of Data to Send.
    *
    * Return:
    *  None.
    *
    * Global Variables:
    *  ETH_A_initVar - checked to identify that the component has been
    *     initialized.
    *
    * Reentrant:
    *  No.
    *
    * Theory:
    *  This function will block if there is not enough memory to place the whole
    *  string, it will block until the entire string has been written to the
    *  transmit buffer.
    *
    *******************************************************************************/
    void ETH_A_PutString(const char8 string[]) 
    {
        uint16 buf_index = 0u;
        /* If not Initialized then skip this function*/
        if(ETH_A_initVar != 0u)
        {
            /* This is a blocking function, it will not exit until all data is sent*/
            while(string[buf_index] != (char8)0)
            {
                ETH_A_PutChar((uint8)string[buf_index]);
                buf_index++;
            }
        }
    }


    /*******************************************************************************
    * Function Name: ETH_A_PutArray
    ********************************************************************************
    *
    * Summary:
    *  Write a Sequence of bytes on the Transmit line. Data comes from RAM or ROM.
    *
    * Parameters:
    *  string: Address of the memory array residing in RAM or ROM.
    *  byteCount: Number of Bytes to be transmitted.
    *
    * Return:
    *  None.
    *
    * Global Variables:
    *  ETH_A_initVar - checked to identify that the component has been
    *     initialized.
    *
    * Reentrant:
    *  No.
    *
    *******************************************************************************/
    void ETH_A_PutArray(const uint8 string[], uint8 byteCount)
                                                                    
    {
        uint8 buf_index = 0u;
        /* If not Initialized then skip this function*/
        if(ETH_A_initVar != 0u)
        {
            do
            {
                ETH_A_PutChar(string[buf_index]);
                buf_index++;
            }while(buf_index < byteCount);
        }
    }


    /*******************************************************************************
    * Function Name: ETH_A_PutCRLF
    ********************************************************************************
    *
    * Summary:
    *  Write a character and then carriage return and line feed.
    *
    * Parameters:
    *  txDataByte: uint8 Character to send.
    *
    * Return:
    *  None.
    *
    * Global Variables:
    *  ETH_A_initVar - checked to identify that the component has been
    *     initialized.
    *
    * Reentrant:
    *  No.
    *
    *******************************************************************************/
    void ETH_A_PutCRLF(uint8 txDataByte) 
    {
        /* If not Initialized then skip this function*/
        if(ETH_A_initVar != 0u)
        {
            ETH_A_PutChar(txDataByte);
            ETH_A_PutChar(0x0Du);
            ETH_A_PutChar(0x0Au);
        }
    }


    /*******************************************************************************
    * Function Name: ETH_A_GetTxBufferSize
    ********************************************************************************
    *
    * Summary:
    *  Determine the amount of space left in the TX buffer and return the count in
    *  bytes
    *
    * Parameters:
    *  None.
    *
    * Return:
    *  Integer count of the number of bytes left in the TX buffer
    *
    * Global Variables:
    *  ETH_A_txBufferWrite - used to calculate left space.
    *  ETH_A_txBufferRead - used to calculate left space.
    *
    * Reentrant:
    *  No.
    *
    * Theory:
    *  Allows the user to find out how full the TX Buffer is.
    *
    *******************************************************************************/
    uint8 ETH_A_GetTxBufferSize(void)
                                                            
    {
        uint8 size;

        #if(ETH_A_TXBUFFERSIZE > ETH_A_FIFO_LENGTH)

            /* Disable Tx interrupt. */
            /* Protect variables that could change on interrupt. */
            #if(ETH_A_TX_INTERRUPT_ENABLED)
                ETH_A_DisableTxInt();
            #endif /* End ETH_A_TX_INTERRUPT_ENABLED */

            if(ETH_A_txBufferRead == ETH_A_txBufferWrite)
            {
                size = 0u;
            }
            else if(ETH_A_txBufferRead < ETH_A_txBufferWrite)
            {
                size = (ETH_A_txBufferWrite - ETH_A_txBufferRead);
            }
            else
            {
                size = (ETH_A_TXBUFFERSIZE - ETH_A_txBufferRead) + ETH_A_txBufferWrite;
            }

            /* Enable Tx interrupt. */
            #if(ETH_A_TX_INTERRUPT_ENABLED)
                ETH_A_EnableTxInt();
            #endif /* End ETH_A_TX_INTERRUPT_ENABLED */

        #else /* ETH_A_TXBUFFERSIZE > ETH_A_FIFO_LENGTH */

            size = ETH_A_TXSTATUS_REG;

            /* Is the fifo is full. */
            if((size & ETH_A_TX_STS_FIFO_FULL) != 0u)
            {
                size = ETH_A_FIFO_LENGTH;
            }
            else if((size & ETH_A_TX_STS_FIFO_EMPTY) != 0u)
            {
                size = 0u;
            }
            else
            {
                /* We only know there is data in the fifo. */
                size = 1u;
            }

        #endif /* End ETH_A_TXBUFFERSIZE > ETH_A_FIFO_LENGTH */

        return(size);
    }


    /*******************************************************************************
    * Function Name: ETH_A_ClearTxBuffer
    ********************************************************************************
    *
    * Summary:
    *  Clears the TX RAM buffer by setting the read and write pointers both to zero.
    *  Clears the hardware TX FIFO.  Any data present in the FIFO will not be sent.
    *
    * Parameters:
    *  None.
    *
    * Return:
    *  None.
    *
    * Global Variables:
    *  ETH_A_txBufferWrite - cleared to zero.
    *  ETH_A_txBufferRead - cleared to zero.
    *
    * Reentrant:
    *  No.
    *
    * Theory:
    *  Setting the pointers to zero makes the system believe there is no data to
    *  read and writing will resume at address 0 overwriting any data that may have
    *  remained in the RAM.
    *
    * Side Effects:
    *  Any received data not read from the RAM buffer will be lost when overwritten.
    *
    *******************************************************************************/
    void ETH_A_ClearTxBuffer(void) 
    {
        uint8 enableInterrupts;

        /* Enter critical section */
        enableInterrupts = CyEnterCriticalSection();
        /* clear the HW FIFO */
        ETH_A_TXDATA_AUX_CTL_REG |=  ETH_A_TX_FIFO_CLR;
        ETH_A_TXDATA_AUX_CTL_REG &= (uint8)~ETH_A_TX_FIFO_CLR;
        /* Exit critical section */
        CyExitCriticalSection(enableInterrupts);

        #if(ETH_A_TXBUFFERSIZE > ETH_A_FIFO_LENGTH)

            /* Disable Tx interrupt. */
            /* Protect variables that could change on interrupt. */
            #if(ETH_A_TX_INTERRUPT_ENABLED)
                ETH_A_DisableTxInt();
            #endif /* End ETH_A_TX_INTERRUPT_ENABLED */

            ETH_A_txBufferRead = 0u;
            ETH_A_txBufferWrite = 0u;

            /* Enable Tx interrupt. */
            #if(ETH_A_TX_INTERRUPT_ENABLED)
                ETH_A_EnableTxInt();
            #endif /* End ETH_A_TX_INTERRUPT_ENABLED */

        #endif /* End ETH_A_TXBUFFERSIZE > ETH_A_FIFO_LENGTH */
    }


    /*******************************************************************************
    * Function Name: ETH_A_SendBreak
    ********************************************************************************
    *
    * Summary:
    *  Write a Break command to the UART
    *
    * Parameters:
    *  uint8 retMode:  Wait mode,
    *   0 - Initialize registers for Break, sends the Break signal and return
    *       imediately.
    *   1 - Wait until Break sending is complete, reinitialize registers to normal
    *       transmission mode then return.
    *   2 - Reinitialize registers to normal transmission mode then return.
    *   3 - both steps: 0 and 1
    *       init registers for Break, send Break signal
    *       wait until Break sending is complete, reinit registers to normal
    *       transmission mode then return.
    *
    * Return:
    *  None.
    *
    * Global Variables:
    *  ETH_A_initVar - checked to identify that the component has been
    *     initialized.
    *  tx_period - static variable, used for keeping TX period configuration.
    *
    * Reentrant:
    *  No.
    *
    * Theory:
    *  SendBreak function initializes registers to send 13-bit break signal. It is
    *  important to return the registers configuration to normal for continue 8-bit
    *  operation.
    *  Trere are 3 variants for this API usage:
    *  1) SendBreak(3) - function will send the Break signal and take care on the
    *     configuration returning. Funcition will block CPU untill transmition
    *     complete.
    *  2) User may want to use bloking time if UART configured to the low speed
    *     operation
    *     Emample for this case:
    *     SendBreak(0);     - init Break signal transmition
    *         Add your code here to use CPU time
    *     SendBreak(1);     - complete Break operation
    *  3) Same to 2) but user may want to init and use the interrupt for complete
    *     break operation.
    *     Example for this case:
    *     Init TX interrupt whith "TX - On TX Complete" parameter
    *     SendBreak(0);     - init Break signal transmition
    *         Add your code here to use CPU time
    *     When interrupt appear with UART_TX_STS_COMPLETE status:
    *     SendBreak(2);     - complete Break operation
    *
    * Side Effects:
    *   Uses static variable to keep registers configuration.
    *
    *******************************************************************************/
    void ETH_A_SendBreak(uint8 retMode) 
    {

        /* If not Initialized then skip this function*/
        if(ETH_A_initVar != 0u)
        {
            /*Set the Counter to 13-bits and transmit a 00 byte*/
            /*When that is done then reset the counter value back*/
            uint8 tmpStat;

            #if(ETH_A_HD_ENABLED) /* Half Duplex mode*/

                if( (retMode == ETH_A_SEND_BREAK) ||
                    (retMode == ETH_A_SEND_WAIT_REINIT ) )
                {
                    /* CTRL_HD_SEND_BREAK - sends break bits in HD mode*/
                    ETH_A_WriteControlRegister(ETH_A_ReadControlRegister() |
                                                          ETH_A_CTRL_HD_SEND_BREAK);
                    /* Send zeros*/
                    ETH_A_TXDATA_REG = 0u;

                    do /*wait until transmit starts*/
                    {
                        tmpStat = ETH_A_TXSTATUS_REG;
                    }while((tmpStat & ETH_A_TX_STS_FIFO_EMPTY) != 0u);
                }

                if( (retMode == ETH_A_WAIT_FOR_COMPLETE_REINIT) ||
                    (retMode == ETH_A_SEND_WAIT_REINIT) )
                {
                    do /*wait until transmit complete*/
                    {
                        tmpStat = ETH_A_TXSTATUS_REG;
                    }while(((uint8)~tmpStat & ETH_A_TX_STS_COMPLETE) != 0u);
                }

                if( (retMode == ETH_A_WAIT_FOR_COMPLETE_REINIT) ||
                    (retMode == ETH_A_REINIT) ||
                    (retMode == ETH_A_SEND_WAIT_REINIT) )
                {
                    ETH_A_WriteControlRegister(ETH_A_ReadControlRegister() &
                                                  (uint8)~ETH_A_CTRL_HD_SEND_BREAK);
                }

            #else /* ETH_A_HD_ENABLED Full Duplex mode */

                static uint8 tx_period;

                if( (retMode == ETH_A_SEND_BREAK) ||
                    (retMode == ETH_A_SEND_WAIT_REINIT) )
                {
                    /* CTRL_HD_SEND_BREAK - skip to send parity bit at Break signal in Full Duplex mode*/
                    #if( (ETH_A_PARITY_TYPE != ETH_A__B_UART__NONE_REVB) || \
                                        (ETH_A_PARITY_TYPE_SW != 0u) )
                        ETH_A_WriteControlRegister(ETH_A_ReadControlRegister() |
                                                              ETH_A_CTRL_HD_SEND_BREAK);
                    #endif /* End ETH_A_PARITY_TYPE != ETH_A__B_UART__NONE_REVB  */

                    #if(ETH_A_TXCLKGEN_DP)
                        tx_period = ETH_A_TXBITCLKTX_COMPLETE_REG;
                        ETH_A_TXBITCLKTX_COMPLETE_REG = ETH_A_TXBITCTR_BREAKBITS;
                    #else
                        tx_period = ETH_A_TXBITCTR_PERIOD_REG;
                        ETH_A_TXBITCTR_PERIOD_REG = ETH_A_TXBITCTR_BREAKBITS8X;
                    #endif /* End ETH_A_TXCLKGEN_DP */

                    /* Send zeros*/
                    ETH_A_TXDATA_REG = 0u;

                    do /* wait until transmit starts */
                    {
                        tmpStat = ETH_A_TXSTATUS_REG;
                    }while((tmpStat & ETH_A_TX_STS_FIFO_EMPTY) != 0u);
                }

                if( (retMode == ETH_A_WAIT_FOR_COMPLETE_REINIT) ||
                    (retMode == ETH_A_SEND_WAIT_REINIT) )
                {
                    do /*wait until transmit complete*/
                    {
                        tmpStat = ETH_A_TXSTATUS_REG;
                    }while(((uint8)~tmpStat & ETH_A_TX_STS_COMPLETE) != 0u);
                }

                if( (retMode == ETH_A_WAIT_FOR_COMPLETE_REINIT) ||
                    (retMode == ETH_A_REINIT) ||
                    (retMode == ETH_A_SEND_WAIT_REINIT) )
                {

                    #if(ETH_A_TXCLKGEN_DP)
                        ETH_A_TXBITCLKTX_COMPLETE_REG = tx_period;
                    #else
                        ETH_A_TXBITCTR_PERIOD_REG = tx_period;
                    #endif /* End ETH_A_TXCLKGEN_DP */

                    #if( (ETH_A_PARITY_TYPE != ETH_A__B_UART__NONE_REVB) || \
                         (ETH_A_PARITY_TYPE_SW != 0u) )
                        ETH_A_WriteControlRegister(ETH_A_ReadControlRegister() &
                                                      (uint8)~ETH_A_CTRL_HD_SEND_BREAK);
                    #endif /* End ETH_A_PARITY_TYPE != NONE */
                }
            #endif    /* End ETH_A_HD_ENABLED */
        }
    }


    /*******************************************************************************
    * Function Name: ETH_A_SetTxAddressMode
    ********************************************************************************
    *
    * Summary:
    *  Set the transmit addressing mode
    *
    * Parameters:
    *  addressMode: 0 -> Space
    *               1 -> Mark
    *
    * Return:
    *  None.
    *
    *******************************************************************************/
    void ETH_A_SetTxAddressMode(uint8 addressMode) 
    {
        /* Mark/Space sending enable*/
        if(addressMode != 0u)
        {
            #if( ETH_A_CONTROL_REG_REMOVED == 0u )
                ETH_A_WriteControlRegister(ETH_A_ReadControlRegister() |
                                                      ETH_A_CTRL_MARK);
            #endif /* End ETH_A_CONTROL_REG_REMOVED == 0u */
        }
        else
        {
            #if( ETH_A_CONTROL_REG_REMOVED == 0u )
                ETH_A_WriteControlRegister(ETH_A_ReadControlRegister() &
                                                    (uint8)~ETH_A_CTRL_MARK);
            #endif /* End ETH_A_CONTROL_REG_REMOVED == 0u */
        }
    }

#endif  /* EndETH_A_TX_ENABLED */

#if(ETH_A_HD_ENABLED)


    /*******************************************************************************
    * Function Name: ETH_A_LoadTxConfig
    ********************************************************************************
    *
    * Summary:
    *  Unloads the Rx configuration if required and loads the
    *  Tx configuration. It is the users responsibility to ensure that any
    *  transaction is complete and it is safe to unload the Tx
    *  configuration.
    *
    * Parameters:
    *  None.
    *
    * Return:
    *  None.
    *
    * Theory:
    *  Valid only for half duplex UART.
    *
    * Side Effects:
    *  Disable RX interrupt mask, when software buffer has been used.
    *
    *******************************************************************************/
    void ETH_A_LoadTxConfig(void) 
    {
        #if((ETH_A_RX_INTERRUPT_ENABLED) && (ETH_A_RXBUFFERSIZE > ETH_A_FIFO_LENGTH))
            /* Disable RX interrupts before set TX configuration */
            ETH_A_SetRxInterruptMode(0u);
        #endif /* ETH_A_RX_INTERRUPT_ENABLED */

        ETH_A_WriteControlRegister(ETH_A_ReadControlRegister() | ETH_A_CTRL_HD_SEND);
        ETH_A_RXBITCTR_PERIOD_REG = ETH_A_HD_TXBITCTR_INIT;
        #if(CY_UDB_V0) /* Manually clear status register when mode has been changed */
            /* Clear status register */
            CY_GET_REG8(ETH_A_RXSTATUS_PTR);
        #endif /* CY_UDB_V0 */
    }


    /*******************************************************************************
    * Function Name: ETH_A_LoadRxConfig
    ********************************************************************************
    *
    * Summary:
    *  Unloads the Tx configuration if required and loads the
    *  Rx configuration. It is the users responsibility to ensure that any
    *  transaction is complete and it is safe to unload the Rx
    *  configuration.
    *
    * Parameters:
    *  None.
    *
    * Return:
    *  None.
    *
    * Theory:
    *  Valid only for half duplex UART
    *
    * Side Effects:
    *  Set RX interrupt mask based on customizer settings, when software buffer
    *  has been used.
    *
    *******************************************************************************/
    void ETH_A_LoadRxConfig(void) 
    {
        ETH_A_WriteControlRegister(ETH_A_ReadControlRegister() &
                                                (uint8)~ETH_A_CTRL_HD_SEND);
        ETH_A_RXBITCTR_PERIOD_REG = ETH_A_HD_RXBITCTR_INIT;
        #if(CY_UDB_V0) /* Manually clear status register when mode has been changed */
            /* Clear status register */
            CY_GET_REG8(ETH_A_RXSTATUS_PTR);
        #endif /* CY_UDB_V0 */

        #if((ETH_A_RX_INTERRUPT_ENABLED) && (ETH_A_RXBUFFERSIZE > ETH_A_FIFO_LENGTH))
            /* Enable RX interrupt after set RX configuration */
            ETH_A_SetRxInterruptMode(ETH_A_INIT_RX_INTERRUPTS_MASK);
        #endif /* ETH_A_RX_INTERRUPT_ENABLED */
    }

#endif  /* ETH_A_HD_ENABLED */


/* [] END OF FILE */
