/*******************************************************************************
* File Name: ETH_A_PM.c
* Version 2.30
*
* Description:
*  This file provides Sleep/WakeUp APIs functionality.
*
* Note:
*
********************************************************************************
* Copyright 2008-2012, Cypress Semiconductor Corporation.  All rights reserved.
* You may use this file only in accordance with the license, terms, conditions,
* disclaimers, and limitations in the end user license agreement accompanying
* the software package with which this file was provided.
*******************************************************************************/

#include "ETH_A.h"


/***************************************
* Local data allocation
***************************************/

static ETH_A_BACKUP_STRUCT  ETH_A_backup =
{
    /* enableState - disabled */
    0u,
};



/*******************************************************************************
* Function Name: ETH_A_SaveConfig
********************************************************************************
*
* Summary:
*  Saves the current user configuration.
*
* Parameters:
*  None.
*
* Return:
*  None.
*
* Global Variables:
*  ETH_A_backup - modified when non-retention registers are saved.
*
* Reentrant:
*  No.
*
*******************************************************************************/
void ETH_A_SaveConfig(void)
{
    #if (CY_UDB_V0)

        #if(ETH_A_CONTROL_REG_REMOVED == 0u)
            ETH_A_backup.cr = ETH_A_CONTROL_REG;
        #endif /* End ETH_A_CONTROL_REG_REMOVED */

        #if( (ETH_A_RX_ENABLED) || (ETH_A_HD_ENABLED) )
            ETH_A_backup.rx_period = ETH_A_RXBITCTR_PERIOD_REG;
            ETH_A_backup.rx_mask = ETH_A_RXSTATUS_MASK_REG;
            #if (ETH_A_RXHW_ADDRESS_ENABLED)
                ETH_A_backup.rx_addr1 = ETH_A_RXADDRESS1_REG;
                ETH_A_backup.rx_addr2 = ETH_A_RXADDRESS2_REG;
            #endif /* End ETH_A_RXHW_ADDRESS_ENABLED */
        #endif /* End ETH_A_RX_ENABLED | ETH_A_HD_ENABLED*/

        #if(ETH_A_TX_ENABLED)
            #if(ETH_A_TXCLKGEN_DP)
                ETH_A_backup.tx_clk_ctr = ETH_A_TXBITCLKGEN_CTR_REG;
                ETH_A_backup.tx_clk_compl = ETH_A_TXBITCLKTX_COMPLETE_REG;
            #else
                ETH_A_backup.tx_period = ETH_A_TXBITCTR_PERIOD_REG;
            #endif /*End ETH_A_TXCLKGEN_DP */
            ETH_A_backup.tx_mask = ETH_A_TXSTATUS_MASK_REG;
        #endif /*End ETH_A_TX_ENABLED */


    #else /* CY_UDB_V1 */

        #if(ETH_A_CONTROL_REG_REMOVED == 0u)
            ETH_A_backup.cr = ETH_A_CONTROL_REG;
        #endif /* End ETH_A_CONTROL_REG_REMOVED */

    #endif  /* End CY_UDB_V0 */
}


/*******************************************************************************
* Function Name: ETH_A_RestoreConfig
********************************************************************************
*
* Summary:
*  Restores the current user configuration.
*
* Parameters:
*  None.
*
* Return:
*  None.
*
* Global Variables:
*  ETH_A_backup - used when non-retention registers are restored.
*
* Reentrant:
*  No.
*
*******************************************************************************/
void ETH_A_RestoreConfig(void)
{

    #if (CY_UDB_V0)

        #if(ETH_A_CONTROL_REG_REMOVED == 0u)
            ETH_A_CONTROL_REG = ETH_A_backup.cr;
        #endif /* End ETH_A_CONTROL_REG_REMOVED */

        #if( (ETH_A_RX_ENABLED) || (ETH_A_HD_ENABLED) )
            ETH_A_RXBITCTR_PERIOD_REG = ETH_A_backup.rx_period;
            ETH_A_RXSTATUS_MASK_REG = ETH_A_backup.rx_mask;
            #if (ETH_A_RXHW_ADDRESS_ENABLED)
                ETH_A_RXADDRESS1_REG = ETH_A_backup.rx_addr1;
                ETH_A_RXADDRESS2_REG = ETH_A_backup.rx_addr2;
            #endif /* End ETH_A_RXHW_ADDRESS_ENABLED */
        #endif  /* End (ETH_A_RX_ENABLED) || (ETH_A_HD_ENABLED) */

        #if(ETH_A_TX_ENABLED)
            #if(ETH_A_TXCLKGEN_DP)
                ETH_A_TXBITCLKGEN_CTR_REG = ETH_A_backup.tx_clk_ctr;
                ETH_A_TXBITCLKTX_COMPLETE_REG = ETH_A_backup.tx_clk_compl;
            #else
                ETH_A_TXBITCTR_PERIOD_REG = ETH_A_backup.tx_period;
            #endif /*End ETH_A_TXCLKGEN_DP */
            ETH_A_TXSTATUS_MASK_REG = ETH_A_backup.tx_mask;
        #endif /*End ETH_A_TX_ENABLED */

    #else /* CY_UDB_V1 */

        #if(ETH_A_CONTROL_REG_REMOVED == 0u)
            ETH_A_CONTROL_REG = ETH_A_backup.cr;
        #endif /* End ETH_A_CONTROL_REG_REMOVED */

    #endif  /* End CY_UDB_V0 */
}


/*******************************************************************************
* Function Name: ETH_A_Sleep
********************************************************************************
*
* Summary:
*  Stops and saves the user configuration. Should be called
*  just prior to entering sleep.
*
*
* Parameters:
*  None.
*
* Return:
*  None.
*
* Global Variables:
*  ETH_A_backup - modified when non-retention registers are saved.
*
* Reentrant:
*  No.
*
*******************************************************************************/
void ETH_A_Sleep(void)
{

    #if(ETH_A_RX_ENABLED || ETH_A_HD_ENABLED)
        if((ETH_A_RXSTATUS_ACTL_REG  & ETH_A_INT_ENABLE) != 0u)
        {
            ETH_A_backup.enableState = 1u;
        }
        else
        {
            ETH_A_backup.enableState = 0u;
        }
    #else
        if((ETH_A_TXSTATUS_ACTL_REG  & ETH_A_INT_ENABLE) !=0u)
        {
            ETH_A_backup.enableState = 1u;
        }
        else
        {
            ETH_A_backup.enableState = 0u;
        }
    #endif /* End ETH_A_RX_ENABLED || ETH_A_HD_ENABLED*/

    ETH_A_Stop();
    ETH_A_SaveConfig();
}


/*******************************************************************************
* Function Name: ETH_A_Wakeup
********************************************************************************
*
* Summary:
*  Restores and enables the user configuration. Should be called
*  just after awaking from sleep.
*
* Parameters:
*  None.
*
* Return:
*  None.
*
* Global Variables:
*  ETH_A_backup - used when non-retention registers are restored.
*
* Reentrant:
*  No.
*
*******************************************************************************/
void ETH_A_Wakeup(void)
{
    ETH_A_RestoreConfig();
    #if( (ETH_A_RX_ENABLED) || (ETH_A_HD_ENABLED) )
        ETH_A_ClearRxBuffer();
    #endif /* End (ETH_A_RX_ENABLED) || (ETH_A_HD_ENABLED) */
    #if(ETH_A_TX_ENABLED || ETH_A_HD_ENABLED)
        ETH_A_ClearTxBuffer();
    #endif /* End ETH_A_TX_ENABLED || ETH_A_HD_ENABLED */

    if(ETH_A_backup.enableState != 0u)
    {
        ETH_A_Enable();
    }
}


/* [] END OF FILE */
