/*******************************************************************************
* File Name: ETH_B.h
* Version 2.30
*
* Description:
*  Contains the function prototypes and constants available to the UART
*  user module.
*
* Note:
*
********************************************************************************
* Copyright 2008-2012, Cypress Semiconductor Corporation.  All rights reserved.
* You may use this file only in accordance with the license, terms, conditions,
* disclaimers, and limitations in the end user license agreement accompanying
* the software package with which this file was provided.
*******************************************************************************/


#if !defined(CY_UART_ETH_B_H)
#define CY_UART_ETH_B_H

#include "cytypes.h"
#include "cyfitter.h"
#include "CyLib.h"


/***************************************
* Conditional Compilation Parameters
***************************************/

#define ETH_B_RX_ENABLED                     (1u)
#define ETH_B_TX_ENABLED                     (1u)
#define ETH_B_HD_ENABLED                     (0u)
#define ETH_B_RX_INTERRUPT_ENABLED           (0u)
#define ETH_B_TX_INTERRUPT_ENABLED           (0u)
#define ETH_B_INTERNAL_CLOCK_USED            (1u)
#define ETH_B_RXHW_ADDRESS_ENABLED           (0u)
#define ETH_B_OVER_SAMPLE_COUNT              (8u)
#define ETH_B_PARITY_TYPE                    (0u)
#define ETH_B_PARITY_TYPE_SW                 (0u)
#define ETH_B_BREAK_DETECT                   (0u)
#define ETH_B_BREAK_BITS_TX                  (13u)
#define ETH_B_BREAK_BITS_RX                  (13u)
#define ETH_B_TXCLKGEN_DP                    (1u)
#define ETH_B_USE23POLLING                   (1u)
#define ETH_B_FLOW_CONTROL                   (0u)
#define ETH_B_CLK_FREQ                       (0u)
#define ETH_B_TXBUFFERSIZE                   (4u)
#define ETH_B_RXBUFFERSIZE                   (4u)

/* Check to see if required defines such as CY_PSOC5LP are available */
/* They are defined starting with cy_boot v3.0 */
#if !defined (CY_PSOC5LP)
    #error Component UART_v2_30 requires cy_boot v3.0 or later
#endif /* (CY_PSOC5LP) */

#ifdef ETH_B_BUART_sCR_SyncCtl_CtrlReg__CONTROL_REG
    #define ETH_B_CONTROL_REG_REMOVED            (0u)
#else
    #define ETH_B_CONTROL_REG_REMOVED            (1u)
#endif /* End ETH_B_BUART_sCR_SyncCtl_CtrlReg__CONTROL_REG */


/***************************************
*      Data Struct Definition
***************************************/

/* Sleep Mode API Support */
typedef struct ETH_B_backupStruct_
{
    uint8 enableState;

    #if(ETH_B_CONTROL_REG_REMOVED == 0u)
        uint8 cr;
    #endif /* End ETH_B_CONTROL_REG_REMOVED */
    #if( (ETH_B_RX_ENABLED) || (ETH_B_HD_ENABLED) )
        uint8 rx_period;
        #if (CY_UDB_V0)
            uint8 rx_mask;
            #if (ETH_B_RXHW_ADDRESS_ENABLED)
                uint8 rx_addr1;
                uint8 rx_addr2;
            #endif /* End ETH_B_RXHW_ADDRESS_ENABLED */
        #endif /* End CY_UDB_V0 */
    #endif  /* End (ETH_B_RX_ENABLED) || (ETH_B_HD_ENABLED)*/

    #if(ETH_B_TX_ENABLED)
        #if(ETH_B_TXCLKGEN_DP)
            uint8 tx_clk_ctr;
            #if (CY_UDB_V0)
                uint8 tx_clk_compl;
            #endif  /* End CY_UDB_V0 */
        #else
            uint8 tx_period;
        #endif /*End ETH_B_TXCLKGEN_DP */
        #if (CY_UDB_V0)
            uint8 tx_mask;
        #endif  /* End CY_UDB_V0 */
    #endif /*End ETH_B_TX_ENABLED */
} ETH_B_BACKUP_STRUCT;


/***************************************
*       Function Prototypes
***************************************/

void ETH_B_Start(void) ;
void ETH_B_Stop(void) ;
uint8 ETH_B_ReadControlRegister(void) ;
void ETH_B_WriteControlRegister(uint8 control) ;

void ETH_B_Init(void) ;
void ETH_B_Enable(void) ;
void ETH_B_SaveConfig(void) ;
void ETH_B_RestoreConfig(void) ;
void ETH_B_Sleep(void) ;
void ETH_B_Wakeup(void) ;

/* Only if RX is enabled */
#if( (ETH_B_RX_ENABLED) || (ETH_B_HD_ENABLED) )

    #if(ETH_B_RX_INTERRUPT_ENABLED)
        void  ETH_B_EnableRxInt(void) ;
        void  ETH_B_DisableRxInt(void) ;
        CY_ISR_PROTO(ETH_B_RXISR);
    #endif /* ETH_B_RX_INTERRUPT_ENABLED */

    void ETH_B_SetRxAddressMode(uint8 addressMode)
                                                           ;
    void ETH_B_SetRxAddress1(uint8 address) ;
    void ETH_B_SetRxAddress2(uint8 address) ;

    void  ETH_B_SetRxInterruptMode(uint8 intSrc) ;
    uint8 ETH_B_ReadRxData(void) ;
    uint8 ETH_B_ReadRxStatus(void) ;
    uint8 ETH_B_GetChar(void) ;
    uint16 ETH_B_GetByte(void) ;
    uint8 ETH_B_GetRxBufferSize(void)
                                                            ;
    void ETH_B_ClearRxBuffer(void) ;

    /* Obsolete functions, defines for backward compatible */
    #define ETH_B_GetRxInterruptSource   ETH_B_ReadRxStatus

#endif /* End (ETH_B_RX_ENABLED) || (ETH_B_HD_ENABLED) */

/* Only if TX is enabled */
#if(ETH_B_TX_ENABLED || ETH_B_HD_ENABLED)

    #if(ETH_B_TX_INTERRUPT_ENABLED)
        void ETH_B_EnableTxInt(void) ;
        void ETH_B_DisableTxInt(void) ;
        CY_ISR_PROTO(ETH_B_TXISR);
    #endif /* ETH_B_TX_INTERRUPT_ENABLED */

    void ETH_B_SetTxInterruptMode(uint8 intSrc) ;
    void ETH_B_WriteTxData(uint8 txDataByte) ;
    uint8 ETH_B_ReadTxStatus(void) ;
    void ETH_B_PutChar(uint8 txDataByte) ;
    void ETH_B_PutString(const char8 string[]) ;
    void ETH_B_PutArray(const uint8 string[], uint8 byteCount)
                                                            ;
    void ETH_B_PutCRLF(uint8 txDataByte) ;
    void ETH_B_ClearTxBuffer(void) ;
    void ETH_B_SetTxAddressMode(uint8 addressMode) ;
    void ETH_B_SendBreak(uint8 retMode) ;
    uint8 ETH_B_GetTxBufferSize(void)
                                                            ;
    /* Obsolete functions, defines for backward compatible */
    #define ETH_B_PutStringConst         ETH_B_PutString
    #define ETH_B_PutArrayConst          ETH_B_PutArray
    #define ETH_B_GetTxInterruptSource   ETH_B_ReadTxStatus

#endif /* End ETH_B_TX_ENABLED || ETH_B_HD_ENABLED */

#if(ETH_B_HD_ENABLED)
    void ETH_B_LoadRxConfig(void) ;
    void ETH_B_LoadTxConfig(void) ;
#endif /* End ETH_B_HD_ENABLED */


/* Communication bootloader APIs */
#if defined(CYDEV_BOOTLOADER_IO_COMP) && ((CYDEV_BOOTLOADER_IO_COMP == CyBtldr_ETH_B) || \
                                          (CYDEV_BOOTLOADER_IO_COMP == CyBtldr_Custom_Interface))
    /* Physical layer functions */
    void    ETH_B_CyBtldrCommStart(void) CYSMALL ;
    void    ETH_B_CyBtldrCommStop(void) CYSMALL ;
    void    ETH_B_CyBtldrCommReset(void) CYSMALL ;
    cystatus ETH_B_CyBtldrCommWrite(const uint8 pData[], uint16 size, uint16 * count, uint8 timeOut) CYSMALL
             ;
    cystatus ETH_B_CyBtldrCommRead(uint8 pData[], uint16 size, uint16 * count, uint8 timeOut) CYSMALL
             ;

    #if (CYDEV_BOOTLOADER_IO_COMP == CyBtldr_ETH_B)
        #define CyBtldrCommStart    ETH_B_CyBtldrCommStart
        #define CyBtldrCommStop     ETH_B_CyBtldrCommStop
        #define CyBtldrCommReset    ETH_B_CyBtldrCommReset
        #define CyBtldrCommWrite    ETH_B_CyBtldrCommWrite
        #define CyBtldrCommRead     ETH_B_CyBtldrCommRead
    #endif  /* (CYDEV_BOOTLOADER_IO_COMP == CyBtldr_ETH_B) */

    /* Byte to Byte time out for detecting end of block data from host */
    #define ETH_B_BYTE2BYTE_TIME_OUT (25u)

#endif /* CYDEV_BOOTLOADER_IO_COMP */


/***************************************
*          API Constants
***************************************/
/* Parameters for SetTxAddressMode API*/
#define ETH_B_SET_SPACE                              (0x00u)
#define ETH_B_SET_MARK                               (0x01u)

/* Status Register definitions */
#if( (ETH_B_TX_ENABLED) || (ETH_B_HD_ENABLED) )
    #if(ETH_B_TX_INTERRUPT_ENABLED)
        #define ETH_B_TX_VECT_NUM            (uint8)ETH_B_TXInternalInterrupt__INTC_NUMBER
        #define ETH_B_TX_PRIOR_NUM           (uint8)ETH_B_TXInternalInterrupt__INTC_PRIOR_NUM
    #endif /* ETH_B_TX_INTERRUPT_ENABLED */
    #if(ETH_B_TX_ENABLED)
        #define ETH_B_TX_STS_COMPLETE_SHIFT          (0x00u)
        #define ETH_B_TX_STS_FIFO_EMPTY_SHIFT        (0x01u)
        #define ETH_B_TX_STS_FIFO_FULL_SHIFT         (0x02u)
        #define ETH_B_TX_STS_FIFO_NOT_FULL_SHIFT     (0x03u)
    #endif /* ETH_B_TX_ENABLED */
    #if(ETH_B_HD_ENABLED)
        #define ETH_B_TX_STS_COMPLETE_SHIFT          (0x00u)
        #define ETH_B_TX_STS_FIFO_EMPTY_SHIFT        (0x01u)
        #define ETH_B_TX_STS_FIFO_FULL_SHIFT         (0x05u)  /*needs MD=0*/
        #define ETH_B_TX_STS_FIFO_NOT_FULL_SHIFT     (0x03u)
    #endif /* ETH_B_HD_ENABLED */
    #define ETH_B_TX_STS_COMPLETE            (uint8)(0x01u << ETH_B_TX_STS_COMPLETE_SHIFT)
    #define ETH_B_TX_STS_FIFO_EMPTY          (uint8)(0x01u << ETH_B_TX_STS_FIFO_EMPTY_SHIFT)
    #define ETH_B_TX_STS_FIFO_FULL           (uint8)(0x01u << ETH_B_TX_STS_FIFO_FULL_SHIFT)
    #define ETH_B_TX_STS_FIFO_NOT_FULL       (uint8)(0x01u << ETH_B_TX_STS_FIFO_NOT_FULL_SHIFT)
#endif /* End (ETH_B_TX_ENABLED) || (ETH_B_HD_ENABLED)*/

#if( (ETH_B_RX_ENABLED) || (ETH_B_HD_ENABLED) )
    #if(ETH_B_RX_INTERRUPT_ENABLED)
        #define ETH_B_RX_VECT_NUM            (uint8)ETH_B_RXInternalInterrupt__INTC_NUMBER
        #define ETH_B_RX_PRIOR_NUM           (uint8)ETH_B_RXInternalInterrupt__INTC_PRIOR_NUM
    #endif /* ETH_B_RX_INTERRUPT_ENABLED */
    #define ETH_B_RX_STS_MRKSPC_SHIFT            (0x00u)
    #define ETH_B_RX_STS_BREAK_SHIFT             (0x01u)
    #define ETH_B_RX_STS_PAR_ERROR_SHIFT         (0x02u)
    #define ETH_B_RX_STS_STOP_ERROR_SHIFT        (0x03u)
    #define ETH_B_RX_STS_OVERRUN_SHIFT           (0x04u)
    #define ETH_B_RX_STS_FIFO_NOTEMPTY_SHIFT     (0x05u)
    #define ETH_B_RX_STS_ADDR_MATCH_SHIFT        (0x06u)
    #define ETH_B_RX_STS_SOFT_BUFF_OVER_SHIFT    (0x07u)

    #define ETH_B_RX_STS_MRKSPC           (uint8)(0x01u << ETH_B_RX_STS_MRKSPC_SHIFT)
    #define ETH_B_RX_STS_BREAK            (uint8)(0x01u << ETH_B_RX_STS_BREAK_SHIFT)
    #define ETH_B_RX_STS_PAR_ERROR        (uint8)(0x01u << ETH_B_RX_STS_PAR_ERROR_SHIFT)
    #define ETH_B_RX_STS_STOP_ERROR       (uint8)(0x01u << ETH_B_RX_STS_STOP_ERROR_SHIFT)
    #define ETH_B_RX_STS_OVERRUN          (uint8)(0x01u << ETH_B_RX_STS_OVERRUN_SHIFT)
    #define ETH_B_RX_STS_FIFO_NOTEMPTY    (uint8)(0x01u << ETH_B_RX_STS_FIFO_NOTEMPTY_SHIFT)
    #define ETH_B_RX_STS_ADDR_MATCH       (uint8)(0x01u << ETH_B_RX_STS_ADDR_MATCH_SHIFT)
    #define ETH_B_RX_STS_SOFT_BUFF_OVER   (uint8)(0x01u << ETH_B_RX_STS_SOFT_BUFF_OVER_SHIFT)
    #define ETH_B_RX_HW_MASK                     (0x7Fu)
#endif /* End (ETH_B_RX_ENABLED) || (ETH_B_HD_ENABLED) */

/* Control Register definitions */
#define ETH_B_CTRL_HD_SEND_SHIFT                 (0x00u) /* 1 enable TX part in Half Duplex mode */
#define ETH_B_CTRL_HD_SEND_BREAK_SHIFT           (0x01u) /* 1 send BREAK signal in Half Duplez mode */
#define ETH_B_CTRL_MARK_SHIFT                    (0x02u) /* 1 sets mark, 0 sets space */
#define ETH_B_CTRL_PARITY_TYPE0_SHIFT            (0x03u) /* Defines the type of parity implemented */
#define ETH_B_CTRL_PARITY_TYPE1_SHIFT            (0x04u) /* Defines the type of parity implemented */
#define ETH_B_CTRL_RXADDR_MODE0_SHIFT            (0x05u)
#define ETH_B_CTRL_RXADDR_MODE1_SHIFT            (0x06u)
#define ETH_B_CTRL_RXADDR_MODE2_SHIFT            (0x07u)

#define ETH_B_CTRL_HD_SEND               (uint8)(0x01u << ETH_B_CTRL_HD_SEND_SHIFT)
#define ETH_B_CTRL_HD_SEND_BREAK         (uint8)(0x01u << ETH_B_CTRL_HD_SEND_BREAK_SHIFT)
#define ETH_B_CTRL_MARK                  (uint8)(0x01u << ETH_B_CTRL_MARK_SHIFT)
#define ETH_B_CTRL_PARITY_TYPE_MASK      (uint8)(0x03u << ETH_B_CTRL_PARITY_TYPE0_SHIFT)
#define ETH_B_CTRL_RXADDR_MODE_MASK      (uint8)(0x07u << ETH_B_CTRL_RXADDR_MODE0_SHIFT)

/* StatusI Register Interrupt Enable Control Bits. As defined by the Register map for the AUX Control Register */
#define ETH_B_INT_ENABLE                         (0x10u)

/* Bit Counter (7-bit) Control Register Bit Definitions. As defined by the Register map for the AUX Control Register */
#define ETH_B_CNTR_ENABLE                        (0x20u)

/*   Constants for SendBreak() "retMode" parameter  */
#define ETH_B_SEND_BREAK                         (0x00u)
#define ETH_B_WAIT_FOR_COMPLETE_REINIT           (0x01u)
#define ETH_B_REINIT                             (0x02u)
#define ETH_B_SEND_WAIT_REINIT                   (0x03u)

#define ETH_B_OVER_SAMPLE_8                      (8u)
#define ETH_B_OVER_SAMPLE_16                     (16u)

#define ETH_B_BIT_CENTER                         (ETH_B_OVER_SAMPLE_COUNT - 1u)

#define ETH_B_FIFO_LENGTH                        (4u)
#define ETH_B_NUMBER_OF_START_BIT                (1u)
#define ETH_B_MAX_BYTE_VALUE                     (0xFFu)

/* 8X always for count7 implementation*/
#define ETH_B_TXBITCTR_BREAKBITS8X   ((ETH_B_BREAK_BITS_TX * ETH_B_OVER_SAMPLE_8) - 1u)
/* 8X or 16X for DP implementation*/
#define ETH_B_TXBITCTR_BREAKBITS ((ETH_B_BREAK_BITS_TX * ETH_B_OVER_SAMPLE_COUNT) - 1u)

#define ETH_B_HALF_BIT_COUNT   \
                            (((ETH_B_OVER_SAMPLE_COUNT / 2u) + (ETH_B_USE23POLLING * 1u)) - 2u)
#if (ETH_B_OVER_SAMPLE_COUNT == ETH_B_OVER_SAMPLE_8)
    #define ETH_B_HD_TXBITCTR_INIT   (((ETH_B_BREAK_BITS_TX + \
                            ETH_B_NUMBER_OF_START_BIT) * ETH_B_OVER_SAMPLE_COUNT) - 1u)

    /* This parameter is increased on the 2 in 2 out of 3 mode to sample voting in the middle */
    #define ETH_B_RXBITCTR_INIT  ((((ETH_B_BREAK_BITS_RX + ETH_B_NUMBER_OF_START_BIT) \
                            * ETH_B_OVER_SAMPLE_COUNT) + ETH_B_HALF_BIT_COUNT) - 1u)


#else /* ETH_B_OVER_SAMPLE_COUNT == ETH_B_OVER_SAMPLE_16 */
    #define ETH_B_HD_TXBITCTR_INIT   ((8u * ETH_B_OVER_SAMPLE_COUNT) - 1u)
    /* 7bit counter need one more bit for OverSampleCount=16 */
    #define ETH_B_RXBITCTR_INIT      (((7u * ETH_B_OVER_SAMPLE_COUNT) - 1u) + \
                                                      ETH_B_HALF_BIT_COUNT)
#endif /* End ETH_B_OVER_SAMPLE_COUNT */
#define ETH_B_HD_RXBITCTR_INIT                   ETH_B_RXBITCTR_INIT


/***************************************
* Global variables external identifier
***************************************/

extern uint8 ETH_B_initVar;
#if( ETH_B_TX_ENABLED && (ETH_B_TXBUFFERSIZE > ETH_B_FIFO_LENGTH))
    extern volatile uint8 ETH_B_txBuffer[ETH_B_TXBUFFERSIZE];
    extern volatile uint8 ETH_B_txBufferRead;
    extern uint8 ETH_B_txBufferWrite;
#endif /* End ETH_B_TX_ENABLED */
#if( ( ETH_B_RX_ENABLED || ETH_B_HD_ENABLED ) && \
     (ETH_B_RXBUFFERSIZE > ETH_B_FIFO_LENGTH) )
    extern volatile uint8 ETH_B_rxBuffer[ETH_B_RXBUFFERSIZE];
    extern volatile uint8 ETH_B_rxBufferRead;
    extern volatile uint8 ETH_B_rxBufferWrite;
    extern volatile uint8 ETH_B_rxBufferLoopDetect;
    extern volatile uint8 ETH_B_rxBufferOverflow;
    #if (ETH_B_RXHW_ADDRESS_ENABLED)
        extern volatile uint8 ETH_B_rxAddressMode;
        extern volatile uint8 ETH_B_rxAddressDetected;
    #endif /* End EnableHWAddress */
#endif /* End ETH_B_RX_ENABLED */


/***************************************
* Enumerated Types and Parameters
***************************************/

#define ETH_B__B_UART__AM_SW_BYTE_BYTE 1
#define ETH_B__B_UART__AM_SW_DETECT_TO_BUFFER 2
#define ETH_B__B_UART__AM_HW_BYTE_BY_BYTE 3
#define ETH_B__B_UART__AM_HW_DETECT_TO_BUFFER 4
#define ETH_B__B_UART__AM_NONE 0

#define ETH_B__B_UART__NONE_REVB 0
#define ETH_B__B_UART__EVEN_REVB 1
#define ETH_B__B_UART__ODD_REVB 2
#define ETH_B__B_UART__MARK_SPACE_REVB 3



/***************************************
*    Initial Parameter Constants
***************************************/

/* UART shifts max 8 bits, Mark/Space functionality working if 9 selected */
#define ETH_B_NUMBER_OF_DATA_BITS    ((8u > 8u) ? 8u : 8u)
#define ETH_B_NUMBER_OF_STOP_BITS    (1u)

#if (ETH_B_RXHW_ADDRESS_ENABLED)
    #define ETH_B_RXADDRESSMODE      (0u)
    #define ETH_B_RXHWADDRESS1       (0u)
    #define ETH_B_RXHWADDRESS2       (0u)
    /* Backward compatible define */
    #define ETH_B_RXAddressMode      ETH_B_RXADDRESSMODE
#endif /* End EnableHWAddress */

#define ETH_B_INIT_RX_INTERRUPTS_MASK \
                                  (uint8)((1 << ETH_B_RX_STS_FIFO_NOTEMPTY_SHIFT) \
                                        | (0 << ETH_B_RX_STS_MRKSPC_SHIFT) \
                                        | (0 << ETH_B_RX_STS_ADDR_MATCH_SHIFT) \
                                        | (0 << ETH_B_RX_STS_PAR_ERROR_SHIFT) \
                                        | (0 << ETH_B_RX_STS_STOP_ERROR_SHIFT) \
                                        | (0 << ETH_B_RX_STS_BREAK_SHIFT) \
                                        | (0 << ETH_B_RX_STS_OVERRUN_SHIFT))

#define ETH_B_INIT_TX_INTERRUPTS_MASK \
                                  (uint8)((0 << ETH_B_TX_STS_COMPLETE_SHIFT) \
                                        | (0 << ETH_B_TX_STS_FIFO_EMPTY_SHIFT) \
                                        | (0 << ETH_B_TX_STS_FIFO_FULL_SHIFT) \
                                        | (0 << ETH_B_TX_STS_FIFO_NOT_FULL_SHIFT))


/***************************************
*              Registers
***************************************/

#ifdef ETH_B_BUART_sCR_SyncCtl_CtrlReg__CONTROL_REG
    #define ETH_B_CONTROL_REG \
                            (* (reg8 *) ETH_B_BUART_sCR_SyncCtl_CtrlReg__CONTROL_REG )
    #define ETH_B_CONTROL_PTR \
                            (  (reg8 *) ETH_B_BUART_sCR_SyncCtl_CtrlReg__CONTROL_REG )
#endif /* End ETH_B_BUART_sCR_SyncCtl_CtrlReg__CONTROL_REG */

#if(ETH_B_TX_ENABLED)
    #define ETH_B_TXDATA_REG          (* (reg8 *) ETH_B_BUART_sTX_TxShifter_u0__F0_REG)
    #define ETH_B_TXDATA_PTR          (  (reg8 *) ETH_B_BUART_sTX_TxShifter_u0__F0_REG)
    #define ETH_B_TXDATA_AUX_CTL_REG  (* (reg8 *) ETH_B_BUART_sTX_TxShifter_u0__DP_AUX_CTL_REG)
    #define ETH_B_TXDATA_AUX_CTL_PTR  (  (reg8 *) ETH_B_BUART_sTX_TxShifter_u0__DP_AUX_CTL_REG)
    #define ETH_B_TXSTATUS_REG        (* (reg8 *) ETH_B_BUART_sTX_TxSts__STATUS_REG)
    #define ETH_B_TXSTATUS_PTR        (  (reg8 *) ETH_B_BUART_sTX_TxSts__STATUS_REG)
    #define ETH_B_TXSTATUS_MASK_REG   (* (reg8 *) ETH_B_BUART_sTX_TxSts__MASK_REG)
    #define ETH_B_TXSTATUS_MASK_PTR   (  (reg8 *) ETH_B_BUART_sTX_TxSts__MASK_REG)
    #define ETH_B_TXSTATUS_ACTL_REG   (* (reg8 *) ETH_B_BUART_sTX_TxSts__STATUS_AUX_CTL_REG)
    #define ETH_B_TXSTATUS_ACTL_PTR   (  (reg8 *) ETH_B_BUART_sTX_TxSts__STATUS_AUX_CTL_REG)

    /* DP clock */
    #if(ETH_B_TXCLKGEN_DP)
        #define ETH_B_TXBITCLKGEN_CTR_REG        \
                                        (* (reg8 *) ETH_B_BUART_sTX_sCLOCK_TxBitClkGen__D0_REG)
        #define ETH_B_TXBITCLKGEN_CTR_PTR        \
                                        (  (reg8 *) ETH_B_BUART_sTX_sCLOCK_TxBitClkGen__D0_REG)
        #define ETH_B_TXBITCLKTX_COMPLETE_REG    \
                                        (* (reg8 *) ETH_B_BUART_sTX_sCLOCK_TxBitClkGen__D1_REG)
        #define ETH_B_TXBITCLKTX_COMPLETE_PTR    \
                                        (  (reg8 *) ETH_B_BUART_sTX_sCLOCK_TxBitClkGen__D1_REG)
    #else     /* Count7 clock*/
        #define ETH_B_TXBITCTR_PERIOD_REG    \
                                        (* (reg8 *) ETH_B_BUART_sTX_sCLOCK_TxBitCounter__PERIOD_REG)
        #define ETH_B_TXBITCTR_PERIOD_PTR    \
                                        (  (reg8 *) ETH_B_BUART_sTX_sCLOCK_TxBitCounter__PERIOD_REG)
        #define ETH_B_TXBITCTR_CONTROL_REG   \
                                        (* (reg8 *) ETH_B_BUART_sTX_sCLOCK_TxBitCounter__CONTROL_AUX_CTL_REG)
        #define ETH_B_TXBITCTR_CONTROL_PTR   \
                                        (  (reg8 *) ETH_B_BUART_sTX_sCLOCK_TxBitCounter__CONTROL_AUX_CTL_REG)
        #define ETH_B_TXBITCTR_COUNTER_REG   \
                                        (* (reg8 *) ETH_B_BUART_sTX_sCLOCK_TxBitCounter__COUNT_REG)
        #define ETH_B_TXBITCTR_COUNTER_PTR   \
                                        (  (reg8 *) ETH_B_BUART_sTX_sCLOCK_TxBitCounter__COUNT_REG)
    #endif /* ETH_B_TXCLKGEN_DP */

#endif /* End ETH_B_TX_ENABLED */

#if(ETH_B_HD_ENABLED)

    #define ETH_B_TXDATA_REG             (* (reg8 *) ETH_B_BUART_sRX_RxShifter_u0__F1_REG )
    #define ETH_B_TXDATA_PTR             (  (reg8 *) ETH_B_BUART_sRX_RxShifter_u0__F1_REG )
    #define ETH_B_TXDATA_AUX_CTL_REG     (* (reg8 *) ETH_B_BUART_sRX_RxShifter_u0__DP_AUX_CTL_REG)
    #define ETH_B_TXDATA_AUX_CTL_PTR     (  (reg8 *) ETH_B_BUART_sRX_RxShifter_u0__DP_AUX_CTL_REG)

    #define ETH_B_TXSTATUS_REG           (* (reg8 *) ETH_B_BUART_sRX_RxSts__STATUS_REG )
    #define ETH_B_TXSTATUS_PTR           (  (reg8 *) ETH_B_BUART_sRX_RxSts__STATUS_REG )
    #define ETH_B_TXSTATUS_MASK_REG      (* (reg8 *) ETH_B_BUART_sRX_RxSts__MASK_REG )
    #define ETH_B_TXSTATUS_MASK_PTR      (  (reg8 *) ETH_B_BUART_sRX_RxSts__MASK_REG )
    #define ETH_B_TXSTATUS_ACTL_REG      (* (reg8 *) ETH_B_BUART_sRX_RxSts__STATUS_AUX_CTL_REG )
    #define ETH_B_TXSTATUS_ACTL_PTR      (  (reg8 *) ETH_B_BUART_sRX_RxSts__STATUS_AUX_CTL_REG )
#endif /* End ETH_B_HD_ENABLED */

#if( (ETH_B_RX_ENABLED) || (ETH_B_HD_ENABLED) )
    #define ETH_B_RXDATA_REG             (* (reg8 *) ETH_B_BUART_sRX_RxShifter_u0__F0_REG )
    #define ETH_B_RXDATA_PTR             (  (reg8 *) ETH_B_BUART_sRX_RxShifter_u0__F0_REG )
    #define ETH_B_RXADDRESS1_REG         (* (reg8 *) ETH_B_BUART_sRX_RxShifter_u0__D0_REG )
    #define ETH_B_RXADDRESS1_PTR         (  (reg8 *) ETH_B_BUART_sRX_RxShifter_u0__D0_REG )
    #define ETH_B_RXADDRESS2_REG         (* (reg8 *) ETH_B_BUART_sRX_RxShifter_u0__D1_REG )
    #define ETH_B_RXADDRESS2_PTR         (  (reg8 *) ETH_B_BUART_sRX_RxShifter_u0__D1_REG )
    #define ETH_B_RXDATA_AUX_CTL_REG     (* (reg8 *) ETH_B_BUART_sRX_RxShifter_u0__DP_AUX_CTL_REG)

    #define ETH_B_RXBITCTR_PERIOD_REG    (* (reg8 *) ETH_B_BUART_sRX_RxBitCounter__PERIOD_REG )
    #define ETH_B_RXBITCTR_PERIOD_PTR    (  (reg8 *) ETH_B_BUART_sRX_RxBitCounter__PERIOD_REG )
    #define ETH_B_RXBITCTR_CONTROL_REG   \
                                        (* (reg8 *) ETH_B_BUART_sRX_RxBitCounter__CONTROL_AUX_CTL_REG )
    #define ETH_B_RXBITCTR_CONTROL_PTR   \
                                        (  (reg8 *) ETH_B_BUART_sRX_RxBitCounter__CONTROL_AUX_CTL_REG )
    #define ETH_B_RXBITCTR_COUNTER_REG   (* (reg8 *) ETH_B_BUART_sRX_RxBitCounter__COUNT_REG )
    #define ETH_B_RXBITCTR_COUNTER_PTR   (  (reg8 *) ETH_B_BUART_sRX_RxBitCounter__COUNT_REG )

    #define ETH_B_RXSTATUS_REG           (* (reg8 *) ETH_B_BUART_sRX_RxSts__STATUS_REG )
    #define ETH_B_RXSTATUS_PTR           (  (reg8 *) ETH_B_BUART_sRX_RxSts__STATUS_REG )
    #define ETH_B_RXSTATUS_MASK_REG      (* (reg8 *) ETH_B_BUART_sRX_RxSts__MASK_REG )
    #define ETH_B_RXSTATUS_MASK_PTR      (  (reg8 *) ETH_B_BUART_sRX_RxSts__MASK_REG )
    #define ETH_B_RXSTATUS_ACTL_REG      (* (reg8 *) ETH_B_BUART_sRX_RxSts__STATUS_AUX_CTL_REG )
    #define ETH_B_RXSTATUS_ACTL_PTR      (  (reg8 *) ETH_B_BUART_sRX_RxSts__STATUS_AUX_CTL_REG )
#endif /* End  (ETH_B_RX_ENABLED) || (ETH_B_HD_ENABLED) */

#if(ETH_B_INTERNAL_CLOCK_USED)
    /* Register to enable or disable the digital clocks */
    #define ETH_B_INTCLOCK_CLKEN_REG     (* (reg8 *) ETH_B_IntClock__PM_ACT_CFG)
    #define ETH_B_INTCLOCK_CLKEN_PTR     (  (reg8 *) ETH_B_IntClock__PM_ACT_CFG)

    /* Clock mask for this clock. */
    #define ETH_B_INTCLOCK_CLKEN_MASK    ETH_B_IntClock__PM_ACT_MSK
#endif /* End ETH_B_INTERNAL_CLOCK_USED */


/***************************************
*       Register Constants
***************************************/

#if(ETH_B_TX_ENABLED)
    #define ETH_B_TX_FIFO_CLR            (0x01u) /* FIFO0 CLR */
#endif /* End ETH_B_TX_ENABLED */

#if(ETH_B_HD_ENABLED)
    #define ETH_B_TX_FIFO_CLR            (0x02u) /* FIFO1 CLR */
#endif /* End ETH_B_HD_ENABLED */

#if( (ETH_B_RX_ENABLED) || (ETH_B_HD_ENABLED) )
    #define ETH_B_RX_FIFO_CLR            (0x01u) /* FIFO0 CLR */
#endif /* End  (ETH_B_RX_ENABLED) || (ETH_B_HD_ENABLED) */


/***************************************
* Renamed global variables or defines
* for backward compatible
***************************************/

#define ETH_B_initvar                    ETH_B_initVar

#define ETH_B_RX_Enabled                 ETH_B_RX_ENABLED
#define ETH_B_TX_Enabled                 ETH_B_TX_ENABLED
#define ETH_B_HD_Enabled                 ETH_B_HD_ENABLED
#define ETH_B_RX_IntInterruptEnabled     ETH_B_RX_INTERRUPT_ENABLED
#define ETH_B_TX_IntInterruptEnabled     ETH_B_TX_INTERRUPT_ENABLED
#define ETH_B_InternalClockUsed          ETH_B_INTERNAL_CLOCK_USED
#define ETH_B_RXHW_Address_Enabled       ETH_B_RXHW_ADDRESS_ENABLED
#define ETH_B_OverSampleCount            ETH_B_OVER_SAMPLE_COUNT
#define ETH_B_ParityType                 ETH_B_PARITY_TYPE

#if( ETH_B_TX_ENABLED && (ETH_B_TXBUFFERSIZE > ETH_B_FIFO_LENGTH))
    #define ETH_B_TXBUFFER               ETH_B_txBuffer
    #define ETH_B_TXBUFFERREAD           ETH_B_txBufferRead
    #define ETH_B_TXBUFFERWRITE          ETH_B_txBufferWrite
#endif /* End ETH_B_TX_ENABLED */
#if( ( ETH_B_RX_ENABLED || ETH_B_HD_ENABLED ) && \
     (ETH_B_RXBUFFERSIZE > ETH_B_FIFO_LENGTH) )
    #define ETH_B_RXBUFFER               ETH_B_rxBuffer
    #define ETH_B_RXBUFFERREAD           ETH_B_rxBufferRead
    #define ETH_B_RXBUFFERWRITE          ETH_B_rxBufferWrite
    #define ETH_B_RXBUFFERLOOPDETECT     ETH_B_rxBufferLoopDetect
    #define ETH_B_RXBUFFER_OVERFLOW      ETH_B_rxBufferOverflow
#endif /* End ETH_B_RX_ENABLED */

#ifdef ETH_B_BUART_sCR_SyncCtl_CtrlReg__CONTROL_REG
    #define ETH_B_CONTROL                ETH_B_CONTROL_REG
#endif /* End ETH_B_BUART_sCR_SyncCtl_CtrlReg__CONTROL_REG */

#if(ETH_B_TX_ENABLED)
    #define ETH_B_TXDATA                 ETH_B_TXDATA_REG
    #define ETH_B_TXSTATUS               ETH_B_TXSTATUS_REG
    #define ETH_B_TXSTATUS_MASK          ETH_B_TXSTATUS_MASK_REG
    #define ETH_B_TXSTATUS_ACTL          ETH_B_TXSTATUS_ACTL_REG
    /* DP clock */
    #if(ETH_B_TXCLKGEN_DP)
        #define ETH_B_TXBITCLKGEN_CTR        ETH_B_TXBITCLKGEN_CTR_REG
        #define ETH_B_TXBITCLKTX_COMPLETE    ETH_B_TXBITCLKTX_COMPLETE_REG
    #else     /* Count7 clock*/
        #define ETH_B_TXBITCTR_PERIOD        ETH_B_TXBITCTR_PERIOD_REG
        #define ETH_B_TXBITCTR_CONTROL       ETH_B_TXBITCTR_CONTROL_REG
        #define ETH_B_TXBITCTR_COUNTER       ETH_B_TXBITCTR_COUNTER_REG
    #endif /* ETH_B_TXCLKGEN_DP */
#endif /* End ETH_B_TX_ENABLED */

#if(ETH_B_HD_ENABLED)
    #define ETH_B_TXDATA                 ETH_B_TXDATA_REG
    #define ETH_B_TXSTATUS               ETH_B_TXSTATUS_REG
    #define ETH_B_TXSTATUS_MASK          ETH_B_TXSTATUS_MASK_REG
    #define ETH_B_TXSTATUS_ACTL          ETH_B_TXSTATUS_ACTL_REG
#endif /* End ETH_B_HD_ENABLED */

#if( (ETH_B_RX_ENABLED) || (ETH_B_HD_ENABLED) )
    #define ETH_B_RXDATA                 ETH_B_RXDATA_REG
    #define ETH_B_RXADDRESS1             ETH_B_RXADDRESS1_REG
    #define ETH_B_RXADDRESS2             ETH_B_RXADDRESS2_REG
    #define ETH_B_RXBITCTR_PERIOD        ETH_B_RXBITCTR_PERIOD_REG
    #define ETH_B_RXBITCTR_CONTROL       ETH_B_RXBITCTR_CONTROL_REG
    #define ETH_B_RXBITCTR_COUNTER       ETH_B_RXBITCTR_COUNTER_REG
    #define ETH_B_RXSTATUS               ETH_B_RXSTATUS_REG
    #define ETH_B_RXSTATUS_MASK          ETH_B_RXSTATUS_MASK_REG
    #define ETH_B_RXSTATUS_ACTL          ETH_B_RXSTATUS_ACTL_REG
#endif /* End  (ETH_B_RX_ENABLED) || (ETH_B_HD_ENABLED) */

#if(ETH_B_INTERNAL_CLOCK_USED)
    #define ETH_B_INTCLOCK_CLKEN         ETH_B_INTCLOCK_CLKEN_REG
#endif /* End ETH_B_INTERNAL_CLOCK_USED */

#define ETH_B_WAIT_FOR_COMLETE_REINIT    ETH_B_WAIT_FOR_COMPLETE_REINIT

#endif  /* CY_UART_ETH_B_H */


/* [] END OF FILE */
