/*******************************************************************************
* File Name: ETH_B_PM.c
* Version 2.30
*
* Description:
*  This file provides Sleep/WakeUp APIs functionality.
*
* Note:
*
********************************************************************************
* Copyright 2008-2012, Cypress Semiconductor Corporation.  All rights reserved.
* You may use this file only in accordance with the license, terms, conditions,
* disclaimers, and limitations in the end user license agreement accompanying
* the software package with which this file was provided.
*******************************************************************************/

#include "ETH_B.h"


/***************************************
* Local data allocation
***************************************/

static ETH_B_BACKUP_STRUCT  ETH_B_backup =
{
    /* enableState - disabled */
    0u,
};



/*******************************************************************************
* Function Name: ETH_B_SaveConfig
********************************************************************************
*
* Summary:
*  Saves the current user configuration.
*
* Parameters:
*  None.
*
* Return:
*  None.
*
* Global Variables:
*  ETH_B_backup - modified when non-retention registers are saved.
*
* Reentrant:
*  No.
*
*******************************************************************************/
void ETH_B_SaveConfig(void)
{
    #if (CY_UDB_V0)

        #if(ETH_B_CONTROL_REG_REMOVED == 0u)
            ETH_B_backup.cr = ETH_B_CONTROL_REG;
        #endif /* End ETH_B_CONTROL_REG_REMOVED */

        #if( (ETH_B_RX_ENABLED) || (ETH_B_HD_ENABLED) )
            ETH_B_backup.rx_period = ETH_B_RXBITCTR_PERIOD_REG;
            ETH_B_backup.rx_mask = ETH_B_RXSTATUS_MASK_REG;
            #if (ETH_B_RXHW_ADDRESS_ENABLED)
                ETH_B_backup.rx_addr1 = ETH_B_RXADDRESS1_REG;
                ETH_B_backup.rx_addr2 = ETH_B_RXADDRESS2_REG;
            #endif /* End ETH_B_RXHW_ADDRESS_ENABLED */
        #endif /* End ETH_B_RX_ENABLED | ETH_B_HD_ENABLED*/

        #if(ETH_B_TX_ENABLED)
            #if(ETH_B_TXCLKGEN_DP)
                ETH_B_backup.tx_clk_ctr = ETH_B_TXBITCLKGEN_CTR_REG;
                ETH_B_backup.tx_clk_compl = ETH_B_TXBITCLKTX_COMPLETE_REG;
            #else
                ETH_B_backup.tx_period = ETH_B_TXBITCTR_PERIOD_REG;
            #endif /*End ETH_B_TXCLKGEN_DP */
            ETH_B_backup.tx_mask = ETH_B_TXSTATUS_MASK_REG;
        #endif /*End ETH_B_TX_ENABLED */


    #else /* CY_UDB_V1 */

        #if(ETH_B_CONTROL_REG_REMOVED == 0u)
            ETH_B_backup.cr = ETH_B_CONTROL_REG;
        #endif /* End ETH_B_CONTROL_REG_REMOVED */

    #endif  /* End CY_UDB_V0 */
}


/*******************************************************************************
* Function Name: ETH_B_RestoreConfig
********************************************************************************
*
* Summary:
*  Restores the current user configuration.
*
* Parameters:
*  None.
*
* Return:
*  None.
*
* Global Variables:
*  ETH_B_backup - used when non-retention registers are restored.
*
* Reentrant:
*  No.
*
*******************************************************************************/
void ETH_B_RestoreConfig(void)
{

    #if (CY_UDB_V0)

        #if(ETH_B_CONTROL_REG_REMOVED == 0u)
            ETH_B_CONTROL_REG = ETH_B_backup.cr;
        #endif /* End ETH_B_CONTROL_REG_REMOVED */

        #if( (ETH_B_RX_ENABLED) || (ETH_B_HD_ENABLED) )
            ETH_B_RXBITCTR_PERIOD_REG = ETH_B_backup.rx_period;
            ETH_B_RXSTATUS_MASK_REG = ETH_B_backup.rx_mask;
            #if (ETH_B_RXHW_ADDRESS_ENABLED)
                ETH_B_RXADDRESS1_REG = ETH_B_backup.rx_addr1;
                ETH_B_RXADDRESS2_REG = ETH_B_backup.rx_addr2;
            #endif /* End ETH_B_RXHW_ADDRESS_ENABLED */
        #endif  /* End (ETH_B_RX_ENABLED) || (ETH_B_HD_ENABLED) */

        #if(ETH_B_TX_ENABLED)
            #if(ETH_B_TXCLKGEN_DP)
                ETH_B_TXBITCLKGEN_CTR_REG = ETH_B_backup.tx_clk_ctr;
                ETH_B_TXBITCLKTX_COMPLETE_REG = ETH_B_backup.tx_clk_compl;
            #else
                ETH_B_TXBITCTR_PERIOD_REG = ETH_B_backup.tx_period;
            #endif /*End ETH_B_TXCLKGEN_DP */
            ETH_B_TXSTATUS_MASK_REG = ETH_B_backup.tx_mask;
        #endif /*End ETH_B_TX_ENABLED */

    #else /* CY_UDB_V1 */

        #if(ETH_B_CONTROL_REG_REMOVED == 0u)
            ETH_B_CONTROL_REG = ETH_B_backup.cr;
        #endif /* End ETH_B_CONTROL_REG_REMOVED */

    #endif  /* End CY_UDB_V0 */
}


/*******************************************************************************
* Function Name: ETH_B_Sleep
********************************************************************************
*
* Summary:
*  Stops and saves the user configuration. Should be called
*  just prior to entering sleep.
*
*
* Parameters:
*  None.
*
* Return:
*  None.
*
* Global Variables:
*  ETH_B_backup - modified when non-retention registers are saved.
*
* Reentrant:
*  No.
*
*******************************************************************************/
void ETH_B_Sleep(void)
{

    #if(ETH_B_RX_ENABLED || ETH_B_HD_ENABLED)
        if((ETH_B_RXSTATUS_ACTL_REG  & ETH_B_INT_ENABLE) != 0u)
        {
            ETH_B_backup.enableState = 1u;
        }
        else
        {
            ETH_B_backup.enableState = 0u;
        }
    #else
        if((ETH_B_TXSTATUS_ACTL_REG  & ETH_B_INT_ENABLE) !=0u)
        {
            ETH_B_backup.enableState = 1u;
        }
        else
        {
            ETH_B_backup.enableState = 0u;
        }
    #endif /* End ETH_B_RX_ENABLED || ETH_B_HD_ENABLED*/

    ETH_B_Stop();
    ETH_B_SaveConfig();
}


/*******************************************************************************
* Function Name: ETH_B_Wakeup
********************************************************************************
*
* Summary:
*  Restores and enables the user configuration. Should be called
*  just after awaking from sleep.
*
* Parameters:
*  None.
*
* Return:
*  None.
*
* Global Variables:
*  ETH_B_backup - used when non-retention registers are restored.
*
* Reentrant:
*  No.
*
*******************************************************************************/
void ETH_B_Wakeup(void)
{
    ETH_B_RestoreConfig();
    #if( (ETH_B_RX_ENABLED) || (ETH_B_HD_ENABLED) )
        ETH_B_ClearRxBuffer();
    #endif /* End (ETH_B_RX_ENABLED) || (ETH_B_HD_ENABLED) */
    #if(ETH_B_TX_ENABLED || ETH_B_HD_ENABLED)
        ETH_B_ClearTxBuffer();
    #endif /* End ETH_B_TX_ENABLED || ETH_B_HD_ENABLED */

    if(ETH_B_backup.enableState != 0u)
    {
        ETH_B_Enable();
    }
}


/* [] END OF FILE */
