/*******************************************************************************
* File Name: PC_CRC_PM.c
* Version 2.40
*
* Description:
*  This file provides Sleep APIs for CRC component.
*
* Note:
*  None
*
********************************************************************************
* Copyright 2008-2013, Cypress Semiconductor Corporation.  All rights reserved.
* You may use this file only in accordance with the license, terms, conditions, 
* disclaimers, and limitations in the end user license agreement accompanying 
* the software package with which this file was provided.
*******************************************************************************/

#include "PC_CRC.h"


/*******************************************************************************
* Function Name: PC_CRC_SaveConfig
********************************************************************************
*
* Summary:
*  Saves seed and polynomial registers.
*
* Parameters:
*  void
*
* Return:
*  void
*
* Global Variables:
*  PC_CRC_backup - modified when non-retention registers are saved.
*
*******************************************************************************/
void PC_CRC_SaveConfig(void) 
{       
    /* Save D0 and D1 registers are none-retention for Panther ES1 */
    #if (CY_UDB_V0)
    
        #if(PC_CRC_CRC_SIZE <= 32u)
            PC_CRC_backup.polynomial = PC_CRC_ReadPolynomial();
            
        #else
            PC_CRC_backup.polynomialUpper = PC_CRC_ReadPolynomialUpper();
            PC_CRC_backup.polynomialLower = PC_CRC_ReadPolynomialLower();
            
        #endif  /* End (PC_CRC_CRC_SIZE <= 32u) */
        
    #endif  /* End (CY_UDB_V0) */
}


/*******************************************************************************
* Function Name: PC_CRC_Sleep
********************************************************************************
*
* Summary:
*  Stops CRC computation and saves CRC configuration.
*
* Parameters:
*  void
*
* Return:
*  void
*
* Global Variables:
*  PC_CRC_backup - modified when non-retention registers are saved.
*
*******************************************************************************/
void PC_CRC_Sleep(void) 
{
    /* Store CRC enable state */
    if(0u != (PC_CRC_CONTROL_REG & PC_CRC_CTRL_ENABLE))
    {
        PC_CRC_backup.enableState = 1u;
        PC_CRC_Stop();
    }
    else
    {
        PC_CRC_backup.enableState = 0u;
    }
    
    PC_CRC_SaveConfig();
}


/*******************************************************************************
* Function Name: PC_CRC_RestoreConfig
********************************************************************************
*
* Summary:
*  Restores seed and polynomial registers.
*
* Parameters:
*  void
*
* Return:
*  void
*
*******************************************************************************/
void PC_CRC_RestoreConfig(void) 
{      
    /* Restore D0 and D1 registers are none-retention for Panther ES1 */
    #if (CY_UDB_V0)
    
        #if(PC_CRC_CRC_SIZE <= 32u)
            PC_CRC_WritePolynomial(PC_CRC_backup.polynomial);
            
        #else
            PC_CRC_WritePolynomialUpper(PC_CRC_backup.polynomialUpper);
            PC_CRC_WritePolynomialLower(PC_CRC_backup.polynomialLower);
            
        #endif  /* End (CY_UDB_V0) */
        
    #endif  /* End (PC_CRC_CRC_SIZE <= 32u) */
    
    #if (PC_CRC_CRC_SIZE <= 32u)
        PC_CRC_WriteSeed(PC_CRC_DEFAULT_SEED);                        
    #else
        PC_CRC_WriteSeedUpper(PC_CRC_DEFAULT_SEED_UPPER);
        PC_CRC_WriteSeedLower(PC_CRC_DEFAULT_SEED_LOWER); 
    #endif  /* End (PC_CRC_CRC_SIZE <= 32u) */
    
    #if (PC_CRC_CRC_SIZE <= 32u)
        PC_CRC_ResetSeedInit(PC_CRC_DEFAULT_SEED);                        
    #else
        PC_CRC_ResetSeedInitUpper(PC_CRC_DEFAULT_SEED_UPPER);
        PC_CRC_ResetSeedInitLower(PC_CRC_DEFAULT_SEED_LOWER); 
    #endif  /* End (PC_CRC_CRC_SIZE <= 32u) */
}


/*******************************************************************************
* Function Name: PC_CRC_Wakeup
********************************************************************************
*
* Summary:
*  Restores CRC configuration and starts CRC computation. 
*
* Parameters:
*  void
*
* Return:
*  void
* 
*******************************************************************************/
void PC_CRC_Wakeup(void) 
{
    PC_CRC_RestoreConfig();
    
    /* Restore CRC enable state */
    if (PC_CRC_backup.enableState != 0u)
    {
        PC_CRC_Enable();
    }
}


/* [] END OF FILE */
