/*******************************************************************************
* File Name: PL1_LEDV.c  
* Version 2.0
*
* Description:
*  This file contains API to enable firmware control of a Pins component.
*
* Note:
*
********************************************************************************
* Copyright 2008-2014, Cypress Semiconductor Corporation.  All rights reserved.
* You may use this file only in accordance with the license, terms, conditions, 
* disclaimers, and limitations in the end user license agreement accompanying 
* the software package with which this file was provided.
*******************************************************************************/

#include "cytypes.h"
#include "PL1_LEDV.h"

/* APIs are not generated for P15[7:6] on PSoC 5 */
#if !(CY_PSOC5A &&\
	 PL1_LEDV__PORT == 15 && ((PL1_LEDV__MASK & 0xC0) != 0))


/*******************************************************************************
* Function Name: PL1_LEDV_Write
********************************************************************************
*
* Summary:
*  Assign a new value to the digital port's data output register.  
*
* Parameters:  
*  prtValue:  The value to be assigned to the Digital Port. 
*
* Return: 
*  None
*  
*******************************************************************************/
void PL1_LEDV_Write(uint8 value) 
{
    uint8 staticBits = (PL1_LEDV_DR & (uint8)(~PL1_LEDV_MASK));
    PL1_LEDV_DR = staticBits | ((uint8)(value << PL1_LEDV_SHIFT) & PL1_LEDV_MASK);
}


/*******************************************************************************
* Function Name: PL1_LEDV_SetDriveMode
********************************************************************************
*
* Summary:
*  Change the drive mode on the pins of the port.
* 
* Parameters:  
*  mode:  Change the pins to one of the following drive modes.
*
*  PL1_LEDV_DM_STRONG     Strong Drive 
*  PL1_LEDV_DM_OD_HI      Open Drain, Drives High 
*  PL1_LEDV_DM_OD_LO      Open Drain, Drives Low 
*  PL1_LEDV_DM_RES_UP     Resistive Pull Up 
*  PL1_LEDV_DM_RES_DWN    Resistive Pull Down 
*  PL1_LEDV_DM_RES_UPDWN  Resistive Pull Up/Down 
*  PL1_LEDV_DM_DIG_HIZ    High Impedance Digital 
*  PL1_LEDV_DM_ALG_HIZ    High Impedance Analog 
*
* Return: 
*  None
*
*******************************************************************************/
void PL1_LEDV_SetDriveMode(uint8 mode) 
{
	CyPins_SetPinDriveMode(PL1_LEDV_0, mode);
}


/*******************************************************************************
* Function Name: PL1_LEDV_Read
********************************************************************************
*
* Summary:
*  Read the current value on the pins of the Digital Port in right justified 
*  form.
*
* Parameters:  
*  None
*
* Return: 
*  Returns the current value of the Digital Port as a right justified number
*  
* Note:
*  Macro PL1_LEDV_ReadPS calls this function. 
*  
*******************************************************************************/
uint8 PL1_LEDV_Read(void) 
{
    return (PL1_LEDV_PS & PL1_LEDV_MASK) >> PL1_LEDV_SHIFT;
}


/*******************************************************************************
* Function Name: PL1_LEDV_ReadDataReg
********************************************************************************
*
* Summary:
*  Read the current value assigned to a Digital Port's data output register
*
* Parameters:  
*  None 
*
* Return: 
*  Returns the current value assigned to the Digital Port's data output register
*  
*******************************************************************************/
uint8 PL1_LEDV_ReadDataReg(void) 
{
    return (PL1_LEDV_DR & PL1_LEDV_MASK) >> PL1_LEDV_SHIFT;
}


/* If Interrupts Are Enabled for this Pins component */ 
#if defined(PL1_LEDV_INTSTAT) 

    /*******************************************************************************
    * Function Name: PL1_LEDV_ClearInterrupt
    ********************************************************************************
    * Summary:
    *  Clears any active interrupts attached to port and returns the value of the 
    *  interrupt status register.
    *
    * Parameters:  
    *  None 
    *
    * Return: 
    *  Returns the value of the interrupt status register
    *  
    *******************************************************************************/
    uint8 PL1_LEDV_ClearInterrupt(void) 
    {
        return (PL1_LEDV_INTSTAT & PL1_LEDV_MASK) >> PL1_LEDV_SHIFT;
    }

#endif /* If Interrupts Are Enabled for this Pins component */ 

#endif /* CY_PSOC5A... */

    
/* [] END OF FILE */
