/*******************************************************************************
* File Name: PL1_RS485.h
* Version 2.30
*
* Description:
*  Contains the function prototypes and constants available to the UART
*  user module.
*
* Note:
*
********************************************************************************
* Copyright 2008-2012, Cypress Semiconductor Corporation.  All rights reserved.
* You may use this file only in accordance with the license, terms, conditions,
* disclaimers, and limitations in the end user license agreement accompanying
* the software package with which this file was provided.
*******************************************************************************/


#if !defined(CY_UART_PL1_RS485_H)
#define CY_UART_PL1_RS485_H

#include "cytypes.h"
#include "cyfitter.h"
#include "CyLib.h"


/***************************************
* Conditional Compilation Parameters
***************************************/

#define PL1_RS485_RX_ENABLED                     (1u)
#define PL1_RS485_TX_ENABLED                     (1u)
#define PL1_RS485_HD_ENABLED                     (0u)
#define PL1_RS485_RX_INTERRUPT_ENABLED           (0u)
#define PL1_RS485_TX_INTERRUPT_ENABLED           (0u)
#define PL1_RS485_INTERNAL_CLOCK_USED            (1u)
#define PL1_RS485_RXHW_ADDRESS_ENABLED           (0u)
#define PL1_RS485_OVER_SAMPLE_COUNT              (8u)
#define PL1_RS485_PARITY_TYPE                    (0u)
#define PL1_RS485_PARITY_TYPE_SW                 (0u)
#define PL1_RS485_BREAK_DETECT                   (0u)
#define PL1_RS485_BREAK_BITS_TX                  (13u)
#define PL1_RS485_BREAK_BITS_RX                  (13u)
#define PL1_RS485_TXCLKGEN_DP                    (1u)
#define PL1_RS485_USE23POLLING                   (1u)
#define PL1_RS485_FLOW_CONTROL                   (0u)
#define PL1_RS485_CLK_FREQ                       (0u)
#define PL1_RS485_TXBUFFERSIZE                   (4u)
#define PL1_RS485_RXBUFFERSIZE                   (4u)

/* Check to see if required defines such as CY_PSOC5LP are available */
/* They are defined starting with cy_boot v3.0 */
#if !defined (CY_PSOC5LP)
    #error Component UART_v2_30 requires cy_boot v3.0 or later
#endif /* (CY_PSOC5LP) */

#ifdef PL1_RS485_BUART_sCR_SyncCtl_CtrlReg__CONTROL_REG
    #define PL1_RS485_CONTROL_REG_REMOVED            (0u)
#else
    #define PL1_RS485_CONTROL_REG_REMOVED            (1u)
#endif /* End PL1_RS485_BUART_sCR_SyncCtl_CtrlReg__CONTROL_REG */


/***************************************
*      Data Struct Definition
***************************************/

/* Sleep Mode API Support */
typedef struct PL1_RS485_backupStruct_
{
    uint8 enableState;

    #if(PL1_RS485_CONTROL_REG_REMOVED == 0u)
        uint8 cr;
    #endif /* End PL1_RS485_CONTROL_REG_REMOVED */
    #if( (PL1_RS485_RX_ENABLED) || (PL1_RS485_HD_ENABLED) )
        uint8 rx_period;
        #if (CY_UDB_V0)
            uint8 rx_mask;
            #if (PL1_RS485_RXHW_ADDRESS_ENABLED)
                uint8 rx_addr1;
                uint8 rx_addr2;
            #endif /* End PL1_RS485_RXHW_ADDRESS_ENABLED */
        #endif /* End CY_UDB_V0 */
    #endif  /* End (PL1_RS485_RX_ENABLED) || (PL1_RS485_HD_ENABLED)*/

    #if(PL1_RS485_TX_ENABLED)
        #if(PL1_RS485_TXCLKGEN_DP)
            uint8 tx_clk_ctr;
            #if (CY_UDB_V0)
                uint8 tx_clk_compl;
            #endif  /* End CY_UDB_V0 */
        #else
            uint8 tx_period;
        #endif /*End PL1_RS485_TXCLKGEN_DP */
        #if (CY_UDB_V0)
            uint8 tx_mask;
        #endif  /* End CY_UDB_V0 */
    #endif /*End PL1_RS485_TX_ENABLED */
} PL1_RS485_BACKUP_STRUCT;


/***************************************
*       Function Prototypes
***************************************/

void PL1_RS485_Start(void) ;
void PL1_RS485_Stop(void) ;
uint8 PL1_RS485_ReadControlRegister(void) ;
void PL1_RS485_WriteControlRegister(uint8 control) ;

void PL1_RS485_Init(void) ;
void PL1_RS485_Enable(void) ;
void PL1_RS485_SaveConfig(void) ;
void PL1_RS485_RestoreConfig(void) ;
void PL1_RS485_Sleep(void) ;
void PL1_RS485_Wakeup(void) ;

/* Only if RX is enabled */
#if( (PL1_RS485_RX_ENABLED) || (PL1_RS485_HD_ENABLED) )

    #if(PL1_RS485_RX_INTERRUPT_ENABLED)
        void  PL1_RS485_EnableRxInt(void) ;
        void  PL1_RS485_DisableRxInt(void) ;
        CY_ISR_PROTO(PL1_RS485_RXISR);
    #endif /* PL1_RS485_RX_INTERRUPT_ENABLED */

    void PL1_RS485_SetRxAddressMode(uint8 addressMode)
                                                           ;
    void PL1_RS485_SetRxAddress1(uint8 address) ;
    void PL1_RS485_SetRxAddress2(uint8 address) ;

    void  PL1_RS485_SetRxInterruptMode(uint8 intSrc) ;
    uint8 PL1_RS485_ReadRxData(void) ;
    uint8 PL1_RS485_ReadRxStatus(void) ;
    uint8 PL1_RS485_GetChar(void) ;
    uint16 PL1_RS485_GetByte(void) ;
    uint8 PL1_RS485_GetRxBufferSize(void)
                                                            ;
    void PL1_RS485_ClearRxBuffer(void) ;

    /* Obsolete functions, defines for backward compatible */
    #define PL1_RS485_GetRxInterruptSource   PL1_RS485_ReadRxStatus

#endif /* End (PL1_RS485_RX_ENABLED) || (PL1_RS485_HD_ENABLED) */

/* Only if TX is enabled */
#if(PL1_RS485_TX_ENABLED || PL1_RS485_HD_ENABLED)

    #if(PL1_RS485_TX_INTERRUPT_ENABLED)
        void PL1_RS485_EnableTxInt(void) ;
        void PL1_RS485_DisableTxInt(void) ;
        CY_ISR_PROTO(PL1_RS485_TXISR);
    #endif /* PL1_RS485_TX_INTERRUPT_ENABLED */

    void PL1_RS485_SetTxInterruptMode(uint8 intSrc) ;
    void PL1_RS485_WriteTxData(uint8 txDataByte) ;
    uint8 PL1_RS485_ReadTxStatus(void) ;
    void PL1_RS485_PutChar(uint8 txDataByte) ;
    void PL1_RS485_PutString(const char8 string[]) ;
    void PL1_RS485_PutArray(const uint8 string[], uint8 byteCount)
                                                            ;
    void PL1_RS485_PutCRLF(uint8 txDataByte) ;
    void PL1_RS485_ClearTxBuffer(void) ;
    void PL1_RS485_SetTxAddressMode(uint8 addressMode) ;
    void PL1_RS485_SendBreak(uint8 retMode) ;
    uint8 PL1_RS485_GetTxBufferSize(void)
                                                            ;
    /* Obsolete functions, defines for backward compatible */
    #define PL1_RS485_PutStringConst         PL1_RS485_PutString
    #define PL1_RS485_PutArrayConst          PL1_RS485_PutArray
    #define PL1_RS485_GetTxInterruptSource   PL1_RS485_ReadTxStatus

#endif /* End PL1_RS485_TX_ENABLED || PL1_RS485_HD_ENABLED */

#if(PL1_RS485_HD_ENABLED)
    void PL1_RS485_LoadRxConfig(void) ;
    void PL1_RS485_LoadTxConfig(void) ;
#endif /* End PL1_RS485_HD_ENABLED */


/* Communication bootloader APIs */
#if defined(CYDEV_BOOTLOADER_IO_COMP) && ((CYDEV_BOOTLOADER_IO_COMP == CyBtldr_PL1_RS485) || \
                                          (CYDEV_BOOTLOADER_IO_COMP == CyBtldr_Custom_Interface))
    /* Physical layer functions */
    void    PL1_RS485_CyBtldrCommStart(void) CYSMALL ;
    void    PL1_RS485_CyBtldrCommStop(void) CYSMALL ;
    void    PL1_RS485_CyBtldrCommReset(void) CYSMALL ;
    cystatus PL1_RS485_CyBtldrCommWrite(const uint8 pData[], uint16 size, uint16 * count, uint8 timeOut) CYSMALL
             ;
    cystatus PL1_RS485_CyBtldrCommRead(uint8 pData[], uint16 size, uint16 * count, uint8 timeOut) CYSMALL
             ;

    #if (CYDEV_BOOTLOADER_IO_COMP == CyBtldr_PL1_RS485)
        #define CyBtldrCommStart    PL1_RS485_CyBtldrCommStart
        #define CyBtldrCommStop     PL1_RS485_CyBtldrCommStop
        #define CyBtldrCommReset    PL1_RS485_CyBtldrCommReset
        #define CyBtldrCommWrite    PL1_RS485_CyBtldrCommWrite
        #define CyBtldrCommRead     PL1_RS485_CyBtldrCommRead
    #endif  /* (CYDEV_BOOTLOADER_IO_COMP == CyBtldr_PL1_RS485) */

    /* Byte to Byte time out for detecting end of block data from host */
    #define PL1_RS485_BYTE2BYTE_TIME_OUT (25u)

#endif /* CYDEV_BOOTLOADER_IO_COMP */


/***************************************
*          API Constants
***************************************/
/* Parameters for SetTxAddressMode API*/
#define PL1_RS485_SET_SPACE                              (0x00u)
#define PL1_RS485_SET_MARK                               (0x01u)

/* Status Register definitions */
#if( (PL1_RS485_TX_ENABLED) || (PL1_RS485_HD_ENABLED) )
    #if(PL1_RS485_TX_INTERRUPT_ENABLED)
        #define PL1_RS485_TX_VECT_NUM            (uint8)PL1_RS485_TXInternalInterrupt__INTC_NUMBER
        #define PL1_RS485_TX_PRIOR_NUM           (uint8)PL1_RS485_TXInternalInterrupt__INTC_PRIOR_NUM
    #endif /* PL1_RS485_TX_INTERRUPT_ENABLED */
    #if(PL1_RS485_TX_ENABLED)
        #define PL1_RS485_TX_STS_COMPLETE_SHIFT          (0x00u)
        #define PL1_RS485_TX_STS_FIFO_EMPTY_SHIFT        (0x01u)
        #define PL1_RS485_TX_STS_FIFO_FULL_SHIFT         (0x02u)
        #define PL1_RS485_TX_STS_FIFO_NOT_FULL_SHIFT     (0x03u)
    #endif /* PL1_RS485_TX_ENABLED */
    #if(PL1_RS485_HD_ENABLED)
        #define PL1_RS485_TX_STS_COMPLETE_SHIFT          (0x00u)
        #define PL1_RS485_TX_STS_FIFO_EMPTY_SHIFT        (0x01u)
        #define PL1_RS485_TX_STS_FIFO_FULL_SHIFT         (0x05u)  /*needs MD=0*/
        #define PL1_RS485_TX_STS_FIFO_NOT_FULL_SHIFT     (0x03u)
    #endif /* PL1_RS485_HD_ENABLED */
    #define PL1_RS485_TX_STS_COMPLETE            (uint8)(0x01u << PL1_RS485_TX_STS_COMPLETE_SHIFT)
    #define PL1_RS485_TX_STS_FIFO_EMPTY          (uint8)(0x01u << PL1_RS485_TX_STS_FIFO_EMPTY_SHIFT)
    #define PL1_RS485_TX_STS_FIFO_FULL           (uint8)(0x01u << PL1_RS485_TX_STS_FIFO_FULL_SHIFT)
    #define PL1_RS485_TX_STS_FIFO_NOT_FULL       (uint8)(0x01u << PL1_RS485_TX_STS_FIFO_NOT_FULL_SHIFT)
#endif /* End (PL1_RS485_TX_ENABLED) || (PL1_RS485_HD_ENABLED)*/

#if( (PL1_RS485_RX_ENABLED) || (PL1_RS485_HD_ENABLED) )
    #if(PL1_RS485_RX_INTERRUPT_ENABLED)
        #define PL1_RS485_RX_VECT_NUM            (uint8)PL1_RS485_RXInternalInterrupt__INTC_NUMBER
        #define PL1_RS485_RX_PRIOR_NUM           (uint8)PL1_RS485_RXInternalInterrupt__INTC_PRIOR_NUM
    #endif /* PL1_RS485_RX_INTERRUPT_ENABLED */
    #define PL1_RS485_RX_STS_MRKSPC_SHIFT            (0x00u)
    #define PL1_RS485_RX_STS_BREAK_SHIFT             (0x01u)
    #define PL1_RS485_RX_STS_PAR_ERROR_SHIFT         (0x02u)
    #define PL1_RS485_RX_STS_STOP_ERROR_SHIFT        (0x03u)
    #define PL1_RS485_RX_STS_OVERRUN_SHIFT           (0x04u)
    #define PL1_RS485_RX_STS_FIFO_NOTEMPTY_SHIFT     (0x05u)
    #define PL1_RS485_RX_STS_ADDR_MATCH_SHIFT        (0x06u)
    #define PL1_RS485_RX_STS_SOFT_BUFF_OVER_SHIFT    (0x07u)

    #define PL1_RS485_RX_STS_MRKSPC           (uint8)(0x01u << PL1_RS485_RX_STS_MRKSPC_SHIFT)
    #define PL1_RS485_RX_STS_BREAK            (uint8)(0x01u << PL1_RS485_RX_STS_BREAK_SHIFT)
    #define PL1_RS485_RX_STS_PAR_ERROR        (uint8)(0x01u << PL1_RS485_RX_STS_PAR_ERROR_SHIFT)
    #define PL1_RS485_RX_STS_STOP_ERROR       (uint8)(0x01u << PL1_RS485_RX_STS_STOP_ERROR_SHIFT)
    #define PL1_RS485_RX_STS_OVERRUN          (uint8)(0x01u << PL1_RS485_RX_STS_OVERRUN_SHIFT)
    #define PL1_RS485_RX_STS_FIFO_NOTEMPTY    (uint8)(0x01u << PL1_RS485_RX_STS_FIFO_NOTEMPTY_SHIFT)
    #define PL1_RS485_RX_STS_ADDR_MATCH       (uint8)(0x01u << PL1_RS485_RX_STS_ADDR_MATCH_SHIFT)
    #define PL1_RS485_RX_STS_SOFT_BUFF_OVER   (uint8)(0x01u << PL1_RS485_RX_STS_SOFT_BUFF_OVER_SHIFT)
    #define PL1_RS485_RX_HW_MASK                     (0x7Fu)
#endif /* End (PL1_RS485_RX_ENABLED) || (PL1_RS485_HD_ENABLED) */

/* Control Register definitions */
#define PL1_RS485_CTRL_HD_SEND_SHIFT                 (0x00u) /* 1 enable TX part in Half Duplex mode */
#define PL1_RS485_CTRL_HD_SEND_BREAK_SHIFT           (0x01u) /* 1 send BREAK signal in Half Duplez mode */
#define PL1_RS485_CTRL_MARK_SHIFT                    (0x02u) /* 1 sets mark, 0 sets space */
#define PL1_RS485_CTRL_PARITY_TYPE0_SHIFT            (0x03u) /* Defines the type of parity implemented */
#define PL1_RS485_CTRL_PARITY_TYPE1_SHIFT            (0x04u) /* Defines the type of parity implemented */
#define PL1_RS485_CTRL_RXADDR_MODE0_SHIFT            (0x05u)
#define PL1_RS485_CTRL_RXADDR_MODE1_SHIFT            (0x06u)
#define PL1_RS485_CTRL_RXADDR_MODE2_SHIFT            (0x07u)

#define PL1_RS485_CTRL_HD_SEND               (uint8)(0x01u << PL1_RS485_CTRL_HD_SEND_SHIFT)
#define PL1_RS485_CTRL_HD_SEND_BREAK         (uint8)(0x01u << PL1_RS485_CTRL_HD_SEND_BREAK_SHIFT)
#define PL1_RS485_CTRL_MARK                  (uint8)(0x01u << PL1_RS485_CTRL_MARK_SHIFT)
#define PL1_RS485_CTRL_PARITY_TYPE_MASK      (uint8)(0x03u << PL1_RS485_CTRL_PARITY_TYPE0_SHIFT)
#define PL1_RS485_CTRL_RXADDR_MODE_MASK      (uint8)(0x07u << PL1_RS485_CTRL_RXADDR_MODE0_SHIFT)

/* StatusI Register Interrupt Enable Control Bits. As defined by the Register map for the AUX Control Register */
#define PL1_RS485_INT_ENABLE                         (0x10u)

/* Bit Counter (7-bit) Control Register Bit Definitions. As defined by the Register map for the AUX Control Register */
#define PL1_RS485_CNTR_ENABLE                        (0x20u)

/*   Constants for SendBreak() "retMode" parameter  */
#define PL1_RS485_SEND_BREAK                         (0x00u)
#define PL1_RS485_WAIT_FOR_COMPLETE_REINIT           (0x01u)
#define PL1_RS485_REINIT                             (0x02u)
#define PL1_RS485_SEND_WAIT_REINIT                   (0x03u)

#define PL1_RS485_OVER_SAMPLE_8                      (8u)
#define PL1_RS485_OVER_SAMPLE_16                     (16u)

#define PL1_RS485_BIT_CENTER                         (PL1_RS485_OVER_SAMPLE_COUNT - 1u)

#define PL1_RS485_FIFO_LENGTH                        (4u)
#define PL1_RS485_NUMBER_OF_START_BIT                (1u)
#define PL1_RS485_MAX_BYTE_VALUE                     (0xFFu)

/* 8X always for count7 implementation*/
#define PL1_RS485_TXBITCTR_BREAKBITS8X   ((PL1_RS485_BREAK_BITS_TX * PL1_RS485_OVER_SAMPLE_8) - 1u)
/* 8X or 16X for DP implementation*/
#define PL1_RS485_TXBITCTR_BREAKBITS ((PL1_RS485_BREAK_BITS_TX * PL1_RS485_OVER_SAMPLE_COUNT) - 1u)

#define PL1_RS485_HALF_BIT_COUNT   \
                            (((PL1_RS485_OVER_SAMPLE_COUNT / 2u) + (PL1_RS485_USE23POLLING * 1u)) - 2u)
#if (PL1_RS485_OVER_SAMPLE_COUNT == PL1_RS485_OVER_SAMPLE_8)
    #define PL1_RS485_HD_TXBITCTR_INIT   (((PL1_RS485_BREAK_BITS_TX + \
                            PL1_RS485_NUMBER_OF_START_BIT) * PL1_RS485_OVER_SAMPLE_COUNT) - 1u)

    /* This parameter is increased on the 2 in 2 out of 3 mode to sample voting in the middle */
    #define PL1_RS485_RXBITCTR_INIT  ((((PL1_RS485_BREAK_BITS_RX + PL1_RS485_NUMBER_OF_START_BIT) \
                            * PL1_RS485_OVER_SAMPLE_COUNT) + PL1_RS485_HALF_BIT_COUNT) - 1u)


#else /* PL1_RS485_OVER_SAMPLE_COUNT == PL1_RS485_OVER_SAMPLE_16 */
    #define PL1_RS485_HD_TXBITCTR_INIT   ((8u * PL1_RS485_OVER_SAMPLE_COUNT) - 1u)
    /* 7bit counter need one more bit for OverSampleCount=16 */
    #define PL1_RS485_RXBITCTR_INIT      (((7u * PL1_RS485_OVER_SAMPLE_COUNT) - 1u) + \
                                                      PL1_RS485_HALF_BIT_COUNT)
#endif /* End PL1_RS485_OVER_SAMPLE_COUNT */
#define PL1_RS485_HD_RXBITCTR_INIT                   PL1_RS485_RXBITCTR_INIT


/***************************************
* Global variables external identifier
***************************************/

extern uint8 PL1_RS485_initVar;
#if( PL1_RS485_TX_ENABLED && (PL1_RS485_TXBUFFERSIZE > PL1_RS485_FIFO_LENGTH))
    extern volatile uint8 PL1_RS485_txBuffer[PL1_RS485_TXBUFFERSIZE];
    extern volatile uint8 PL1_RS485_txBufferRead;
    extern uint8 PL1_RS485_txBufferWrite;
#endif /* End PL1_RS485_TX_ENABLED */
#if( ( PL1_RS485_RX_ENABLED || PL1_RS485_HD_ENABLED ) && \
     (PL1_RS485_RXBUFFERSIZE > PL1_RS485_FIFO_LENGTH) )
    extern volatile uint8 PL1_RS485_rxBuffer[PL1_RS485_RXBUFFERSIZE];
    extern volatile uint8 PL1_RS485_rxBufferRead;
    extern volatile uint8 PL1_RS485_rxBufferWrite;
    extern volatile uint8 PL1_RS485_rxBufferLoopDetect;
    extern volatile uint8 PL1_RS485_rxBufferOverflow;
    #if (PL1_RS485_RXHW_ADDRESS_ENABLED)
        extern volatile uint8 PL1_RS485_rxAddressMode;
        extern volatile uint8 PL1_RS485_rxAddressDetected;
    #endif /* End EnableHWAddress */
#endif /* End PL1_RS485_RX_ENABLED */


/***************************************
* Enumerated Types and Parameters
***************************************/

#define PL1_RS485__B_UART__AM_SW_BYTE_BYTE 1
#define PL1_RS485__B_UART__AM_SW_DETECT_TO_BUFFER 2
#define PL1_RS485__B_UART__AM_HW_BYTE_BY_BYTE 3
#define PL1_RS485__B_UART__AM_HW_DETECT_TO_BUFFER 4
#define PL1_RS485__B_UART__AM_NONE 0

#define PL1_RS485__B_UART__NONE_REVB 0
#define PL1_RS485__B_UART__EVEN_REVB 1
#define PL1_RS485__B_UART__ODD_REVB 2
#define PL1_RS485__B_UART__MARK_SPACE_REVB 3



/***************************************
*    Initial Parameter Constants
***************************************/

/* UART shifts max 8 bits, Mark/Space functionality working if 9 selected */
#define PL1_RS485_NUMBER_OF_DATA_BITS    ((8u > 8u) ? 8u : 8u)
#define PL1_RS485_NUMBER_OF_STOP_BITS    (1u)

#if (PL1_RS485_RXHW_ADDRESS_ENABLED)
    #define PL1_RS485_RXADDRESSMODE      (0u)
    #define PL1_RS485_RXHWADDRESS1       (0u)
    #define PL1_RS485_RXHWADDRESS2       (0u)
    /* Backward compatible define */
    #define PL1_RS485_RXAddressMode      PL1_RS485_RXADDRESSMODE
#endif /* End EnableHWAddress */

#define PL1_RS485_INIT_RX_INTERRUPTS_MASK \
                                  (uint8)((1 << PL1_RS485_RX_STS_FIFO_NOTEMPTY_SHIFT) \
                                        | (0 << PL1_RS485_RX_STS_MRKSPC_SHIFT) \
                                        | (0 << PL1_RS485_RX_STS_ADDR_MATCH_SHIFT) \
                                        | (0 << PL1_RS485_RX_STS_PAR_ERROR_SHIFT) \
                                        | (0 << PL1_RS485_RX_STS_STOP_ERROR_SHIFT) \
                                        | (0 << PL1_RS485_RX_STS_BREAK_SHIFT) \
                                        | (0 << PL1_RS485_RX_STS_OVERRUN_SHIFT))

#define PL1_RS485_INIT_TX_INTERRUPTS_MASK \
                                  (uint8)((0 << PL1_RS485_TX_STS_COMPLETE_SHIFT) \
                                        | (0 << PL1_RS485_TX_STS_FIFO_EMPTY_SHIFT) \
                                        | (0 << PL1_RS485_TX_STS_FIFO_FULL_SHIFT) \
                                        | (0 << PL1_RS485_TX_STS_FIFO_NOT_FULL_SHIFT))


/***************************************
*              Registers
***************************************/

#ifdef PL1_RS485_BUART_sCR_SyncCtl_CtrlReg__CONTROL_REG
    #define PL1_RS485_CONTROL_REG \
                            (* (reg8 *) PL1_RS485_BUART_sCR_SyncCtl_CtrlReg__CONTROL_REG )
    #define PL1_RS485_CONTROL_PTR \
                            (  (reg8 *) PL1_RS485_BUART_sCR_SyncCtl_CtrlReg__CONTROL_REG )
#endif /* End PL1_RS485_BUART_sCR_SyncCtl_CtrlReg__CONTROL_REG */

#if(PL1_RS485_TX_ENABLED)
    #define PL1_RS485_TXDATA_REG          (* (reg8 *) PL1_RS485_BUART_sTX_TxShifter_u0__F0_REG)
    #define PL1_RS485_TXDATA_PTR          (  (reg8 *) PL1_RS485_BUART_sTX_TxShifter_u0__F0_REG)
    #define PL1_RS485_TXDATA_AUX_CTL_REG  (* (reg8 *) PL1_RS485_BUART_sTX_TxShifter_u0__DP_AUX_CTL_REG)
    #define PL1_RS485_TXDATA_AUX_CTL_PTR  (  (reg8 *) PL1_RS485_BUART_sTX_TxShifter_u0__DP_AUX_CTL_REG)
    #define PL1_RS485_TXSTATUS_REG        (* (reg8 *) PL1_RS485_BUART_sTX_TxSts__STATUS_REG)
    #define PL1_RS485_TXSTATUS_PTR        (  (reg8 *) PL1_RS485_BUART_sTX_TxSts__STATUS_REG)
    #define PL1_RS485_TXSTATUS_MASK_REG   (* (reg8 *) PL1_RS485_BUART_sTX_TxSts__MASK_REG)
    #define PL1_RS485_TXSTATUS_MASK_PTR   (  (reg8 *) PL1_RS485_BUART_sTX_TxSts__MASK_REG)
    #define PL1_RS485_TXSTATUS_ACTL_REG   (* (reg8 *) PL1_RS485_BUART_sTX_TxSts__STATUS_AUX_CTL_REG)
    #define PL1_RS485_TXSTATUS_ACTL_PTR   (  (reg8 *) PL1_RS485_BUART_sTX_TxSts__STATUS_AUX_CTL_REG)

    /* DP clock */
    #if(PL1_RS485_TXCLKGEN_DP)
        #define PL1_RS485_TXBITCLKGEN_CTR_REG        \
                                        (* (reg8 *) PL1_RS485_BUART_sTX_sCLOCK_TxBitClkGen__D0_REG)
        #define PL1_RS485_TXBITCLKGEN_CTR_PTR        \
                                        (  (reg8 *) PL1_RS485_BUART_sTX_sCLOCK_TxBitClkGen__D0_REG)
        #define PL1_RS485_TXBITCLKTX_COMPLETE_REG    \
                                        (* (reg8 *) PL1_RS485_BUART_sTX_sCLOCK_TxBitClkGen__D1_REG)
        #define PL1_RS485_TXBITCLKTX_COMPLETE_PTR    \
                                        (  (reg8 *) PL1_RS485_BUART_sTX_sCLOCK_TxBitClkGen__D1_REG)
    #else     /* Count7 clock*/
        #define PL1_RS485_TXBITCTR_PERIOD_REG    \
                                        (* (reg8 *) PL1_RS485_BUART_sTX_sCLOCK_TxBitCounter__PERIOD_REG)
        #define PL1_RS485_TXBITCTR_PERIOD_PTR    \
                                        (  (reg8 *) PL1_RS485_BUART_sTX_sCLOCK_TxBitCounter__PERIOD_REG)
        #define PL1_RS485_TXBITCTR_CONTROL_REG   \
                                        (* (reg8 *) PL1_RS485_BUART_sTX_sCLOCK_TxBitCounter__CONTROL_AUX_CTL_REG)
        #define PL1_RS485_TXBITCTR_CONTROL_PTR   \
                                        (  (reg8 *) PL1_RS485_BUART_sTX_sCLOCK_TxBitCounter__CONTROL_AUX_CTL_REG)
        #define PL1_RS485_TXBITCTR_COUNTER_REG   \
                                        (* (reg8 *) PL1_RS485_BUART_sTX_sCLOCK_TxBitCounter__COUNT_REG)
        #define PL1_RS485_TXBITCTR_COUNTER_PTR   \
                                        (  (reg8 *) PL1_RS485_BUART_sTX_sCLOCK_TxBitCounter__COUNT_REG)
    #endif /* PL1_RS485_TXCLKGEN_DP */

#endif /* End PL1_RS485_TX_ENABLED */

#if(PL1_RS485_HD_ENABLED)

    #define PL1_RS485_TXDATA_REG             (* (reg8 *) PL1_RS485_BUART_sRX_RxShifter_u0__F1_REG )
    #define PL1_RS485_TXDATA_PTR             (  (reg8 *) PL1_RS485_BUART_sRX_RxShifter_u0__F1_REG )
    #define PL1_RS485_TXDATA_AUX_CTL_REG     (* (reg8 *) PL1_RS485_BUART_sRX_RxShifter_u0__DP_AUX_CTL_REG)
    #define PL1_RS485_TXDATA_AUX_CTL_PTR     (  (reg8 *) PL1_RS485_BUART_sRX_RxShifter_u0__DP_AUX_CTL_REG)

    #define PL1_RS485_TXSTATUS_REG           (* (reg8 *) PL1_RS485_BUART_sRX_RxSts__STATUS_REG )
    #define PL1_RS485_TXSTATUS_PTR           (  (reg8 *) PL1_RS485_BUART_sRX_RxSts__STATUS_REG )
    #define PL1_RS485_TXSTATUS_MASK_REG      (* (reg8 *) PL1_RS485_BUART_sRX_RxSts__MASK_REG )
    #define PL1_RS485_TXSTATUS_MASK_PTR      (  (reg8 *) PL1_RS485_BUART_sRX_RxSts__MASK_REG )
    #define PL1_RS485_TXSTATUS_ACTL_REG      (* (reg8 *) PL1_RS485_BUART_sRX_RxSts__STATUS_AUX_CTL_REG )
    #define PL1_RS485_TXSTATUS_ACTL_PTR      (  (reg8 *) PL1_RS485_BUART_sRX_RxSts__STATUS_AUX_CTL_REG )
#endif /* End PL1_RS485_HD_ENABLED */

#if( (PL1_RS485_RX_ENABLED) || (PL1_RS485_HD_ENABLED) )
    #define PL1_RS485_RXDATA_REG             (* (reg8 *) PL1_RS485_BUART_sRX_RxShifter_u0__F0_REG )
    #define PL1_RS485_RXDATA_PTR             (  (reg8 *) PL1_RS485_BUART_sRX_RxShifter_u0__F0_REG )
    #define PL1_RS485_RXADDRESS1_REG         (* (reg8 *) PL1_RS485_BUART_sRX_RxShifter_u0__D0_REG )
    #define PL1_RS485_RXADDRESS1_PTR         (  (reg8 *) PL1_RS485_BUART_sRX_RxShifter_u0__D0_REG )
    #define PL1_RS485_RXADDRESS2_REG         (* (reg8 *) PL1_RS485_BUART_sRX_RxShifter_u0__D1_REG )
    #define PL1_RS485_RXADDRESS2_PTR         (  (reg8 *) PL1_RS485_BUART_sRX_RxShifter_u0__D1_REG )
    #define PL1_RS485_RXDATA_AUX_CTL_REG     (* (reg8 *) PL1_RS485_BUART_sRX_RxShifter_u0__DP_AUX_CTL_REG)

    #define PL1_RS485_RXBITCTR_PERIOD_REG    (* (reg8 *) PL1_RS485_BUART_sRX_RxBitCounter__PERIOD_REG )
    #define PL1_RS485_RXBITCTR_PERIOD_PTR    (  (reg8 *) PL1_RS485_BUART_sRX_RxBitCounter__PERIOD_REG )
    #define PL1_RS485_RXBITCTR_CONTROL_REG   \
                                        (* (reg8 *) PL1_RS485_BUART_sRX_RxBitCounter__CONTROL_AUX_CTL_REG )
    #define PL1_RS485_RXBITCTR_CONTROL_PTR   \
                                        (  (reg8 *) PL1_RS485_BUART_sRX_RxBitCounter__CONTROL_AUX_CTL_REG )
    #define PL1_RS485_RXBITCTR_COUNTER_REG   (* (reg8 *) PL1_RS485_BUART_sRX_RxBitCounter__COUNT_REG )
    #define PL1_RS485_RXBITCTR_COUNTER_PTR   (  (reg8 *) PL1_RS485_BUART_sRX_RxBitCounter__COUNT_REG )

    #define PL1_RS485_RXSTATUS_REG           (* (reg8 *) PL1_RS485_BUART_sRX_RxSts__STATUS_REG )
    #define PL1_RS485_RXSTATUS_PTR           (  (reg8 *) PL1_RS485_BUART_sRX_RxSts__STATUS_REG )
    #define PL1_RS485_RXSTATUS_MASK_REG      (* (reg8 *) PL1_RS485_BUART_sRX_RxSts__MASK_REG )
    #define PL1_RS485_RXSTATUS_MASK_PTR      (  (reg8 *) PL1_RS485_BUART_sRX_RxSts__MASK_REG )
    #define PL1_RS485_RXSTATUS_ACTL_REG      (* (reg8 *) PL1_RS485_BUART_sRX_RxSts__STATUS_AUX_CTL_REG )
    #define PL1_RS485_RXSTATUS_ACTL_PTR      (  (reg8 *) PL1_RS485_BUART_sRX_RxSts__STATUS_AUX_CTL_REG )
#endif /* End  (PL1_RS485_RX_ENABLED) || (PL1_RS485_HD_ENABLED) */

#if(PL1_RS485_INTERNAL_CLOCK_USED)
    /* Register to enable or disable the digital clocks */
    #define PL1_RS485_INTCLOCK_CLKEN_REG     (* (reg8 *) PL1_RS485_IntClock__PM_ACT_CFG)
    #define PL1_RS485_INTCLOCK_CLKEN_PTR     (  (reg8 *) PL1_RS485_IntClock__PM_ACT_CFG)

    /* Clock mask for this clock. */
    #define PL1_RS485_INTCLOCK_CLKEN_MASK    PL1_RS485_IntClock__PM_ACT_MSK
#endif /* End PL1_RS485_INTERNAL_CLOCK_USED */


/***************************************
*       Register Constants
***************************************/

#if(PL1_RS485_TX_ENABLED)
    #define PL1_RS485_TX_FIFO_CLR            (0x01u) /* FIFO0 CLR */
#endif /* End PL1_RS485_TX_ENABLED */

#if(PL1_RS485_HD_ENABLED)
    #define PL1_RS485_TX_FIFO_CLR            (0x02u) /* FIFO1 CLR */
#endif /* End PL1_RS485_HD_ENABLED */

#if( (PL1_RS485_RX_ENABLED) || (PL1_RS485_HD_ENABLED) )
    #define PL1_RS485_RX_FIFO_CLR            (0x01u) /* FIFO0 CLR */
#endif /* End  (PL1_RS485_RX_ENABLED) || (PL1_RS485_HD_ENABLED) */


/***************************************
* Renamed global variables or defines
* for backward compatible
***************************************/

#define PL1_RS485_initvar                    PL1_RS485_initVar

#define PL1_RS485_RX_Enabled                 PL1_RS485_RX_ENABLED
#define PL1_RS485_TX_Enabled                 PL1_RS485_TX_ENABLED
#define PL1_RS485_HD_Enabled                 PL1_RS485_HD_ENABLED
#define PL1_RS485_RX_IntInterruptEnabled     PL1_RS485_RX_INTERRUPT_ENABLED
#define PL1_RS485_TX_IntInterruptEnabled     PL1_RS485_TX_INTERRUPT_ENABLED
#define PL1_RS485_InternalClockUsed          PL1_RS485_INTERNAL_CLOCK_USED
#define PL1_RS485_RXHW_Address_Enabled       PL1_RS485_RXHW_ADDRESS_ENABLED
#define PL1_RS485_OverSampleCount            PL1_RS485_OVER_SAMPLE_COUNT
#define PL1_RS485_ParityType                 PL1_RS485_PARITY_TYPE

#if( PL1_RS485_TX_ENABLED && (PL1_RS485_TXBUFFERSIZE > PL1_RS485_FIFO_LENGTH))
    #define PL1_RS485_TXBUFFER               PL1_RS485_txBuffer
    #define PL1_RS485_TXBUFFERREAD           PL1_RS485_txBufferRead
    #define PL1_RS485_TXBUFFERWRITE          PL1_RS485_txBufferWrite
#endif /* End PL1_RS485_TX_ENABLED */
#if( ( PL1_RS485_RX_ENABLED || PL1_RS485_HD_ENABLED ) && \
     (PL1_RS485_RXBUFFERSIZE > PL1_RS485_FIFO_LENGTH) )
    #define PL1_RS485_RXBUFFER               PL1_RS485_rxBuffer
    #define PL1_RS485_RXBUFFERREAD           PL1_RS485_rxBufferRead
    #define PL1_RS485_RXBUFFERWRITE          PL1_RS485_rxBufferWrite
    #define PL1_RS485_RXBUFFERLOOPDETECT     PL1_RS485_rxBufferLoopDetect
    #define PL1_RS485_RXBUFFER_OVERFLOW      PL1_RS485_rxBufferOverflow
#endif /* End PL1_RS485_RX_ENABLED */

#ifdef PL1_RS485_BUART_sCR_SyncCtl_CtrlReg__CONTROL_REG
    #define PL1_RS485_CONTROL                PL1_RS485_CONTROL_REG
#endif /* End PL1_RS485_BUART_sCR_SyncCtl_CtrlReg__CONTROL_REG */

#if(PL1_RS485_TX_ENABLED)
    #define PL1_RS485_TXDATA                 PL1_RS485_TXDATA_REG
    #define PL1_RS485_TXSTATUS               PL1_RS485_TXSTATUS_REG
    #define PL1_RS485_TXSTATUS_MASK          PL1_RS485_TXSTATUS_MASK_REG
    #define PL1_RS485_TXSTATUS_ACTL          PL1_RS485_TXSTATUS_ACTL_REG
    /* DP clock */
    #if(PL1_RS485_TXCLKGEN_DP)
        #define PL1_RS485_TXBITCLKGEN_CTR        PL1_RS485_TXBITCLKGEN_CTR_REG
        #define PL1_RS485_TXBITCLKTX_COMPLETE    PL1_RS485_TXBITCLKTX_COMPLETE_REG
    #else     /* Count7 clock*/
        #define PL1_RS485_TXBITCTR_PERIOD        PL1_RS485_TXBITCTR_PERIOD_REG
        #define PL1_RS485_TXBITCTR_CONTROL       PL1_RS485_TXBITCTR_CONTROL_REG
        #define PL1_RS485_TXBITCTR_COUNTER       PL1_RS485_TXBITCTR_COUNTER_REG
    #endif /* PL1_RS485_TXCLKGEN_DP */
#endif /* End PL1_RS485_TX_ENABLED */

#if(PL1_RS485_HD_ENABLED)
    #define PL1_RS485_TXDATA                 PL1_RS485_TXDATA_REG
    #define PL1_RS485_TXSTATUS               PL1_RS485_TXSTATUS_REG
    #define PL1_RS485_TXSTATUS_MASK          PL1_RS485_TXSTATUS_MASK_REG
    #define PL1_RS485_TXSTATUS_ACTL          PL1_RS485_TXSTATUS_ACTL_REG
#endif /* End PL1_RS485_HD_ENABLED */

#if( (PL1_RS485_RX_ENABLED) || (PL1_RS485_HD_ENABLED) )
    #define PL1_RS485_RXDATA                 PL1_RS485_RXDATA_REG
    #define PL1_RS485_RXADDRESS1             PL1_RS485_RXADDRESS1_REG
    #define PL1_RS485_RXADDRESS2             PL1_RS485_RXADDRESS2_REG
    #define PL1_RS485_RXBITCTR_PERIOD        PL1_RS485_RXBITCTR_PERIOD_REG
    #define PL1_RS485_RXBITCTR_CONTROL       PL1_RS485_RXBITCTR_CONTROL_REG
    #define PL1_RS485_RXBITCTR_COUNTER       PL1_RS485_RXBITCTR_COUNTER_REG
    #define PL1_RS485_RXSTATUS               PL1_RS485_RXSTATUS_REG
    #define PL1_RS485_RXSTATUS_MASK          PL1_RS485_RXSTATUS_MASK_REG
    #define PL1_RS485_RXSTATUS_ACTL          PL1_RS485_RXSTATUS_ACTL_REG
#endif /* End  (PL1_RS485_RX_ENABLED) || (PL1_RS485_HD_ENABLED) */

#if(PL1_RS485_INTERNAL_CLOCK_USED)
    #define PL1_RS485_INTCLOCK_CLKEN         PL1_RS485_INTCLOCK_CLKEN_REG
#endif /* End PL1_RS485_INTERNAL_CLOCK_USED */

#define PL1_RS485_WAIT_FOR_COMLETE_REINIT    PL1_RS485_WAIT_FOR_COMPLETE_REINIT

#endif  /* CY_UART_PL1_RS485_H */


/* [] END OF FILE */
