/*******************************************************************************
* File Name: PL2_RS485_PM.c
* Version 2.30
*
* Description:
*  This file provides Sleep/WakeUp APIs functionality.
*
* Note:
*
********************************************************************************
* Copyright 2008-2012, Cypress Semiconductor Corporation.  All rights reserved.
* You may use this file only in accordance with the license, terms, conditions,
* disclaimers, and limitations in the end user license agreement accompanying
* the software package with which this file was provided.
*******************************************************************************/

#include "PL2_RS485.h"


/***************************************
* Local data allocation
***************************************/

static PL2_RS485_BACKUP_STRUCT  PL2_RS485_backup =
{
    /* enableState - disabled */
    0u,
};



/*******************************************************************************
* Function Name: PL2_RS485_SaveConfig
********************************************************************************
*
* Summary:
*  Saves the current user configuration.
*
* Parameters:
*  None.
*
* Return:
*  None.
*
* Global Variables:
*  PL2_RS485_backup - modified when non-retention registers are saved.
*
* Reentrant:
*  No.
*
*******************************************************************************/
void PL2_RS485_SaveConfig(void)
{
    #if (CY_UDB_V0)

        #if(PL2_RS485_CONTROL_REG_REMOVED == 0u)
            PL2_RS485_backup.cr = PL2_RS485_CONTROL_REG;
        #endif /* End PL2_RS485_CONTROL_REG_REMOVED */

        #if( (PL2_RS485_RX_ENABLED) || (PL2_RS485_HD_ENABLED) )
            PL2_RS485_backup.rx_period = PL2_RS485_RXBITCTR_PERIOD_REG;
            PL2_RS485_backup.rx_mask = PL2_RS485_RXSTATUS_MASK_REG;
            #if (PL2_RS485_RXHW_ADDRESS_ENABLED)
                PL2_RS485_backup.rx_addr1 = PL2_RS485_RXADDRESS1_REG;
                PL2_RS485_backup.rx_addr2 = PL2_RS485_RXADDRESS2_REG;
            #endif /* End PL2_RS485_RXHW_ADDRESS_ENABLED */
        #endif /* End PL2_RS485_RX_ENABLED | PL2_RS485_HD_ENABLED*/

        #if(PL2_RS485_TX_ENABLED)
            #if(PL2_RS485_TXCLKGEN_DP)
                PL2_RS485_backup.tx_clk_ctr = PL2_RS485_TXBITCLKGEN_CTR_REG;
                PL2_RS485_backup.tx_clk_compl = PL2_RS485_TXBITCLKTX_COMPLETE_REG;
            #else
                PL2_RS485_backup.tx_period = PL2_RS485_TXBITCTR_PERIOD_REG;
            #endif /*End PL2_RS485_TXCLKGEN_DP */
            PL2_RS485_backup.tx_mask = PL2_RS485_TXSTATUS_MASK_REG;
        #endif /*End PL2_RS485_TX_ENABLED */


    #else /* CY_UDB_V1 */

        #if(PL2_RS485_CONTROL_REG_REMOVED == 0u)
            PL2_RS485_backup.cr = PL2_RS485_CONTROL_REG;
        #endif /* End PL2_RS485_CONTROL_REG_REMOVED */

    #endif  /* End CY_UDB_V0 */
}


/*******************************************************************************
* Function Name: PL2_RS485_RestoreConfig
********************************************************************************
*
* Summary:
*  Restores the current user configuration.
*
* Parameters:
*  None.
*
* Return:
*  None.
*
* Global Variables:
*  PL2_RS485_backup - used when non-retention registers are restored.
*
* Reentrant:
*  No.
*
*******************************************************************************/
void PL2_RS485_RestoreConfig(void)
{

    #if (CY_UDB_V0)

        #if(PL2_RS485_CONTROL_REG_REMOVED == 0u)
            PL2_RS485_CONTROL_REG = PL2_RS485_backup.cr;
        #endif /* End PL2_RS485_CONTROL_REG_REMOVED */

        #if( (PL2_RS485_RX_ENABLED) || (PL2_RS485_HD_ENABLED) )
            PL2_RS485_RXBITCTR_PERIOD_REG = PL2_RS485_backup.rx_period;
            PL2_RS485_RXSTATUS_MASK_REG = PL2_RS485_backup.rx_mask;
            #if (PL2_RS485_RXHW_ADDRESS_ENABLED)
                PL2_RS485_RXADDRESS1_REG = PL2_RS485_backup.rx_addr1;
                PL2_RS485_RXADDRESS2_REG = PL2_RS485_backup.rx_addr2;
            #endif /* End PL2_RS485_RXHW_ADDRESS_ENABLED */
        #endif  /* End (PL2_RS485_RX_ENABLED) || (PL2_RS485_HD_ENABLED) */

        #if(PL2_RS485_TX_ENABLED)
            #if(PL2_RS485_TXCLKGEN_DP)
                PL2_RS485_TXBITCLKGEN_CTR_REG = PL2_RS485_backup.tx_clk_ctr;
                PL2_RS485_TXBITCLKTX_COMPLETE_REG = PL2_RS485_backup.tx_clk_compl;
            #else
                PL2_RS485_TXBITCTR_PERIOD_REG = PL2_RS485_backup.tx_period;
            #endif /*End PL2_RS485_TXCLKGEN_DP */
            PL2_RS485_TXSTATUS_MASK_REG = PL2_RS485_backup.tx_mask;
        #endif /*End PL2_RS485_TX_ENABLED */

    #else /* CY_UDB_V1 */

        #if(PL2_RS485_CONTROL_REG_REMOVED == 0u)
            PL2_RS485_CONTROL_REG = PL2_RS485_backup.cr;
        #endif /* End PL2_RS485_CONTROL_REG_REMOVED */

    #endif  /* End CY_UDB_V0 */
}


/*******************************************************************************
* Function Name: PL2_RS485_Sleep
********************************************************************************
*
* Summary:
*  Stops and saves the user configuration. Should be called
*  just prior to entering sleep.
*
*
* Parameters:
*  None.
*
* Return:
*  None.
*
* Global Variables:
*  PL2_RS485_backup - modified when non-retention registers are saved.
*
* Reentrant:
*  No.
*
*******************************************************************************/
void PL2_RS485_Sleep(void)
{

    #if(PL2_RS485_RX_ENABLED || PL2_RS485_HD_ENABLED)
        if((PL2_RS485_RXSTATUS_ACTL_REG  & PL2_RS485_INT_ENABLE) != 0u)
        {
            PL2_RS485_backup.enableState = 1u;
        }
        else
        {
            PL2_RS485_backup.enableState = 0u;
        }
    #else
        if((PL2_RS485_TXSTATUS_ACTL_REG  & PL2_RS485_INT_ENABLE) !=0u)
        {
            PL2_RS485_backup.enableState = 1u;
        }
        else
        {
            PL2_RS485_backup.enableState = 0u;
        }
    #endif /* End PL2_RS485_RX_ENABLED || PL2_RS485_HD_ENABLED*/

    PL2_RS485_Stop();
    PL2_RS485_SaveConfig();
}


/*******************************************************************************
* Function Name: PL2_RS485_Wakeup
********************************************************************************
*
* Summary:
*  Restores and enables the user configuration. Should be called
*  just after awaking from sleep.
*
* Parameters:
*  None.
*
* Return:
*  None.
*
* Global Variables:
*  PL2_RS485_backup - used when non-retention registers are restored.
*
* Reentrant:
*  No.
*
*******************************************************************************/
void PL2_RS485_Wakeup(void)
{
    PL2_RS485_RestoreConfig();
    #if( (PL2_RS485_RX_ENABLED) || (PL2_RS485_HD_ENABLED) )
        PL2_RS485_ClearRxBuffer();
    #endif /* End (PL2_RS485_RX_ENABLED) || (PL2_RS485_HD_ENABLED) */
    #if(PL2_RS485_TX_ENABLED || PL2_RS485_HD_ENABLED)
        PL2_RS485_ClearTxBuffer();
    #endif /* End PL2_RS485_TX_ENABLED || PL2_RS485_HD_ENABLED */

    if(PL2_RS485_backup.enableState != 0u)
    {
        PL2_RS485_Enable();
    }
}


/* [] END OF FILE */
