/*******************************************************************************
* File Name: PL2_RS485_TxInt.c  
* Version 1.70
*
*  Description:
*   API for controlling the state of an interrupt.
*
*
*  Note:
*
********************************************************************************
* Copyright 2008-2012, Cypress Semiconductor Corporation.  All rights reserved.
* You may use this file only in accordance with the license, terms, conditions, 
* disclaimers, and limitations in the end user license agreement accompanying 
* the software package with which this file was provided.
*******************************************************************************/


#include <cydevice_trm.h>
#include <CyLib.h>
#include <PL2_RS485_TxInt.h>

#if !defined(PL2_RS485_TxInt__REMOVED) /* Check for removal by optimization */

/*******************************************************************************
*  Place your includes, defines and code here 
********************************************************************************/
/* `#START PL2_RS485_TxInt_intc` */

/* `#END` */

#ifndef CYINT_IRQ_BASE
#define CYINT_IRQ_BASE      16
#endif /* CYINT_IRQ_BASE */
#ifndef CYINT_VECT_TABLE
#define CYINT_VECT_TABLE    ((cyisraddress **) CYREG_NVIC_VECT_OFFSET)
#endif /* CYINT_VECT_TABLE */

/* Declared in startup, used to set unused interrupts to. */
CY_ISR_PROTO(IntDefaultHandler);


/*******************************************************************************
* Function Name: PL2_RS485_TxInt_Start
********************************************************************************
*
* Summary:
*  Set up the interrupt and enable it.
*
* Parameters:  
*   None
*
* Return:
*   None
*
*******************************************************************************/
void PL2_RS485_TxInt_Start(void)
{
    /* For all we know the interrupt is active. */
    PL2_RS485_TxInt_Disable();

    /* Set the ISR to point to the PL2_RS485_TxInt Interrupt. */
    PL2_RS485_TxInt_SetVector(&PL2_RS485_TxInt_Interrupt);

    /* Set the priority. */
    PL2_RS485_TxInt_SetPriority((uint8)PL2_RS485_TxInt_INTC_PRIOR_NUMBER);

    /* Enable it. */
    PL2_RS485_TxInt_Enable();
}


/*******************************************************************************
* Function Name: PL2_RS485_TxInt_StartEx
********************************************************************************
*
* Summary:
*  Set up the interrupt and enable it.
*
* Parameters:  
*   address: Address of the ISR to set in the interrupt vector table.
*
* Return:
*   None
*
*******************************************************************************/
void PL2_RS485_TxInt_StartEx(cyisraddress address)
{
    /* For all we know the interrupt is active. */
    PL2_RS485_TxInt_Disable();

    /* Set the ISR to point to the PL2_RS485_TxInt Interrupt. */
    PL2_RS485_TxInt_SetVector(address);

    /* Set the priority. */
    PL2_RS485_TxInt_SetPriority((uint8)PL2_RS485_TxInt_INTC_PRIOR_NUMBER);

    /* Enable it. */
    PL2_RS485_TxInt_Enable();
}


/*******************************************************************************
* Function Name: PL2_RS485_TxInt_Stop
********************************************************************************
*
* Summary:
*   Disables and removes the interrupt.
*
* Parameters:  
*
* Return:
*   None
*
*******************************************************************************/
void PL2_RS485_TxInt_Stop(void)
{
    /* Disable this interrupt. */
    PL2_RS485_TxInt_Disable();

    /* Set the ISR to point to the passive one. */
    PL2_RS485_TxInt_SetVector(&IntDefaultHandler);
}


/*******************************************************************************
* Function Name: PL2_RS485_TxInt_Interrupt
********************************************************************************
*
* Summary:
*   The default Interrupt Service Routine for PL2_RS485_TxInt.
*
*   Add custom code between the coments to keep the next version of this file
*   from over writting your code.
*
* Parameters:  
*
* Return:
*   None
*
*******************************************************************************/
CY_ISR(PL2_RS485_TxInt_Interrupt)
{
    /*  Place your Interrupt code here. */
    /* `#START PL2_RS485_TxInt_Interrupt` */

    /* `#END` */
}


/*******************************************************************************
* Function Name: PL2_RS485_TxInt_SetVector
********************************************************************************
*
* Summary:
*   Change the ISR vector for the Interrupt. Note calling PL2_RS485_TxInt_Start
*   will override any effect this method would have had. To set the vector 
*   before the component has been started use PL2_RS485_TxInt_StartEx instead.
*
* Parameters:
*   address: Address of the ISR to set in the interrupt vector table.
*
* Return:
*   None
*
*******************************************************************************/
void PL2_RS485_TxInt_SetVector(cyisraddress address)
{
    cyisraddress * ramVectorTable;

    ramVectorTable = (cyisraddress *) *CYINT_VECT_TABLE;

    ramVectorTable[CYINT_IRQ_BASE + (uint32)PL2_RS485_TxInt__INTC_NUMBER] = address;
}


/*******************************************************************************
* Function Name: PL2_RS485_TxInt_GetVector
********************************************************************************
*
* Summary:
*   Gets the "address" of the current ISR vector for the Interrupt.
*
* Parameters:
*   None
*
* Return:
*   Address of the ISR in the interrupt vector table.
*
*******************************************************************************/
cyisraddress PL2_RS485_TxInt_GetVector(void)
{
    cyisraddress * ramVectorTable;

    ramVectorTable = (cyisraddress *) *CYINT_VECT_TABLE;

    return ramVectorTable[CYINT_IRQ_BASE + (uint32)PL2_RS485_TxInt__INTC_NUMBER];
}


/*******************************************************************************
* Function Name: PL2_RS485_TxInt_SetPriority
********************************************************************************
*
* Summary:
*   Sets the Priority of the Interrupt. Note calling PL2_RS485_TxInt_Start
*   or PL2_RS485_TxInt_StartEx will override any effect this method 
*   would have had. This method should only be called after 
*   PL2_RS485_TxInt_Start or PL2_RS485_TxInt_StartEx has been called. To set 
*   the initial priority for the component use the cydwr file in the tool.
*
* Parameters:
*   priority: Priority of the interrupt. 0 - 7, 0 being the highest.
*
* Return:
*   None
*
*******************************************************************************/
void PL2_RS485_TxInt_SetPriority(uint8 priority)
{
    *PL2_RS485_TxInt_INTC_PRIOR = priority << 5;
}


/*******************************************************************************
* Function Name: PL2_RS485_TxInt_GetPriority
********************************************************************************
*
* Summary:
*   Gets the Priority of the Interrupt.
*
* Parameters:
*   None
*
* Return:
*   Priority of the interrupt. 0 - 7, 0 being the highest.
*
*******************************************************************************/
uint8 PL2_RS485_TxInt_GetPriority(void)
{
    uint8 priority;


    priority = *PL2_RS485_TxInt_INTC_PRIOR >> 5;

    return priority;
}


/*******************************************************************************
* Function Name: PL2_RS485_TxInt_Enable
********************************************************************************
*
* Summary:
*   Enables the interrupt.
*
* Parameters:
*   None
*
* Return:
*   None
*
*******************************************************************************/
void PL2_RS485_TxInt_Enable(void)
{
    /* Enable the general interrupt. */
    *PL2_RS485_TxInt_INTC_SET_EN = PL2_RS485_TxInt__INTC_MASK;
}


/*******************************************************************************
* Function Name: PL2_RS485_TxInt_GetState
********************************************************************************
*
* Summary:
*   Gets the state (enabled, disabled) of the Interrupt.
*
* Parameters:
*   None
*
* Return:
*   1 if enabled, 0 if disabled.
*
*******************************************************************************/
uint8 PL2_RS485_TxInt_GetState(void)
{
    /* Get the state of the general interrupt. */
    return ((*PL2_RS485_TxInt_INTC_SET_EN & (uint32)PL2_RS485_TxInt__INTC_MASK) != 0u) ? 1u:0u;
}


/*******************************************************************************
* Function Name: PL2_RS485_TxInt_Disable
********************************************************************************
*
* Summary:
*   Disables the Interrupt.
*
* Parameters:
*   None
*
* Return:
*   None
*
*******************************************************************************/
void PL2_RS485_TxInt_Disable(void)
{
    /* Disable the general interrupt. */
    *PL2_RS485_TxInt_INTC_CLR_EN = PL2_RS485_TxInt__INTC_MASK;
}


/*******************************************************************************
* Function Name: PL2_RS485_TxInt_SetPending
********************************************************************************
*
* Summary:
*   Causes the Interrupt to enter the pending state, a software method of
*   generating the interrupt.
*
* Parameters:
*   None
*
* Return:
*   None
*
*******************************************************************************/
void PL2_RS485_TxInt_SetPending(void)
{
    *PL2_RS485_TxInt_INTC_SET_PD = PL2_RS485_TxInt__INTC_MASK;
}


/*******************************************************************************
* Function Name: PL2_RS485_TxInt_ClearPending
********************************************************************************
*
* Summary:
*   Clears a pending interrupt.
*
* Parameters:
*   None
*
* Return:
*   None
*
*******************************************************************************/
void PL2_RS485_TxInt_ClearPending(void)
{
    *PL2_RS485_TxInt_INTC_CLR_PD = PL2_RS485_TxInt__INTC_MASK;
}

#endif /* End check for removal by optimization */


/* [] END OF FILE */
