/*******************************************************************************
* File Name: RES_SW.c  
* Version 2.0
*
* Description:
*  This file contains API to enable firmware control of a Pins component.
*
* Note:
*
********************************************************************************
* Copyright 2008-2014, Cypress Semiconductor Corporation.  All rights reserved.
* You may use this file only in accordance with the license, terms, conditions, 
* disclaimers, and limitations in the end user license agreement accompanying 
* the software package with which this file was provided.
*******************************************************************************/

#include "cytypes.h"
#include "RES_SW.h"

/* APIs are not generated for P15[7:6] on PSoC 5 */
#if !(CY_PSOC5A &&\
	 RES_SW__PORT == 15 && ((RES_SW__MASK & 0xC0) != 0))


/*******************************************************************************
* Function Name: RES_SW_Write
********************************************************************************
*
* Summary:
*  Assign a new value to the digital port's data output register.  
*
* Parameters:  
*  prtValue:  The value to be assigned to the Digital Port. 
*
* Return: 
*  None
*  
*******************************************************************************/
void RES_SW_Write(uint8 value) 
{
    uint8 staticBits = (RES_SW_DR & (uint8)(~RES_SW_MASK));
    RES_SW_DR = staticBits | ((uint8)(value << RES_SW_SHIFT) & RES_SW_MASK);
}


/*******************************************************************************
* Function Name: RES_SW_SetDriveMode
********************************************************************************
*
* Summary:
*  Change the drive mode on the pins of the port.
* 
* Parameters:  
*  mode:  Change the pins to one of the following drive modes.
*
*  RES_SW_DM_STRONG     Strong Drive 
*  RES_SW_DM_OD_HI      Open Drain, Drives High 
*  RES_SW_DM_OD_LO      Open Drain, Drives Low 
*  RES_SW_DM_RES_UP     Resistive Pull Up 
*  RES_SW_DM_RES_DWN    Resistive Pull Down 
*  RES_SW_DM_RES_UPDWN  Resistive Pull Up/Down 
*  RES_SW_DM_DIG_HIZ    High Impedance Digital 
*  RES_SW_DM_ALG_HIZ    High Impedance Analog 
*
* Return: 
*  None
*
*******************************************************************************/
void RES_SW_SetDriveMode(uint8 mode) 
{
	CyPins_SetPinDriveMode(RES_SW_0, mode);
}


/*******************************************************************************
* Function Name: RES_SW_Read
********************************************************************************
*
* Summary:
*  Read the current value on the pins of the Digital Port in right justified 
*  form.
*
* Parameters:  
*  None
*
* Return: 
*  Returns the current value of the Digital Port as a right justified number
*  
* Note:
*  Macro RES_SW_ReadPS calls this function. 
*  
*******************************************************************************/
uint8 RES_SW_Read(void) 
{
    return (RES_SW_PS & RES_SW_MASK) >> RES_SW_SHIFT;
}


/*******************************************************************************
* Function Name: RES_SW_ReadDataReg
********************************************************************************
*
* Summary:
*  Read the current value assigned to a Digital Port's data output register
*
* Parameters:  
*  None 
*
* Return: 
*  Returns the current value assigned to the Digital Port's data output register
*  
*******************************************************************************/
uint8 RES_SW_ReadDataReg(void) 
{
    return (RES_SW_DR & RES_SW_MASK) >> RES_SW_SHIFT;
}


/* If Interrupts Are Enabled for this Pins component */ 
#if defined(RES_SW_INTSTAT) 

    /*******************************************************************************
    * Function Name: RES_SW_ClearInterrupt
    ********************************************************************************
    * Summary:
    *  Clears any active interrupts attached to port and returns the value of the 
    *  interrupt status register.
    *
    * Parameters:  
    *  None 
    *
    * Return: 
    *  Returns the value of the interrupt status register
    *  
    *******************************************************************************/
    uint8 RES_SW_ClearInterrupt(void) 
    {
        return (RES_SW_INTSTAT & RES_SW_MASK) >> RES_SW_SHIFT;
    }

#endif /* If Interrupts Are Enabled for this Pins component */ 

#endif /* CY_PSOC5A... */

    
/* [] END OF FILE */
