/*******************************************************************************
* File Name: RS232_LEDJ.c  
* Version 2.0
*
* Description:
*  This file contains API to enable firmware control of a Pins component.
*
* Note:
*
********************************************************************************
* Copyright 2008-2014, Cypress Semiconductor Corporation.  All rights reserved.
* You may use this file only in accordance with the license, terms, conditions, 
* disclaimers, and limitations in the end user license agreement accompanying 
* the software package with which this file was provided.
*******************************************************************************/

#include "cytypes.h"
#include "RS232_LEDJ.h"

/* APIs are not generated for P15[7:6] on PSoC 5 */
#if !(CY_PSOC5A &&\
	 RS232_LEDJ__PORT == 15 && ((RS232_LEDJ__MASK & 0xC0) != 0))


/*******************************************************************************
* Function Name: RS232_LEDJ_Write
********************************************************************************
*
* Summary:
*  Assign a new value to the digital port's data output register.  
*
* Parameters:  
*  prtValue:  The value to be assigned to the Digital Port. 
*
* Return: 
*  None
*  
*******************************************************************************/
void RS232_LEDJ_Write(uint8 value) 
{
    uint8 staticBits = (RS232_LEDJ_DR & (uint8)(~RS232_LEDJ_MASK));
    RS232_LEDJ_DR = staticBits | ((uint8)(value << RS232_LEDJ_SHIFT) & RS232_LEDJ_MASK);
}


/*******************************************************************************
* Function Name: RS232_LEDJ_SetDriveMode
********************************************************************************
*
* Summary:
*  Change the drive mode on the pins of the port.
* 
* Parameters:  
*  mode:  Change the pins to one of the following drive modes.
*
*  RS232_LEDJ_DM_STRONG     Strong Drive 
*  RS232_LEDJ_DM_OD_HI      Open Drain, Drives High 
*  RS232_LEDJ_DM_OD_LO      Open Drain, Drives Low 
*  RS232_LEDJ_DM_RES_UP     Resistive Pull Up 
*  RS232_LEDJ_DM_RES_DWN    Resistive Pull Down 
*  RS232_LEDJ_DM_RES_UPDWN  Resistive Pull Up/Down 
*  RS232_LEDJ_DM_DIG_HIZ    High Impedance Digital 
*  RS232_LEDJ_DM_ALG_HIZ    High Impedance Analog 
*
* Return: 
*  None
*
*******************************************************************************/
void RS232_LEDJ_SetDriveMode(uint8 mode) 
{
	CyPins_SetPinDriveMode(RS232_LEDJ_0, mode);
}


/*******************************************************************************
* Function Name: RS232_LEDJ_Read
********************************************************************************
*
* Summary:
*  Read the current value on the pins of the Digital Port in right justified 
*  form.
*
* Parameters:  
*  None
*
* Return: 
*  Returns the current value of the Digital Port as a right justified number
*  
* Note:
*  Macro RS232_LEDJ_ReadPS calls this function. 
*  
*******************************************************************************/
uint8 RS232_LEDJ_Read(void) 
{
    return (RS232_LEDJ_PS & RS232_LEDJ_MASK) >> RS232_LEDJ_SHIFT;
}


/*******************************************************************************
* Function Name: RS232_LEDJ_ReadDataReg
********************************************************************************
*
* Summary:
*  Read the current value assigned to a Digital Port's data output register
*
* Parameters:  
*  None 
*
* Return: 
*  Returns the current value assigned to the Digital Port's data output register
*  
*******************************************************************************/
uint8 RS232_LEDJ_ReadDataReg(void) 
{
    return (RS232_LEDJ_DR & RS232_LEDJ_MASK) >> RS232_LEDJ_SHIFT;
}


/* If Interrupts Are Enabled for this Pins component */ 
#if defined(RS232_LEDJ_INTSTAT) 

    /*******************************************************************************
    * Function Name: RS232_LEDJ_ClearInterrupt
    ********************************************************************************
    * Summary:
    *  Clears any active interrupts attached to port and returns the value of the 
    *  interrupt status register.
    *
    * Parameters:  
    *  None 
    *
    * Return: 
    *  Returns the value of the interrupt status register
    *  
    *******************************************************************************/
    uint8 RS232_LEDJ_ClearInterrupt(void) 
    {
        return (RS232_LEDJ_INTSTAT & RS232_LEDJ_MASK) >> RS232_LEDJ_SHIFT;
    }

#endif /* If Interrupts Are Enabled for this Pins component */ 

#endif /* CY_PSOC5A... */

    
/* [] END OF FILE */
