/*******************************************************************************
* File Name: RS232_RxInt.c  
* Version 1.70
*
*  Description:
*   API for controlling the state of an interrupt.
*
*
*  Note:
*
********************************************************************************
* Copyright 2008-2012, Cypress Semiconductor Corporation.  All rights reserved.
* You may use this file only in accordance with the license, terms, conditions, 
* disclaimers, and limitations in the end user license agreement accompanying 
* the software package with which this file was provided.
*******************************************************************************/


#include <cydevice_trm.h>
#include <CyLib.h>
#include <RS232_RxInt.h>

#if !defined(RS232_RxInt__REMOVED) /* Check for removal by optimization */

/*******************************************************************************
*  Place your includes, defines and code here 
********************************************************************************/
/* `#START RS232_RxInt_intc` */

/* `#END` */

#ifndef CYINT_IRQ_BASE
#define CYINT_IRQ_BASE      16
#endif /* CYINT_IRQ_BASE */
#ifndef CYINT_VECT_TABLE
#define CYINT_VECT_TABLE    ((cyisraddress **) CYREG_NVIC_VECT_OFFSET)
#endif /* CYINT_VECT_TABLE */

/* Declared in startup, used to set unused interrupts to. */
CY_ISR_PROTO(IntDefaultHandler);


/*******************************************************************************
* Function Name: RS232_RxInt_Start
********************************************************************************
*
* Summary:
*  Set up the interrupt and enable it.
*
* Parameters:  
*   None
*
* Return:
*   None
*
*******************************************************************************/
void RS232_RxInt_Start(void)
{
    /* For all we know the interrupt is active. */
    RS232_RxInt_Disable();

    /* Set the ISR to point to the RS232_RxInt Interrupt. */
    RS232_RxInt_SetVector(&RS232_RxInt_Interrupt);

    /* Set the priority. */
    RS232_RxInt_SetPriority((uint8)RS232_RxInt_INTC_PRIOR_NUMBER);

    /* Enable it. */
    RS232_RxInt_Enable();
}


/*******************************************************************************
* Function Name: RS232_RxInt_StartEx
********************************************************************************
*
* Summary:
*  Set up the interrupt and enable it.
*
* Parameters:  
*   address: Address of the ISR to set in the interrupt vector table.
*
* Return:
*   None
*
*******************************************************************************/
void RS232_RxInt_StartEx(cyisraddress address)
{
    /* For all we know the interrupt is active. */
    RS232_RxInt_Disable();

    /* Set the ISR to point to the RS232_RxInt Interrupt. */
    RS232_RxInt_SetVector(address);

    /* Set the priority. */
    RS232_RxInt_SetPriority((uint8)RS232_RxInt_INTC_PRIOR_NUMBER);

    /* Enable it. */
    RS232_RxInt_Enable();
}


/*******************************************************************************
* Function Name: RS232_RxInt_Stop
********************************************************************************
*
* Summary:
*   Disables and removes the interrupt.
*
* Parameters:  
*
* Return:
*   None
*
*******************************************************************************/
void RS232_RxInt_Stop(void)
{
    /* Disable this interrupt. */
    RS232_RxInt_Disable();

    /* Set the ISR to point to the passive one. */
    RS232_RxInt_SetVector(&IntDefaultHandler);
}


/*******************************************************************************
* Function Name: RS232_RxInt_Interrupt
********************************************************************************
*
* Summary:
*   The default Interrupt Service Routine for RS232_RxInt.
*
*   Add custom code between the coments to keep the next version of this file
*   from over writting your code.
*
* Parameters:  
*
* Return:
*   None
*
*******************************************************************************/
CY_ISR(RS232_RxInt_Interrupt)
{
    /*  Place your Interrupt code here. */
    /* `#START RS232_RxInt_Interrupt` */

    /* `#END` */
}


/*******************************************************************************
* Function Name: RS232_RxInt_SetVector
********************************************************************************
*
* Summary:
*   Change the ISR vector for the Interrupt. Note calling RS232_RxInt_Start
*   will override any effect this method would have had. To set the vector 
*   before the component has been started use RS232_RxInt_StartEx instead.
*
* Parameters:
*   address: Address of the ISR to set in the interrupt vector table.
*
* Return:
*   None
*
*******************************************************************************/
void RS232_RxInt_SetVector(cyisraddress address)
{
    cyisraddress * ramVectorTable;

    ramVectorTable = (cyisraddress *) *CYINT_VECT_TABLE;

    ramVectorTable[CYINT_IRQ_BASE + (uint32)RS232_RxInt__INTC_NUMBER] = address;
}


/*******************************************************************************
* Function Name: RS232_RxInt_GetVector
********************************************************************************
*
* Summary:
*   Gets the "address" of the current ISR vector for the Interrupt.
*
* Parameters:
*   None
*
* Return:
*   Address of the ISR in the interrupt vector table.
*
*******************************************************************************/
cyisraddress RS232_RxInt_GetVector(void)
{
    cyisraddress * ramVectorTable;

    ramVectorTable = (cyisraddress *) *CYINT_VECT_TABLE;

    return ramVectorTable[CYINT_IRQ_BASE + (uint32)RS232_RxInt__INTC_NUMBER];
}


/*******************************************************************************
* Function Name: RS232_RxInt_SetPriority
********************************************************************************
*
* Summary:
*   Sets the Priority of the Interrupt. Note calling RS232_RxInt_Start
*   or RS232_RxInt_StartEx will override any effect this method 
*   would have had. This method should only be called after 
*   RS232_RxInt_Start or RS232_RxInt_StartEx has been called. To set 
*   the initial priority for the component use the cydwr file in the tool.
*
* Parameters:
*   priority: Priority of the interrupt. 0 - 7, 0 being the highest.
*
* Return:
*   None
*
*******************************************************************************/
void RS232_RxInt_SetPriority(uint8 priority)
{
    *RS232_RxInt_INTC_PRIOR = priority << 5;
}


/*******************************************************************************
* Function Name: RS232_RxInt_GetPriority
********************************************************************************
*
* Summary:
*   Gets the Priority of the Interrupt.
*
* Parameters:
*   None
*
* Return:
*   Priority of the interrupt. 0 - 7, 0 being the highest.
*
*******************************************************************************/
uint8 RS232_RxInt_GetPriority(void)
{
    uint8 priority;


    priority = *RS232_RxInt_INTC_PRIOR >> 5;

    return priority;
}


/*******************************************************************************
* Function Name: RS232_RxInt_Enable
********************************************************************************
*
* Summary:
*   Enables the interrupt.
*
* Parameters:
*   None
*
* Return:
*   None
*
*******************************************************************************/
void RS232_RxInt_Enable(void)
{
    /* Enable the general interrupt. */
    *RS232_RxInt_INTC_SET_EN = RS232_RxInt__INTC_MASK;
}


/*******************************************************************************
* Function Name: RS232_RxInt_GetState
********************************************************************************
*
* Summary:
*   Gets the state (enabled, disabled) of the Interrupt.
*
* Parameters:
*   None
*
* Return:
*   1 if enabled, 0 if disabled.
*
*******************************************************************************/
uint8 RS232_RxInt_GetState(void)
{
    /* Get the state of the general interrupt. */
    return ((*RS232_RxInt_INTC_SET_EN & (uint32)RS232_RxInt__INTC_MASK) != 0u) ? 1u:0u;
}


/*******************************************************************************
* Function Name: RS232_RxInt_Disable
********************************************************************************
*
* Summary:
*   Disables the Interrupt.
*
* Parameters:
*   None
*
* Return:
*   None
*
*******************************************************************************/
void RS232_RxInt_Disable(void)
{
    /* Disable the general interrupt. */
    *RS232_RxInt_INTC_CLR_EN = RS232_RxInt__INTC_MASK;
}


/*******************************************************************************
* Function Name: RS232_RxInt_SetPending
********************************************************************************
*
* Summary:
*   Causes the Interrupt to enter the pending state, a software method of
*   generating the interrupt.
*
* Parameters:
*   None
*
* Return:
*   None
*
*******************************************************************************/
void RS232_RxInt_SetPending(void)
{
    *RS232_RxInt_INTC_SET_PD = RS232_RxInt__INTC_MASK;
}


/*******************************************************************************
* Function Name: RS232_RxInt_ClearPending
********************************************************************************
*
* Summary:
*   Clears a pending interrupt.
*
* Parameters:
*   None
*
* Return:
*   None
*
*******************************************************************************/
void RS232_RxInt_ClearPending(void)
{
    *RS232_RxInt_INTC_CLR_PD = RS232_RxInt__INTC_MASK;
}

#endif /* End check for removal by optimization */


/* [] END OF FILE */
