/*******************************************************************************
* File Name: VLS_PWR.c  
* Version 2.0
*
* Description:
*  This file contains API to enable firmware control of a Pins component.
*
* Note:
*
********************************************************************************
* Copyright 2008-2014, Cypress Semiconductor Corporation.  All rights reserved.
* You may use this file only in accordance with the license, terms, conditions, 
* disclaimers, and limitations in the end user license agreement accompanying 
* the software package with which this file was provided.
*******************************************************************************/

#include "cytypes.h"
#include "VLS_PWR.h"

/* APIs are not generated for P15[7:6] on PSoC 5 */
#if !(CY_PSOC5A &&\
	 VLS_PWR__PORT == 15 && ((VLS_PWR__MASK & 0xC0) != 0))


/*******************************************************************************
* Function Name: VLS_PWR_Write
********************************************************************************
*
* Summary:
*  Assign a new value to the digital port's data output register.  
*
* Parameters:  
*  prtValue:  The value to be assigned to the Digital Port. 
*
* Return: 
*  None
*  
*******************************************************************************/
void VLS_PWR_Write(uint8 value) 
{
    uint8 staticBits = (VLS_PWR_DR & (uint8)(~VLS_PWR_MASK));
    VLS_PWR_DR = staticBits | ((uint8)(value << VLS_PWR_SHIFT) & VLS_PWR_MASK);
}


/*******************************************************************************
* Function Name: VLS_PWR_SetDriveMode
********************************************************************************
*
* Summary:
*  Change the drive mode on the pins of the port.
* 
* Parameters:  
*  mode:  Change the pins to one of the following drive modes.
*
*  VLS_PWR_DM_STRONG     Strong Drive 
*  VLS_PWR_DM_OD_HI      Open Drain, Drives High 
*  VLS_PWR_DM_OD_LO      Open Drain, Drives Low 
*  VLS_PWR_DM_RES_UP     Resistive Pull Up 
*  VLS_PWR_DM_RES_DWN    Resistive Pull Down 
*  VLS_PWR_DM_RES_UPDWN  Resistive Pull Up/Down 
*  VLS_PWR_DM_DIG_HIZ    High Impedance Digital 
*  VLS_PWR_DM_ALG_HIZ    High Impedance Analog 
*
* Return: 
*  None
*
*******************************************************************************/
void VLS_PWR_SetDriveMode(uint8 mode) 
{
	CyPins_SetPinDriveMode(VLS_PWR_0, mode);
}


/*******************************************************************************
* Function Name: VLS_PWR_Read
********************************************************************************
*
* Summary:
*  Read the current value on the pins of the Digital Port in right justified 
*  form.
*
* Parameters:  
*  None
*
* Return: 
*  Returns the current value of the Digital Port as a right justified number
*  
* Note:
*  Macro VLS_PWR_ReadPS calls this function. 
*  
*******************************************************************************/
uint8 VLS_PWR_Read(void) 
{
    return (VLS_PWR_PS & VLS_PWR_MASK) >> VLS_PWR_SHIFT;
}


/*******************************************************************************
* Function Name: VLS_PWR_ReadDataReg
********************************************************************************
*
* Summary:
*  Read the current value assigned to a Digital Port's data output register
*
* Parameters:  
*  None 
*
* Return: 
*  Returns the current value assigned to the Digital Port's data output register
*  
*******************************************************************************/
uint8 VLS_PWR_ReadDataReg(void) 
{
    return (VLS_PWR_DR & VLS_PWR_MASK) >> VLS_PWR_SHIFT;
}


/* If Interrupts Are Enabled for this Pins component */ 
#if defined(VLS_PWR_INTSTAT) 

    /*******************************************************************************
    * Function Name: VLS_PWR_ClearInterrupt
    ********************************************************************************
    * Summary:
    *  Clears any active interrupts attached to port and returns the value of the 
    *  interrupt status register.
    *
    * Parameters:  
    *  None 
    *
    * Return: 
    *  Returns the value of the interrupt status register
    *  
    *******************************************************************************/
    uint8 VLS_PWR_ClearInterrupt(void) 
    {
        return (VLS_PWR_INTSTAT & VLS_PWR_MASK) >> VLS_PWR_SHIFT;
    }

#endif /* If Interrupts Are Enabled for this Pins component */ 

#endif /* CY_PSOC5A... */

    
/* [] END OF FILE */
